@@ -34,6 +34,7 @@ import org.apache.commons.mail.HtmlEmail;
 
 import java.io.File;
 import java.io.IOException;
+import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
@@ -153,7 +154,7 @@ public final class MailSender {
      */
     public AlertResult sendMails(List<String> receivers, List<String> receiverCcs, String title, String content) {
         AlertResult alertResult = new AlertResult();
-        alertResult.setStatus("false");
+        alertResult.setSuccess(false);
 
         // if there is no receivers && no receiversCc, no need to process
         if (CollectionUtils.isEmpty(receivers) && CollectionUtils.isEmpty(receiverCcs)) {
@@ -171,7 +172,7 @@ public final class MailSender {
                 Session session = getSession();
                 email.setMailSession(session);
                 email.setFrom(mailSenderEmail);
-                email.setCharset(EmailConstants.UTF_8);
+                email.setCharset(StandardCharsets.UTF_8.name());
                 if (CollectionUtils.isNotEmpty(receivers)) {
                     // receivers mail
                     for (String receiver : receivers) {
@@ -200,7 +201,7 @@ public final class MailSender {
 
                 attachment(title, content, partContent);
 
-                alertResult.setStatus("true");
+                alertResult.setSuccess(true);
                 return alertResult;
             } catch (Exception e) {
                 handleException(alertResult, e);
@@ -344,7 +345,8 @@ public final class MailSender {
         ExcelUtils.genExcelFile(content, randomFilename, xlsFilePath);
 
         part2.attachFile(file);
-        part2.setFileName(MimeUtility.encodeText(title + EmailConstants.EXCEL_SUFFIX_XLSX, EmailConstants.UTF_8, "B"));
+        part2.setFileName(
+                MimeUtility.encodeText(title + EmailConstants.EXCEL_SUFFIX_XLSX, StandardCharsets.UTF_8.name(), "B"));
         // add components to collection
         partList.addBodyPart(part1);
         partList.addBodyPart(part2);
@@ -378,7 +380,7 @@ public final class MailSender {
         email.setDebug(true);
         email.send();
 
-        alertResult.setStatus("true");
+        alertResult.setSuccess(true);
 
         return alertResult;
     }
@@ -405,7 +407,9 @@ public final class MailSender {
      */
     private void handleException(AlertResult alertResult, Exception e) {
         log.error("Send email to {} failed", receivers, e);
-        alertResult.setMessage("Send email to {" + String.join(",", receivers) + "} failed，" + e.toString());
+        alertResult.setMessage(
+                String.format("Send email to: %s, failed: %s",
+                        String.join(",", receivers), e.getMessage()));
     }
 
 }
