@@ -17,8 +17,6 @@
 
 package org.apache.dolphinscheduler.plugin.alert.email.template;
 
-import static org.junit.Assert.assertEquals;
-
 import org.apache.dolphinscheduler.alert.api.ShowType;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.plugin.alert.email.EmailConstants;
@@ -27,7 +25,8 @@ import java.util.ArrayList;
 import java.util.LinkedHashMap;
 import java.util.List;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -41,11 +40,11 @@ public class DefaultHTMLTemplateTest {
 
         String tableTypeMessage = template.getMessageFromTemplate(list2String(), ShowType.TABLE, true);
 
-        assertEquals(tableTypeMessage, generateMockTableTypeResultByHand());
+        Assertions.assertEquals(tableTypeMessage, generateMockTableTypeResultByHand());
 
         String textTypeMessage = template.getMessageFromTemplate(list2String(), ShowType.TEXT, true);
 
-        assertEquals(textTypeMessage, generateMockTextTypeResultByHand());
+        Assertions.assertEquals(textTypeMessage, generateMockTextTypeResultByHand());
 
         String mapjson = "{\"taskInstanceId\":94,\"taskName\":\"000\",\"taskType\":\"DATA_QUALITY\","
                 + "\"processDefinitionId\":0,\"processInstanceId\":58,\"state\":\"RUNNING_EXECUTION\","
@@ -53,7 +52,7 @@ public class DefaultHTMLTemplateTest {
                 + "\"logPath\":\"/Users/mac/学习/dolphinscheduler/dolphinscheduler/logs/20220717/6222644042400_1-58-94.log\"}";
         textTypeMessage = template.getMessageFromTemplate(mapjson, ShowType.TEXT, true);
         String result = textTypeMessage;
-        assertEquals(textTypeMessage, result);
+        Assertions.assertEquals(textTypeMessage, result);
     }
 
     private String list2String() {
@@ -82,19 +81,19 @@ public class DefaultHTMLTemplateTest {
 
     private String generateMockTableTypeResultByHand() {
         return EmailConstants.HTML_HEADER_PREFIX
-            + "<thead>"
-            + "<tr><th>mysql service name</th><th>mysql address</th><th>database client connections</th><th>port</th><th>no index of number</th></tr>"
-            + "</thead>"+System.getProperty("line.separator")
-            + "<tr><td>mysql200</td><td>192.168.xx.xx</td><td>190</td><td>3306</td><td>80</td></tr>"
-            + "<tr><td>mysql210</td><td>192.168.xx.xx</td><td>90</td><td>3306</td><td>10</td></tr>"
-            + EmailConstants.TABLE_BODY_HTML_TAIL;
+                + "<thead>"
+                + "<tr><th>mysql service name</th><th>mysql address</th><th>database client connections</th><th>port</th><th>no index of number</th></tr>"
+                + "</thead>" + System.getProperty("line.separator")
+                + "<tr><td>mysql200</td><td>192.168.xx.xx</td><td>190</td><td>3306</td><td>80</td></tr>"
+                + "<tr><td>mysql210</td><td>192.168.xx.xx</td><td>90</td><td>3306</td><td>10</td></tr>"
+                + EmailConstants.TABLE_BODY_HTML_TAIL;
 
     }
 
     private String generateMockTextTypeResultByHand() {
         return EmailConstants.HTML_HEADER_PREFIX
-            + "<tr><td>{\"mysql service name\":\"mysql200\",\"mysql address\":\"192.168.xx.xx\",\"database client connections\":\"190\",\"port\":\"3306\",\"no index of number\":\"80\"}</td></tr>"
-            + "<tr><td>{\"mysql service name\":\"mysql210\",\"mysql address\":\"192.168.xx.xx\",\"database client connections\":\"90\",\"port\":\"3306\",\"no index of number\":\"10\"}</td></tr>"
-            + EmailConstants.TABLE_BODY_HTML_TAIL;
+                + "<tr><td>{\"mysql service name\":\"mysql200\",\"mysql address\":\"192.168.xx.xx\",\"database client connections\":\"190\",\"port\":\"3306\",\"no index of number\":\"80\"}</td></tr>"
+                + "<tr><td>{\"mysql service name\":\"mysql210\",\"mysql address\":\"192.168.xx.xx\",\"database client connections\":\"90\",\"port\":\"3306\",\"no index of number\":\"10\"}</td></tr>"
+                + EmailConstants.TABLE_BODY_HTML_TAIL;
     }
 }
