@@ -31,7 +31,7 @@ public final class HttpAlertChannel implements AlertChannel {
         AlertData alertData = alertInfo.getAlertData();
         Map<String, String> paramsMap = alertInfo.getAlertParams();
         if (null == paramsMap) {
-            return new AlertResult("false", "http params is null");
+            return new AlertResult(false, "http params is null");
         }
 
         return new HttpSender(paramsMap).send(alertData.getContent());
