@@ -20,11 +20,15 @@ package org.apache.dolphinscheduler.plugin.alert.http;
 import org.apache.dolphinscheduler.alert.api.AlertChannel;
 import org.apache.dolphinscheduler.alert.api.AlertChannelFactory;
 import org.apache.dolphinscheduler.alert.api.AlertInputTips;
+import org.apache.dolphinscheduler.common.model.OkHttpRequestHeaderContentType;
+import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.spi.params.base.DataType;
+import org.apache.dolphinscheduler.spi.params.base.ParamsOptions;
 import org.apache.dolphinscheduler.spi.params.base.PluginParams;
 import org.apache.dolphinscheduler.spi.params.base.Validate;
 import org.apache.dolphinscheduler.spi.params.input.InputParam;
 import org.apache.dolphinscheduler.spi.params.input.number.InputNumberParam;
+import org.apache.dolphinscheduler.spi.params.radio.RadioParam;
 
 import java.util.Arrays;
 import java.util.List;
@@ -43,7 +47,7 @@ public final class HttpAlertChannelFactory implements AlertChannelFactory {
     public List<PluginParams> params() {
 
         InputParam url = InputParam.newBuilder(HttpAlertConstants.NAME_URL, HttpAlertConstants.URL)
-                .setPlaceholder(AlertInputTips.URL.getMsg())
+                .setPlaceholder(JSONUtils.toJsonString(AlertInputTips.getAllMsg(AlertInputTips.URL)))
                 .addValidate(Validate.newBuilder()
                         .setRequired(true)
                         .build())
@@ -51,7 +55,20 @@ public final class HttpAlertChannelFactory implements AlertChannelFactory {
 
         InputParam headerParams =
                 InputParam.newBuilder(HttpAlertConstants.NAME_HEADER_PARAMS, HttpAlertConstants.HEADER_PARAMS)
-                        .setPlaceholder(AlertInputTips.HEADER.getMsg())
+                        .setPlaceholder(JSONUtils.toJsonString(AlertInputTips.getAllMsg(AlertInputTips.HEADER)))
+                        .addValidate(Validate.newBuilder()
+                                .setRequired(false)
+                                .build())
+                        .build();
+
+        RadioParam contentType =
+                RadioParam.newBuilder(HttpAlertConstants.NAME_CONTENT_TYPE, HttpAlertConstants.CONTENT_TYPE)
+                        .addParamsOptions(new ParamsOptions(OkHttpRequestHeaderContentType.APPLICATION_JSON.getValue(),
+                                OkHttpRequestHeaderContentType.APPLICATION_JSON.getValue(), false))
+                        .addParamsOptions(
+                                new ParamsOptions(OkHttpRequestHeaderContentType.APPLICATION_FORM_URLENCODED.getValue(),
+                                        OkHttpRequestHeaderContentType.APPLICATION_FORM_URLENCODED.getValue(), false))
+                        .setValue(OkHttpRequestHeaderContentType.APPLICATION_JSON.getValue())
                         .addValidate(Validate.newBuilder()
                                 .setRequired(true)
                                 .build())
@@ -59,27 +76,21 @@ public final class HttpAlertChannelFactory implements AlertChannelFactory {
 
         InputParam bodyParams =
                 InputParam.newBuilder(HttpAlertConstants.NAME_BODY_PARAMS, HttpAlertConstants.BODY_PARAMS)
-                        .setPlaceholder(AlertInputTips.JSON_BODY.getMsg())
+                        .setPlaceholder(JSONUtils.toJsonString(AlertInputTips.getAllMsg(AlertInputTips.JSON_BODY)))
                         .addValidate(Validate.newBuilder()
                                 .setRequired(false)
                                 .build())
                         .build();
 
-        InputParam contentField =
-                InputParam.newBuilder(HttpAlertConstants.NAME_CONTENT_FIELD, HttpAlertConstants.CONTENT_FIELD)
-                        .setPlaceholder(AlertInputTips.FIELD_NAME.getMsg())
-                        .addValidate(Validate.newBuilder()
-                                .setRequired(true)
-                                .build())
-                        .build();
-
-        InputParam requestType =
-                InputParam.newBuilder(HttpAlertConstants.NAME_REQUEST_TYPE, HttpAlertConstants.REQUEST_TYPE)
-                        .setPlaceholder(AlertInputTips.HTTP_METHOD.getMsg())
-                        .addValidate(Validate.newBuilder()
-                                .setRequired(true)
-                                .build())
-                        .build();
+        RadioParam requestType = RadioParam
+                .newBuilder(HttpAlertConstants.NAME_REQUEST_TYPE, HttpAlertConstants.REQUEST_TYPE)
+                .addParamsOptions(new ParamsOptions(HttpRequestMethod.GET.name(), HttpRequestMethod.GET.name(), false))
+                .addParamsOptions(
+                        new ParamsOptions(HttpRequestMethod.POST.name(), HttpRequestMethod.POST.name(), false))
+                .addParamsOptions(new ParamsOptions(HttpRequestMethod.PUT.name(), HttpRequestMethod.PUT.name(), false))
+                .setValue(HttpRequestMethod.GET.name())
+                .addValidate(Validate.newBuilder().setRequired(true).build())
+                .build();
 
         InputNumberParam timeout =
                 InputNumberParam.newBuilder(HttpAlertConstants.NAME_TIMEOUT, HttpAlertConstants.TIMEOUT)
@@ -90,7 +101,7 @@ public final class HttpAlertChannelFactory implements AlertChannelFactory {
                                 .build())
                         .build();
 
-        return Arrays.asList(url, requestType, headerParams, bodyParams, contentField, timeout);
+        return Arrays.asList(url, requestType, headerParams, bodyParams, contentType, timeout);
     }
 
     @Override
