@@ -30,7 +30,7 @@ public final class TelegramAlertChannel implements AlertChannel {
     public AlertResult process(AlertInfo info) {
         Map<String, String> alertParams = info.getAlertParams();
         if (alertParams == null || alertParams.isEmpty()) {
-            return new AlertResult("false", "Telegram alert params is empty");
+            return AlertResult.fail("Telegram alert params is empty");
         }
         AlertData data = info.getAlertData();
         return new TelegramSender(alertParams).sendMessage(data);
