@@ -17,8 +17,6 @@
 
 package org.apache.dolphinscheduler.plugin.alert.telegram;
 
-import com.google.auto.service.AutoService;
-
 import static org.apache.dolphinscheduler.common.constants.Constants.STRING_FALSE;
 import static org.apache.dolphinscheduler.common.constants.Constants.STRING_NO;
 import static org.apache.dolphinscheduler.common.constants.Constants.STRING_TRUE;
@@ -26,17 +24,22 @@ import static org.apache.dolphinscheduler.common.constants.Constants.STRING_YES;
 
 import org.apache.dolphinscheduler.alert.api.AlertChannel;
 import org.apache.dolphinscheduler.alert.api.AlertChannelFactory;
-import org.apache.dolphinscheduler.spi.params.PasswordParam;
+import org.apache.dolphinscheduler.alert.api.AlertInputTips;
+import org.apache.dolphinscheduler.common.utils.JSONUtils;
+import org.apache.dolphinscheduler.spi.params.base.DataType;
 import org.apache.dolphinscheduler.spi.params.base.ParamsOptions;
 import org.apache.dolphinscheduler.spi.params.base.PluginParams;
 import org.apache.dolphinscheduler.spi.params.base.Validate;
 import org.apache.dolphinscheduler.spi.params.input.InputParam;
+import org.apache.dolphinscheduler.spi.params.input.number.InputNumberParam;
 import org.apache.dolphinscheduler.spi.params.radio.RadioParam;
 import org.apache.dolphinscheduler.spi.params.select.SelectParam;
 
 import java.util.Arrays;
 import java.util.List;
 
+import com.google.auto.service.AutoService;
+
 @AutoService(AlertChannelFactory.class)
 public final class TelegramAlertChannelFactory implements AlertChannelFactory {
 
@@ -53,40 +56,50 @@ public final class TelegramAlertChannelFactory implements AlertChannelFactory {
     @Override
     public List<PluginParams> params() {
 
-
-        InputParam webHookParam = InputParam.newBuilder(TelegramParamsConstants.NAME_TELEGRAM_WEB_HOOK, TelegramParamsConstants.TELEGRAM_WEB_HOOK)
+        InputParam webHookParam = InputParam
+                .newBuilder(TelegramParamsConstants.NAME_TELEGRAM_WEB_HOOK, TelegramParamsConstants.TELEGRAM_WEB_HOOK)
                 .addValidate(Validate.newBuilder()
                         .setRequired(true)
                         .build())
-                .setPlaceholder("telegram web hook")
+                .setPlaceholder(JSONUtils.toJsonString(AlertInputTips.getAllMsg(AlertInputTips.WEBHOOK)))
                 .build();
 
-        InputParam botTokenParam = InputParam.newBuilder(TelegramParamsConstants.NAME_TELEGRAM_BOT_TOKEN, TelegramParamsConstants.TELEGRAM_BOT_TOKEN)
+        InputParam botTokenParam = InputParam
+                .newBuilder(TelegramParamsConstants.NAME_TELEGRAM_BOT_TOKEN, TelegramParamsConstants.TELEGRAM_BOT_TOKEN)
                 .addValidate(Validate.newBuilder()
                         .setRequired(true)
                         .build())
-                .setPlaceholder("telegram bot token")
+                .setPlaceholder(JSONUtils.toJsonString(AlertInputTips.getAllMsg(AlertInputTips.BOT_TOKEN)))
                 .build();
 
-        InputParam chatIdParam = InputParam.newBuilder(TelegramParamsConstants.NAME_TELEGRAM_CHAT_ID, TelegramParamsConstants.TELEGRAM_CHAT_ID)
+        InputParam chatIdParam = InputParam
+                .newBuilder(TelegramParamsConstants.NAME_TELEGRAM_CHAT_ID, TelegramParamsConstants.TELEGRAM_CHAT_ID)
                 .addValidate(Validate.newBuilder()
                         .setRequired(true)
                         .build())
-                .setPlaceholder("telegram channel chat id")
+                .setPlaceholder(JSONUtils.toJsonString(AlertInputTips.getAllMsg(AlertInputTips.CHANNEL_ID)))
                 .build();
 
-        SelectParam parseMode = SelectParam.newBuilder(TelegramParamsConstants.NAME_TELEGRAM_PARSE_MODE, TelegramParamsConstants.TELEGRAM_PARSE_MODE)
-                .addOptions(new ParamsOptions(TelegramAlertConstants.PARSE_MODE_TXT, TelegramAlertConstants.PARSE_MODE_TXT, false))
-                .addOptions(new ParamsOptions(TelegramAlertConstants.PARSE_MODE_MARKDOWN, TelegramAlertConstants.PARSE_MODE_MARKDOWN, false))
-                .addOptions(new ParamsOptions(TelegramAlertConstants.PARSE_MODE_MARKDOWN_V2, TelegramAlertConstants.PARSE_MODE_MARKDOWN_V2, false))
-                .addOptions(new ParamsOptions(TelegramAlertConstants.PARSE_MODE_HTML, TelegramAlertConstants.PARSE_MODE_HTML, false))
+        SelectParam parseMode = SelectParam
+                .newBuilder(TelegramParamsConstants.NAME_TELEGRAM_PARSE_MODE,
+                        TelegramParamsConstants.TELEGRAM_PARSE_MODE)
+                .addOptions(new ParamsOptions(TelegramAlertConstants.PARSE_MODE_TXT,
+                        TelegramAlertConstants.PARSE_MODE_TXT, false))
+                .addOptions(new ParamsOptions(TelegramAlertConstants.PARSE_MODE_MARKDOWN,
+                        TelegramAlertConstants.PARSE_MODE_MARKDOWN, false))
+                .addOptions(new ParamsOptions(TelegramAlertConstants.PARSE_MODE_MARKDOWN_V2,
+                        TelegramAlertConstants.PARSE_MODE_MARKDOWN_V2, false))
+                .addOptions(new ParamsOptions(TelegramAlertConstants.PARSE_MODE_HTML,
+                        TelegramAlertConstants.PARSE_MODE_HTML, false))
                 .setValue(TelegramAlertConstants.PARSE_MODE_TXT)
                 .addValidate(Validate.newBuilder()
                         .setRequired(true)
                         .build())
                 .build();
 
-        RadioParam isEnableProxy = RadioParam.newBuilder(TelegramParamsConstants.NAME_TELEGRAM_PROXY_ENABLE, TelegramParamsConstants.TELEGRAM_PROXY_ENABLE)
+        RadioParam isEnableProxy = RadioParam
+                .newBuilder(TelegramParamsConstants.NAME_TELEGRAM_PROXY_ENABLE,
+                        TelegramParamsConstants.TELEGRAM_PROXY_ENABLE)
                 .addParamsOptions(new ParamsOptions(STRING_YES, STRING_TRUE, false))
                 .addParamsOptions(new ParamsOptions(STRING_NO, STRING_FALSE, false))
                 .setValue(STRING_FALSE)
@@ -95,33 +108,40 @@ public final class TelegramAlertChannelFactory implements AlertChannelFactory {
                         .build())
                 .build();
 
-        InputParam proxyParam = InputParam.newBuilder(TelegramParamsConstants.NAME_TELEGRAM_PROXY, TelegramParamsConstants.TELEGRAM_PROXY)
+        InputParam proxyParam = InputParam
+                .newBuilder(TelegramParamsConstants.NAME_TELEGRAM_PROXY, TelegramParamsConstants.TELEGRAM_PROXY)
                 .addValidate(Validate.newBuilder()
                         .setRequired(false)
                         .build())
                 .build();
 
-        InputParam portParam = InputParam.newBuilder(TelegramParamsConstants.NAME_TELEGRAM_PORT, TelegramParamsConstants.TELEGRAM_PORT)
+        InputNumberParam portParam =
+                InputNumberParam
+                        .newBuilder(TelegramParamsConstants.NAME_TELEGRAM_PORT, TelegramParamsConstants.TELEGRAM_PORT)
+                        .addValidate(Validate.newBuilder()
+                                .setRequired(false)
+                                .setType(DataType.NUMBER.getDataType())
+                                .build())
+                        .build();
+
+        InputParam userParam =
+                InputParam.newBuilder(TelegramParamsConstants.NAME_TELEGRAM_USER, TelegramParamsConstants.TELEGRAM_USER)
+                        .addValidate(Validate.newBuilder()
+                                .setRequired(false)
+                                .build())
+                        .build();
+
+        InputParam passwordParam = InputParam
+                .newBuilder(TelegramParamsConstants.NAME_TELEGRAM_PASSWORD, TelegramParamsConstants.TELEGRAM_PASSWORD)
                 .addValidate(Validate.newBuilder()
                         .setRequired(false)
                         .build())
+                .setPlaceholder(JSONUtils.toJsonString(AlertInputTips.getAllMsg(AlertInputTips.PASSWORD)))
+                .setType("password")
                 .build();
 
-        InputParam userParam = InputParam.newBuilder(TelegramParamsConstants.NAME_TELEGRAM_USER, TelegramParamsConstants.TELEGRAM_USER)
-                .addValidate(Validate.newBuilder()
-                        .setRequired(false)
-                        .build())
-                .build();
-
-        PasswordParam passwordParam = PasswordParam.newBuilder(TelegramParamsConstants.NAME_TELEGRAM_PASSWORD, TelegramParamsConstants.TELEGRAM_PASSWORD)
-                .addValidate(Validate.newBuilder()
-                        .setRequired(false)
-                        .build())
-                .setPlaceholder("if enable use authentication, you need input password")
-                .build();
-
-        return Arrays.asList(webHookParam, botTokenParam, chatIdParam, parseMode, isEnableProxy, proxyParam, portParam, userParam, passwordParam);
+        return Arrays.asList(webHookParam, botTokenParam, chatIdParam, parseMode, isEnableProxy, proxyParam, portParam,
+                userParam, passwordParam);
     }
 
-
 }
