@@ -52,7 +52,7 @@ public class TelegramSenderTest {
                 TelegramParamsConstants.NAME_TELEGRAM_BOT_TOKEN, "XXXXXXX");
         TelegramSender telegramSender = new TelegramSender(telegramConfig);
         AlertResult result = telegramSender.sendMessage(alertData);
-        Assertions.assertEquals("false", result.getStatus());
+        Assertions.assertFalse(result.isSuccess());
 
     }
 
@@ -65,7 +65,7 @@ public class TelegramSenderTest {
                 TelegramParamsConstants.NAME_TELEGRAM_CHAT_ID, "-XXXXXXX");
         TelegramSender telegramSender = new TelegramSender(telegramConfig);
         AlertResult result = telegramSender.sendMessage(alertData);
-        Assertions.assertEquals("false", result.getStatus());
+        Assertions.assertFalse(result.isSuccess());
     }
 
     @Test
@@ -75,7 +75,7 @@ public class TelegramSenderTest {
         alertData.setContent("telegram test content");
         TelegramSender telegramSender = new TelegramSender(telegramConfig);
         AlertResult result = telegramSender.sendMessage(alertData);
-        Assertions.assertEquals("false", result.getStatus());
+        Assertions.assertFalse(result.isSuccess());
 
     }
 
@@ -89,7 +89,7 @@ public class TelegramSenderTest {
                 TelegramParamsConstants.NAME_TELEGRAM_PARSE_MODE, TelegramAlertConstants.PARSE_MODE_MARKDOWN);
         TelegramSender telegramSender = new TelegramSender(telegramConfig);
         AlertResult result = telegramSender.sendMessage(alertData);
-        Assertions.assertEquals("false", result.getStatus());
+        Assertions.assertFalse(result.isSuccess());
 
     }
 
@@ -102,7 +102,7 @@ public class TelegramSenderTest {
                 TelegramParamsConstants.NAME_TELEGRAM_PARSE_MODE, TelegramAlertConstants.PARSE_MODE_HTML);
         TelegramSender telegramSender = new TelegramSender(telegramConfig);
         AlertResult result = telegramSender.sendMessage(alertData);
-        Assertions.assertEquals("false", result.getStatus());
+        Assertions.assertFalse(result.isSuccess());
 
     }
 
