@@ -31,7 +31,7 @@ public final class WeChatAlertChannel implements AlertChannel {
         AlertData alertData = info.getAlertData();
         Map<String, String> paramsMap = info.getAlertParams();
         if (null == paramsMap) {
-            return new AlertResult("false", "we chat params is null");
+            return new AlertResult(false, "we chat params is null");
         }
         return new WeChatSender(paramsMap).sendEnterpriseWeChat(alertData.getTitle(), alertData.getContent());
 
