@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-
 package org.apache.dolphinscheduler.plugin.alert.wechat;
 
 public enum WeChatType {
-    APP(1, "应用"),
-    APPCHAT(2, "群聊"),
+
+    APP(1, "APP/应用"),
+    APPCHAT(2, "GROUP CHAT/群聊"),
     ;
 
     private final int code;
