@@ -17,66 +17,89 @@
 
 package org.apache.dolphinscheduler.alert;
 
+import org.apache.dolphinscheduler.alert.metrics.AlertServerMetrics;
 import org.apache.dolphinscheduler.alert.plugin.AlertPluginManager;
 import org.apache.dolphinscheduler.alert.registry.AlertRegistryClient;
 import org.apache.dolphinscheduler.alert.rpc.AlertRpcServer;
 import org.apache.dolphinscheduler.alert.service.AlertBootstrapService;
+import org.apache.dolphinscheduler.alert.service.AlertHAServer;
+import org.apache.dolphinscheduler.common.CommonConfiguration;
 import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.lifecycle.ServerLifeCycleManager;
+import org.apache.dolphinscheduler.common.thread.DefaultUncaughtExceptionHandler;
 import org.apache.dolphinscheduler.common.thread.ThreadUtils;
+import org.apache.dolphinscheduler.dao.DaoConfiguration;
+import org.apache.dolphinscheduler.registry.api.RegistryConfiguration;
+import org.apache.dolphinscheduler.registry.api.ha.AbstractServerStatusChangeListener;
 
+import javax.annotation.PostConstruct;
 import javax.annotation.PreDestroy;
 
 import lombok.extern.slf4j.Slf4j;
 
 import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.boot.SpringApplication;
 import org.springframework.boot.autoconfigure.SpringBootApplication;
-import org.springframework.boot.builder.SpringApplicationBuilder;
-import org.springframework.boot.context.event.ApplicationReadyEvent;
-import org.springframework.context.annotation.ComponentScan;
-import org.springframework.context.event.EventListener;
+import org.springframework.context.annotation.Import;
 
-@SpringBootApplication
-@ComponentScan("org.apache.dolphinscheduler")
 @Slf4j
+@Import({CommonConfiguration.class,
+        DaoConfiguration.class,
+        RegistryConfiguration.class})
+@SpringBootApplication
 public class AlertServer {
 
-    @Autowired
-    private AlertBootstrapService alertBootstrapService;
     @Autowired
     private AlertRpcServer alertRpcServer;
+
     @Autowired
     private AlertPluginManager alertPluginManager;
+
     @Autowired
     private AlertRegistryClient alertRegistryClient;
 
+    @Autowired
+    private AlertHAServer alertHAServer;
+
+    @Autowired
+    private AlertBootstrapService alertBootstrapService;
+
     public static void main(String[] args) {
+        AlertServerMetrics.registerUncachedException(DefaultUncaughtExceptionHandler::getUncaughtExceptionCount);
+        Thread.setDefaultUncaughtExceptionHandler(DefaultUncaughtExceptionHandler.getInstance());
         Thread.currentThread().setName(Constants.THREAD_NAME_ALERT_SERVER);
-        new SpringApplicationBuilder(AlertServer.class).run(args);
+        SpringApplication.run(AlertServer.class, args);
     }
 
-    @EventListener
-    public void run(ApplicationReadyEvent readyEvent) {
-        log.info("Alert server is staring ...");
+    @PostConstruct
+    public void run() {
+        ServerLifeCycleManager.toRunning();
+        log.info("AlertServer is staring ...");
         alertPluginManager.start();
-        alertRegistryClient.start();
-        alertBootstrapService.start();
         alertRpcServer.start();
-        log.info("Alert server is started ...");
+        alertRegistryClient.start();
+
+        alertHAServer.addServerStatusChangeListener(new AbstractServerStatusChangeListener() {
+
+            @Override
+            public void changeToActive() {
+                alertBootstrapService.start();
+            }
+
+            @Override
+            public void changeToStandBy() {
+                close();
+            }
+        });
+
+        alertHAServer.start();
+
+        log.info("AlertServer is started ...");
     }
 
     @PreDestroy
     public void close() {
-        destroy("alert server destroy");
-    }
-
-    /**
-     * gracefully stop
-     *
-     * @param cause stop cause
-     */
-    public void destroy(String cause) {
-
+        String cause = "AlertServer destroy";
         try {
             // set stop signal is true
             // execute only once
@@ -84,18 +107,19 @@ public class AlertServer {
                 log.warn("AlterServer is already stopped");
                 return;
             }
-            log.info("Alert server is stopping, cause: {}", cause);
+            log.info("AlertServer is stopping, cause: {}", cause);
             try (
-                    AlertRpcServer closedAlertRpcServer = alertRpcServer;
-                    AlertBootstrapService closedAlertBootstrapService = alertBootstrapService;
-                    AlertRegistryClient closedAlertRegistryClient = alertRegistryClient) {
-                // close resource
+                    final AlertRpcServer ignore = alertRpcServer;
+                    final AlertRegistryClient ignore1 = alertRegistryClient;
+                    final AlertHAServer ignore2 = alertHAServer;
+                    final AlertBootstrapService ignore3 = alertBootstrapService;) {
             }
             // thread sleep 3 seconds for thread quietly stop
             ThreadUtils.sleep(Constants.SERVER_CLOSE_WAIT_TIME.toMillis());
-            log.info("Alter server stopped, cause: {}", cause);
+            log.info("AlertServer stopped, cause: {}", cause);
         } catch (Exception e) {
-            log.error("Alert server stop failed, cause: {}", cause, e);
+            log.error("AlertServer stop failed, cause: {}", cause, e);
         }
     }
+
 }
