@@ -34,8 +34,6 @@ import org.apache.dolphinscheduler.api.utils.PageInfo;
 import org.apache.dolphinscheduler.api.utils.Result;
 import org.apache.dolphinscheduler.api.vo.AlertPluginInstanceVO;
 import org.apache.dolphinscheduler.common.constants.Constants;
-import org.apache.dolphinscheduler.common.enums.AlertPluginInstanceType;
-import org.apache.dolphinscheduler.common.enums.WarningType;
 import org.apache.dolphinscheduler.dao.entity.AlertPluginInstance;
 import org.apache.dolphinscheduler.dao.entity.User;
 import org.apache.dolphinscheduler.plugin.task.api.utils.ParameterUtils;
@@ -97,11 +95,9 @@ public class AlertPluginInstanceController extends BaseController {
     public Result<AlertPluginInstance> createAlertPluginInstance(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
                                                                  @RequestParam(value = "pluginDefineId") int pluginDefineId,
                                                                  @RequestParam(value = "instanceName") String instanceName,
-                                                                 @RequestParam(value = "instanceType") AlertPluginInstanceType instanceType,
-                                                                 @RequestParam(value = "warningType") WarningType warningType,
                                                                  @RequestParam(value = "pluginInstanceParams") String pluginInstanceParams) {
         AlertPluginInstance alertPluginInstance = alertPluginInstanceService.create(loginUser, pluginDefineId,
-                instanceName, instanceType, warningType, pluginInstanceParams);
+                instanceName, pluginInstanceParams);
         return Result.success(alertPluginInstance);
     }
 
@@ -141,10 +137,9 @@ public class AlertPluginInstanceController extends BaseController {
     public Result<AlertPluginInstance> updateAlertPluginInstanceById(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
                                                                      @PathVariable(value = "id") int id,
                                                                      @RequestParam(value = "instanceName") String instanceName,
-                                                                     @RequestParam(value = "warningType") WarningType warningType,
                                                                      @RequestParam(value = "pluginInstanceParams") String pluginInstanceParams) {
         AlertPluginInstance alertPluginInstance =
-                alertPluginInstanceService.updateById(loginUser, id, instanceName, warningType, pluginInstanceParams);
+                alertPluginInstanceService.updateById(loginUser, id, instanceName, pluginInstanceParams);
         return Result.success(alertPluginInstance);
     }
 
