@@ -24,7 +24,6 @@ import static org.apache.dolphinscheduler.api.enums.Status.GET_USER_INFO_ERROR;
 import static org.apache.dolphinscheduler.api.enums.Status.GRANT_DATASOURCE_ERROR;
 import static org.apache.dolphinscheduler.api.enums.Status.GRANT_K8S_NAMESPACE_ERROR;
 import static org.apache.dolphinscheduler.api.enums.Status.GRANT_PROJECT_ERROR;
-import static org.apache.dolphinscheduler.api.enums.Status.GRANT_UDF_FUNCTION_ERROR;
 import static org.apache.dolphinscheduler.api.enums.Status.QUERY_USER_LIST_PAGING_ERROR;
 import static org.apache.dolphinscheduler.api.enums.Status.REVOKE_PROJECT_ERROR;
 import static org.apache.dolphinscheduler.api.enums.Status.UNAUTHORIZED_USER_ERROR;
@@ -112,9 +111,9 @@ public class UsersController extends BaseController {
      * query user list paging
      *
      * @param loginUser login user
-     * @param pageNo page number
+     * @param pageNo    page number
      * @param searchVal search avlue
-     * @param pageSize page size
+     * @param pageSize  page size
      * @return user list page
      */
     @Operation(summary = "queryUserList", description = "QUERY_USER_LIST_NOTES")
@@ -138,14 +137,14 @@ public class UsersController extends BaseController {
     /**
      * update user
      *
-     * @param loginUser login user
-     * @param id user id
-     * @param userName user name
+     * @param loginUser    login user
+     * @param id           user id
+     * @param userName     user name
      * @param userPassword user password
-     * @param email email
-     * @param tenantId tennat id
-     * @param phone phone
-     * @param queue queue
+     * @param email        email
+     * @param tenantId     tennat id
+     * @param phone        phone
+     * @param queue        queue
      * @return update result code
      */
     @Operation(summary = "updateUser", description = "UPDATE_USER_NOTES")
@@ -190,7 +189,7 @@ public class UsersController extends BaseController {
      * delete user by id
      *
      * @param loginUser login user
-     * @param id user id
+     * @param id        user id
      * @return delete result code
      */
     @Operation(summary = "delUserById", description = "DELETE_USER_BY_ID_NOTES")
@@ -210,8 +209,8 @@ public class UsersController extends BaseController {
     /**
      * revoke project By Id
      *
-     * @param loginUser login user
-     * @param userId user id
+     * @param loginUser  login user
+     * @param userId     user id
      * @param projectIds project id array
      * @return revoke result code
      */
@@ -233,8 +232,8 @@ public class UsersController extends BaseController {
     /**
      * grant project with read permission
      *
-     * @param loginUser login user
-     * @param userId user id
+     * @param loginUser  login user
+     * @param userId     user id
      * @param projectIds project id array
      * @return grant result code
      */
@@ -256,8 +255,8 @@ public class UsersController extends BaseController {
     /**
      * grant project
      *
-     * @param loginUser login user
-     * @param userId user id
+     * @param loginUser  login user
+     * @param userId     user id
      * @param projectIds project id array
      * @return grant result code
      */
@@ -279,8 +278,8 @@ public class UsersController extends BaseController {
     /**
      * grant project by code
      *
-     * @param loginUser login user
-     * @param userId user id
+     * @param loginUser   login user
+     * @param userId      user id
      * @param projectCode project code
      * @return grant result code
      */
@@ -302,9 +301,9 @@ public class UsersController extends BaseController {
     /**
      * revoke project
      *
-     * @param loginUser     login user
-     * @param userId        user id
-     * @param projectCode   project code
+     * @param loginUser   login user
+     * @param userId      user id
+     * @param projectCode project code
      * @return revoke result code
      */
     @Operation(summary = "revokeProject", description = "REVOKE_PROJECT_NOTES")
@@ -322,34 +321,11 @@ public class UsersController extends BaseController {
         return returnDataList(result);
     }
 
-    /**
-     * grant udf function
-     *
-     * @param loginUser login user
-     * @param userId user id
-     * @param udfIds udf id array
-     * @return grant result code
-     */
-    @Operation(summary = "grantUDFFunc", description = "GRANT_UDF_FUNC_NOTES")
-    @Parameters({
-            @Parameter(name = "userId", description = "USER_ID", required = true, schema = @Schema(implementation = int.class, example = "100")),
-            @Parameter(name = "udfIds", description = "UDF_IDS", required = true, schema = @Schema(implementation = String.class))
-    })
-    @PostMapping(value = "/grant-udf-func")
-    @ResponseStatus(HttpStatus.OK)
-    @ApiException(GRANT_UDF_FUNCTION_ERROR)
-    public Result grantUDFFunc(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
-                               @RequestParam(value = "userId") int userId,
-                               @RequestParam(value = "udfIds") String udfIds) {
-        Map<String, Object> result = usersService.grantUDFFunction(loginUser, userId, udfIds);
-        return returnDataList(result);
-    }
-
     /**
      * grant namespace
      *
-     * @param loginUser login user
-     * @param userId user id
+     * @param loginUser    login user
+     * @param userId       user id
      * @param namespaceIds namespace id array
      * @return grant result code
      */
@@ -371,8 +347,8 @@ public class UsersController extends BaseController {
     /**
      * grant datasource
      *
-     * @param loginUser login user
-     * @param userId user id
+     * @param loginUser     login user
+     * @param userId        user id
      * @param datasourceIds data source id array
      * @return grant result code
      */
@@ -439,7 +415,7 @@ public class UsersController extends BaseController {
      * verify username
      *
      * @param loginUser login user
-     * @param userName user name
+     * @param userName  user name
      * @return true if user name not exists, otherwise return false
      */
     @Operation(summary = "verifyUserName", description = "VERIFY_USER_NAME_NOTES")
@@ -457,7 +433,7 @@ public class UsersController extends BaseController {
     /**
      * unauthorized user
      *
-     * @param loginUser login user
+     * @param loginUser    login user
      * @param alertgroupId alert group id
      * @return unauthorize result code
      */
@@ -477,7 +453,7 @@ public class UsersController extends BaseController {
     /**
      * authorized user
      *
-     * @param loginUser login user
+     * @param loginUser    login user
      * @param alertgroupId alert group id
      * @return authorized result code
      */
@@ -502,10 +478,10 @@ public class UsersController extends BaseController {
     /**
      * user registry
      *
-     * @param userName user name
-     * @param userPassword user password
+     * @param userName       user name
+     * @param userPassword   user password
      * @param repeatPassword repeat password
-     * @param email user email
+     * @param email          user email
      */
     @Operation(summary = "registerUser", description = "REGISTER_USER_NOTES")
     @Parameters({
