@@ -19,12 +19,12 @@ package org.apache.dolphinscheduler.api.dto.treeview;
 
 import java.util.Date;
 
-/**
- * Instance
- */
+import lombok.Data;
+
+@Data
 public class Instance {
 
-    private int id;
+    private Integer id;
 
     /**
      * node name
@@ -56,7 +56,6 @@ public class Instance {
      */
     private Date endTime;
 
-
     /**
      * node running on which host
      */
@@ -79,7 +78,8 @@ public class Instance {
         this.type = type;
     }
 
-    public Instance(int id, String name, long code, String type, String state, Date startTime, Date endTime, String host, String duration, long subflowCode) {
+    public Instance(int id, String name, long code, String type, String state, Date startTime, Date endTime,
+                    String host, String duration, long subflowCode) {
         this.id = id;
         this.name = name;
         this.code = code;
@@ -92,87 +92,8 @@ public class Instance {
         this.subflowCode = subflowCode;
     }
 
-    public Instance(int id, String name, long code, String type, String state, Date startTime, Date endTime, String host, String duration) {
+    public Instance(int id, String name, long code, String type, String state, Date startTime, Date endTime,
+                    String host, String duration) {
         this(id, name, code, type, state, startTime, endTime, host, duration, 0);
     }
-
-    public int getId() {
-        return id;
-    }
-
-    public void setId(int id) {
-        this.id = id;
-    }
-
-    public String getName() {
-        return name;
-    }
-
-    public void setName(String name) {
-        this.name = name;
-    }
-
-    public long getCode() {
-        return code;
-    }
-
-    public void setCode(long code) {
-        this.code = code;
-    }
-
-    public String getType() {
-        return type;
-    }
-
-    public void setType(String type) {
-        this.type = type;
-    }
-
-    public String getState() {
-        return state;
-    }
-
-    public void setState(String state) {
-        this.state = state;
-    }
-
-    public Date getStartTime() {
-        return startTime;
-    }
-
-    public void setStartTime(Date startTime) {
-        this.startTime = startTime;
-    }
-
-    public Date getEndTime() {
-        return endTime;
-    }
-
-    public void setEndTime(Date endTime) {
-        this.endTime = endTime;
-    }
-
-    public String getHost() {
-        return host;
-    }
-
-    public void setHost(String host) {
-        this.host = host;
-    }
-
-    public String getDuration() {
-        return duration;
-    }
-
-    public void setDuration(String duration) {
-        this.duration = duration;
-    }
-
-    public long getSubflowCode() {
-        return subflowCode;
-    }
-
-    public void setSubflowCode(long subflowCode) {
-        this.subflowCode = subflowCode;
-    }
 }
