@@ -14,6 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package org.apache.dolphinscheduler.api.enums;
 
 /**
@@ -21,7 +22,6 @@ package org.apache.dolphinscheduler.api.enums;
  */
 public enum ExecuteType {
 
-
     /**
      * operation type
      * 1 repeat running
@@ -30,15 +30,43 @@ public enum ExecuteType {
      * 4 stop
      * 5 pause
      */
-    NONE, REPEAT_RUNNING, RECOVER_SUSPENDED_PROCESS, START_FAILURE_TASK_PROCESS, STOP, PAUSE;
+    NONE(0, "NONE"),
 
+    // ******************************* Workflow ***************************
+    REPEAT_RUNNING(1, "REPEAT_RUNNING"),
+    RECOVER_SUSPENDED_PROCESS(2, "RECOVER_SUSPENDED_PROCESS"),
+    START_FAILURE_TASK_PROCESS(3, "START_FAILURE_TASK_PROCESS"),
+    STOP(4, "STOP"),
+    PAUSE(5, "PAUSE"),
+    // ******************************* Workflow ***************************
 
-    public static ExecuteType getEnum(int value){
-        for (ExecuteType e: ExecuteType.values()) {
-            if(e.ordinal() == value) {
+    // ******************************* Task *******************************
+    EXECUTE_TASK(6, "EXECUTE_TASK"),
+    // ******************************* Task *******************************
+    ;
+
+    private final int code;
+    private final String desc;
+
+    ExecuteType(int code, String desc) {
+        this.code = code;
+        this.desc = desc;
+    }
+
+    public int getCode() {
+        return code;
+    }
+
+    public String getDesc() {
+        return desc;
+    }
+
+    public static ExecuteType getEnum(int value) {
+        for (ExecuteType e : ExecuteType.values()) {
+            if (e.getCode() == value) {
                 return e;
             }
         }
-        return null;
+        return NONE;
     }
 }
