@@ -20,33 +20,33 @@ package org.apache.dolphinscheduler.api.python;
 import org.apache.dolphinscheduler.api.configuration.ApiConfig;
 import org.apache.dolphinscheduler.api.dto.EnvironmentDto;
 import org.apache.dolphinscheduler.api.dto.resources.ResourceComponent;
+import org.apache.dolphinscheduler.api.dto.workflow.WorkflowTriggerRequest;
 import org.apache.dolphinscheduler.api.enums.Status;
 import org.apache.dolphinscheduler.api.exceptions.ServiceException;
 import org.apache.dolphinscheduler.api.service.EnvironmentService;
 import org.apache.dolphinscheduler.api.service.ExecutorService;
-import org.apache.dolphinscheduler.api.service.ProcessDefinitionService;
 import org.apache.dolphinscheduler.api.service.ProjectService;
 import org.apache.dolphinscheduler.api.service.ResourcesService;
 import org.apache.dolphinscheduler.api.service.SchedulerService;
 import org.apache.dolphinscheduler.api.service.TaskDefinitionService;
 import org.apache.dolphinscheduler.api.service.TenantService;
 import org.apache.dolphinscheduler.api.service.UsersService;
-import org.apache.dolphinscheduler.api.utils.Result;
+import org.apache.dolphinscheduler.api.service.WorkflowDefinitionService;
 import org.apache.dolphinscheduler.common.constants.Constants;
+import org.apache.dolphinscheduler.common.enums.CommandType;
 import org.apache.dolphinscheduler.common.enums.ComplementDependentMode;
 import org.apache.dolphinscheduler.common.enums.ExecutionOrder;
 import org.apache.dolphinscheduler.common.enums.FailureStrategy;
+import org.apache.dolphinscheduler.common.enums.Flag;
 import org.apache.dolphinscheduler.common.enums.Priority;
-import org.apache.dolphinscheduler.common.enums.ProcessExecutionTypeEnum;
-import org.apache.dolphinscheduler.common.enums.ProgramType;
 import org.apache.dolphinscheduler.common.enums.ReleaseState;
 import org.apache.dolphinscheduler.common.enums.RunMode;
 import org.apache.dolphinscheduler.common.enums.TaskDependType;
 import org.apache.dolphinscheduler.common.enums.UserType;
 import org.apache.dolphinscheduler.common.enums.WarningType;
+import org.apache.dolphinscheduler.common.enums.WorkflowExecutionTypeEnum;
 import org.apache.dolphinscheduler.common.utils.CodeGenerateUtils;
 import org.apache.dolphinscheduler.dao.entity.DataSource;
-import org.apache.dolphinscheduler.dao.entity.ProcessDefinition;
 import org.apache.dolphinscheduler.dao.entity.Project;
 import org.apache.dolphinscheduler.dao.entity.ProjectUser;
 import org.apache.dolphinscheduler.dao.entity.Queue;
@@ -54,12 +54,13 @@ import org.apache.dolphinscheduler.dao.entity.Schedule;
 import org.apache.dolphinscheduler.dao.entity.TaskDefinition;
 import org.apache.dolphinscheduler.dao.entity.Tenant;
 import org.apache.dolphinscheduler.dao.entity.User;
+import org.apache.dolphinscheduler.dao.entity.WorkflowDefinition;
 import org.apache.dolphinscheduler.dao.mapper.DataSourceMapper;
-import org.apache.dolphinscheduler.dao.mapper.ProcessDefinitionMapper;
 import org.apache.dolphinscheduler.dao.mapper.ProjectMapper;
 import org.apache.dolphinscheduler.dao.mapper.ProjectUserMapper;
 import org.apache.dolphinscheduler.dao.mapper.ScheduleMapper;
 import org.apache.dolphinscheduler.dao.mapper.TaskDefinitionMapper;
+import org.apache.dolphinscheduler.dao.mapper.WorkflowDefinitionMapper;
 import org.apache.dolphinscheduler.plugin.storage.api.StorageEntity;
 import org.apache.dolphinscheduler.spi.enums.ResourceType;
 
@@ -97,13 +98,12 @@ public class PythonGateway {
     private static final RunMode DEFAULT_RUN_MODE = RunMode.RUN_MODE_SERIAL;
     private static final ExecutionOrder DEFAULT_EXECUTION_ORDER = ExecutionOrder.DESC_ORDER;
     private static final int DEFAULT_DRY_RUN = 0;
-    private static final int DEFAULT_TEST_FLAG = 0;
     private static final ComplementDependentMode COMPLEMENT_DEPENDENT_MODE = ComplementDependentMode.OFF_MODE;
     // We use admin user's user_id to skip some permission issue from python gateway service
     private static final int ADMIN_USER_ID = 1;
 
     @Autowired
-    private ProcessDefinitionMapper processDefinitionMapper;
+    private WorkflowDefinitionMapper workflowDefinitionMapper;
 
     @Autowired
     private ProjectService projectService;
@@ -118,7 +118,7 @@ public class PythonGateway {
     private ExecutorService executorService;
 
     @Autowired
-    private ProcessDefinitionService processDefinitionService;
+    private WorkflowDefinitionService workflowDefinitionService;
 
     @Autowired
     private TaskDefinitionService taskDefinitionService;
@@ -178,31 +178,31 @@ public class PythonGateway {
         return taskDefinitionService.genTaskCodeList(genNum);
     }
 
-    public Map<String, Long> getCodeAndVersion(String projectName, String processDefinitionName,
-                                               String taskName) throws CodeGenerateUtils.CodeGenerateException {
+    public Map<String, Long> getCodeAndVersion(String projectName, String workflowDefinitionName,
+                                               String taskName) {
         Project project = projectMapper.queryByName(projectName);
         Map<String, Long> result = new HashMap<>();
         // project do not exists, mean task not exists too, so we should directly return init value
         if (project == null) {
-            result.put("code", CodeGenerateUtils.getInstance().genCode());
+            result.put("code", CodeGenerateUtils.genCode());
             result.put("version", 0L);
             return result;
         }
 
-        ProcessDefinition processDefinition =
-                processDefinitionMapper.queryByDefineName(project.getCode(), processDefinitionName);
+        WorkflowDefinition workflowDefinition =
+                workflowDefinitionMapper.queryByDefineName(project.getCode(), workflowDefinitionName);
         // In the case project exists, but current workflow still not created, we should also return the init
         // version of it
-        if (processDefinition == null) {
-            result.put("code", CodeGenerateUtils.getInstance().genCode());
+        if (workflowDefinition == null) {
+            result.put("code", CodeGenerateUtils.genCode());
             result.put("version", 0L);
             return result;
         }
 
         TaskDefinition taskDefinition =
-                taskDefinitionMapper.queryByName(project.getCode(), processDefinition.getCode(), taskName);
+                taskDefinitionMapper.queryByName(project.getCode(), workflowDefinition.getCode(), taskName);
         if (taskDefinition == null) {
-            result.put("code", CodeGenerateUtils.getInstance().genCode());
+            result.put("code", CodeGenerateUtils.genCode());
             result.put("version", 0L);
         } else {
             result.put("code", taskDefinition.getCode());
@@ -216,22 +216,22 @@ public class PythonGateway {
      * If workflow do not exists in Project=`projectCode` would create a new one
      * If workflow already exists in Project=`projectCode` would update it
      *
-     * @param userName user name who create or update workflow
-     * @param projectName project name which workflow belongs to
-     * @param name workflow name
-     * @param description description
-     * @param globalParams global params
-     * @param schedule schedule for workflow, will not set schedule if null,
-     * and if would always fresh exists schedule if not null
-     * @param onlineSchedule Whether set the workflow's schedule to online state
-     * @param warningType warning type
-     * @param warningGroupId warning group id
-     * @param timeout timeout for workflow working, if running time longer than timeout,
-     * task will mark as fail
-     * @param workerGroup run task in which worker group
-     * @param taskRelationJson relation json for nodes
+     * @param userName           user name who create or update workflow
+     * @param projectName        project name which workflow belongs to
+     * @param name               workflow name
+     * @param description        description
+     * @param globalParams       global params
+     * @param schedule           schedule for workflow, will not set schedule if null,
+     *                           and if would always fresh exists schedule if not null
+     * @param onlineSchedule     Whether set the workflow's schedule to online state
+     * @param warningType        warning type
+     * @param warningGroupId     warning group id
+     * @param timeout            timeout for workflow working, if running time longer than timeout,
+     *                           task will mark as fail
+     * @param workerGroup        run task in which worker group
+     * @param taskRelationJson   relation json for nodes
      * @param taskDefinitionJson taskDefinitionJson
-     * @param otherParamsJson otherParamsJson handle other params
+     * @param otherParamsJson    otherParamsJson handle other params
      * @return create result code
      */
     public Long createOrUpdateWorkflow(String userName,
@@ -258,21 +258,20 @@ public class PythonGateway {
         Project project = projectMapper.queryByName(projectName);
         long projectCode = project.getCode();
 
-        ProcessDefinition processDefinition = getWorkflow(user, projectCode, name);
-        ProcessExecutionTypeEnum executionTypeEnum = ProcessExecutionTypeEnum.valueOf(executionType);
-        long processDefinitionCode;
+        WorkflowDefinition workflowDefinition = getWorkflow(user, projectCode, name);
+        WorkflowExecutionTypeEnum executionTypeEnum = WorkflowExecutionTypeEnum.valueOf(executionType);
+        long workflowDefinitionCode;
         // create or update workflow
-        if (processDefinition != null) {
-            processDefinitionCode = processDefinition.getCode();
+        if (workflowDefinition != null) {
+            workflowDefinitionCode = workflowDefinition.getCode();
             // make sure workflow offline which could edit
-            processDefinitionService.releaseProcessDefinition(user, projectCode, processDefinitionCode,
-                    ReleaseState.OFFLINE);
-            processDefinitionService.updateProcessDefinition(user, projectCode, name,
-                    processDefinitionCode, description, globalParams,
-                    null, timeout, taskRelationJson, taskDefinitionJson, otherParamsJson,
+            workflowDefinitionService.offlineWorkflowDefinition(user, projectCode, workflowDefinitionCode);
+            workflowDefinitionService.updateWorkflowDefinition(user, projectCode, name,
+                    workflowDefinitionCode, description, globalParams,
+                    null, timeout, taskRelationJson, taskDefinitionJson,
                     executionTypeEnum);
         } else {
-            Map<String, Object> result = processDefinitionService.createProcessDefinition(user, projectCode, name,
+            Map<String, Object> result = workflowDefinitionService.createWorkflowDefinition(user, projectCode, name,
                     description, globalParams,
                     null, timeout, taskRelationJson, taskDefinitionJson, otherParamsJson,
                     executionTypeEnum);
@@ -280,36 +279,39 @@ public class PythonGateway {
                 log.error(result.get(Constants.MSG).toString());
                 throw new ServiceException(result.get(Constants.MSG).toString());
             }
-            processDefinition = (ProcessDefinition) result.get(Constants.DATA_LIST);
-            processDefinitionCode = processDefinition.getCode();
+            workflowDefinition = (WorkflowDefinition) result.get(Constants.DATA_LIST);
+            workflowDefinitionCode = workflowDefinition.getCode();
         }
 
         // Fresh workflow schedule
         if (schedule != null) {
-            createOrUpdateSchedule(user, projectCode, processDefinitionCode, schedule, onlineSchedule, workerGroup,
+            createOrUpdateSchedule(user, projectCode, workflowDefinitionCode, schedule, onlineSchedule, workerGroup,
                     warningType,
                     warningGroupId);
         }
-        processDefinitionService.releaseProcessDefinition(user, projectCode, processDefinitionCode,
-                ReleaseState.getEnum(releaseState));
-        return processDefinitionCode;
+        if (ReleaseState.ONLINE.equals(ReleaseState.getEnum(releaseState))) {
+            workflowDefinitionService.onlineWorkflowDefinition(user, projectCode, workflowDefinitionCode);
+        } else if (ReleaseState.OFFLINE.equals(ReleaseState.getEnum(releaseState))) {
+            workflowDefinitionService.offlineWorkflowDefinition(user, projectCode, workflowDefinitionCode);
+        }
+        return workflowDefinitionCode;
     }
 
     /**
      * get workflow
      *
-     * @param user user who create or update schedule
-     * @param projectCode project which workflow belongs to
+     * @param user         user who create or update schedule
+     * @param projectCode  project which workflow belongs to
      * @param workflowName workflow name
      */
-    private ProcessDefinition getWorkflow(User user, long projectCode, String workflowName) {
-        Map<String, Object> verifyProcessDefinitionExists =
-                processDefinitionService.verifyProcessDefinitionName(user, projectCode, workflowName, 0);
-        Status verifyStatus = (Status) verifyProcessDefinitionExists.get(Constants.STATUS);
+    private WorkflowDefinition getWorkflow(User user, long projectCode, String workflowName) {
+        Map<String, Object> verifyWorkflowDefinitionExists =
+                workflowDefinitionService.verifyWorkflowDefinitionName(user, projectCode, workflowName, 0);
+        Status verifyStatus = (Status) verifyWorkflowDefinitionExists.get(Constants.STATUS);
 
-        ProcessDefinition processDefinition = null;
-        if (verifyStatus == Status.PROCESS_DEFINITION_NAME_EXIST) {
-            processDefinition = processDefinitionMapper.queryByDefineName(projectCode, workflowName);
+        WorkflowDefinition workflowDefinition = null;
+        if (verifyStatus == Status.WORKFLOW_DEFINITION_NAME_EXIST) {
+            workflowDefinition = workflowDefinitionMapper.queryByDefineName(projectCode, workflowName);
         } else if (verifyStatus != Status.SUCCESS) {
             String msg =
                     "Verify workflow exists status is invalid, neither SUCCESS or WORKFLOW_NAME_EXIST.";
@@ -317,7 +319,7 @@ public class PythonGateway {
             throw new RuntimeException(msg);
         }
 
-        return processDefinition;
+        return workflowDefinition;
     }
 
     /**
@@ -325,13 +327,13 @@ public class PythonGateway {
      * It would always use latest schedule define in workflow-as-code, and set schedule online when
      * it's not null
      *
-     * @param user user who create or update schedule
-     * @param projectCode project which workflow belongs to
-     * @param workflowCode workflow code
-     * @param schedule schedule expression
+     * @param user           user who create or update schedule
+     * @param projectCode    project which workflow belongs to
+     * @param workflowCode   workflow code
+     * @param schedule       schedule expression
      * @param onlineSchedule Whether set the workflow's schedule to online state
-     * @param workerGroup work group
-     * @param warningType warning type
+     * @param workerGroup    work group
+     * @param warningType    warning type
      * @param warningGroupId warning group id
      */
     private void createOrUpdateSchedule(User user,
@@ -342,12 +344,11 @@ public class PythonGateway {
                                         String workerGroup,
                                         String warningType,
                                         int warningGroupId) {
-        Schedule scheduleObj = scheduleMapper.queryByProcessDefinitionCode(workflowCode);
+        Schedule scheduleObj = scheduleMapper.queryByWorkflowDefinitionCode(workflowCode);
         // create or update schedule
         int scheduleId;
         if (scheduleObj == null) {
-            processDefinitionService.releaseProcessDefinition(user, projectCode, workflowCode,
-                    ReleaseState.ONLINE);
+            workflowDefinitionService.onlineWorkflowDefinition(user, projectCode, workflowCode);
             Map<String, Object> result = schedulerService.insertSchedule(user, projectCode, workflowCode,
                     schedule, WarningType.valueOf(warningType),
                     warningGroupId, DEFAULT_FAILURE_STRATEGY, DEFAULT_PRIORITY, workerGroup, user.getTenantCode(),
@@ -355,60 +356,43 @@ public class PythonGateway {
             scheduleId = (int) result.get("scheduleId");
         } else {
             scheduleId = scheduleObj.getId();
-            processDefinitionService.releaseProcessDefinition(user, projectCode, workflowCode,
-                    ReleaseState.OFFLINE);
+            workflowDefinitionService.offlineWorkflowDefinition(user, projectCode, workflowCode);
             schedulerService.updateSchedule(user, projectCode, scheduleId, schedule, WarningType.valueOf(warningType),
                     warningGroupId, DEFAULT_FAILURE_STRATEGY, DEFAULT_PRIORITY, workerGroup, user.getTenantCode(),
                     DEFAULT_ENVIRONMENT_CODE);
         }
         if (onlineSchedule) {
             // set workflow online to make sure we can set schedule online
-            processDefinitionService.releaseProcessDefinition(user, projectCode, workflowCode, ReleaseState.ONLINE);
-            schedulerService.setScheduleState(user, projectCode, scheduleId, ReleaseState.ONLINE);
+            workflowDefinitionService.onlineWorkflowDefinition(user, projectCode, workflowCode);
+            schedulerService.onlineScheduler(user, projectCode, scheduleId);
         }
     }
 
     public void execWorkflowInstance(String userName,
                                      String projectName,
                                      String workflowName,
-                                     String cronTime,
                                      String workerGroup,
                                      String warningType,
-                                     Integer warningGroupId,
-                                     Integer timeout) {
+                                     Integer warningGroupId) {
         User user = usersService.queryUser(userName);
         Project project = projectMapper.queryByName(projectName);
-        ProcessDefinition processDefinition =
-                processDefinitionMapper.queryByDefineName(project.getCode(), workflowName);
+        WorkflowDefinition workflowDefinition =
+                workflowDefinitionMapper.queryByDefineName(project.getCode(), workflowName);
 
         // make sure workflow online
-        processDefinitionService.releaseProcessDefinition(user, project.getCode(), processDefinition.getCode(),
-                ReleaseState.ONLINE);
+        workflowDefinitionService.onlineWorkflowDefinition(user, project.getCode(), workflowDefinition.getCode());
 
-        executorService.execProcessInstance(user,
-                project.getCode(),
-                processDefinition.getCode(),
-                cronTime,
-                null,
-                DEFAULT_FAILURE_STRATEGY,
-                null,
-                DEFAULT_TASK_DEPEND_TYPE,
-                WarningType.valueOf(warningType),
-                warningGroupId,
-                DEFAULT_RUN_MODE,
-                DEFAULT_PRIORITY,
-                workerGroup,
-                user.getTenantCode(),
-                DEFAULT_ENVIRONMENT_CODE,
-                timeout,
-                null,
-                null,
-                DEFAULT_DRY_RUN,
-                DEFAULT_TEST_FLAG,
-                COMPLEMENT_DEPENDENT_MODE,
-                processDefinition.getVersion(),
-                false,
-                DEFAULT_EXECUTION_ORDER);
+        WorkflowTriggerRequest workflowTriggerRequest = WorkflowTriggerRequest.builder()
+                .loginUser(user)
+                .workflowDefinitionCode(workflowDefinition.getCode())
+                .workerGroup(workerGroup)
+                .warningType(WarningType.of(warningType))
+                .warningGroupId(warningGroupId)
+                .execType(CommandType.START_PROCESS)
+                .taskDependType(TaskDependType.TASK_POST)
+                .dryRun(Flag.NO)
+                .build();
+        executorService.triggerWorkflowDefinition(workflowTriggerRequest);
     }
 
     // side object
@@ -453,7 +437,7 @@ public class PythonGateway {
 
     public void updateProject(String userName, Long projectCode, String projectName, String desc) {
         User user = usersService.queryUser(userName);
-        projectService.update(user, projectCode, projectName, desc, userName);
+        projectService.update(user, projectCode, projectName, desc);
     }
 
     public void deleteProject(String userName, Long projectCode) {
@@ -513,7 +497,7 @@ public class PythonGateway {
      * it will return the datasource match the type.
      *
      * @param datasourceName datasource name of datasource
-     * @param type datasource type
+     * @param type           datasource type
      */
     public DataSource getDatasource(String datasourceName, String type) {
 
@@ -544,10 +528,10 @@ public class PythonGateway {
 
     /**
      * Get workflow object by given workflow name. It returns map contain workflow id, name, code.
-     * Useful in Python API create subProcess task which need workflow information.
+     * Useful in Python API create sub workflow task which need workflow information.
      *
-     * @param userName user who create or update schedule
-     * @param projectName project name which workflow belongs to
+     * @param userName     user who create or update schedule
+     * @param projectName  project name which workflow belongs to
      * @param workflowName workflow name
      */
     public Map<String, Object> getWorkflowInfo(String userName, String projectName,
@@ -557,15 +541,14 @@ public class PythonGateway {
         User user = usersService.queryUser(userName);
         Project project = (Project) projectService.queryByName(user, projectName).get(Constants.DATA_LIST);
         long projectCode = project.getCode();
-        ProcessDefinition processDefinition = getWorkflow(user, projectCode, workflowName);
+        WorkflowDefinition workflowDefinition = getWorkflow(user, projectCode, workflowName);
         // get workflow info
-        if (processDefinition != null) {
+        if (workflowDefinition != null) {
             // make sure workflow online
-            processDefinitionService.releaseProcessDefinition(user, projectCode, processDefinition.getCode(),
-                    ReleaseState.ONLINE);
-            result.put("id", processDefinition.getId());
-            result.put("name", processDefinition.getName());
-            result.put("code", processDefinition.getCode());
+            workflowDefinitionService.onlineWorkflowDefinition(user, projectCode, workflowDefinition.getCode());
+            result.put("id", workflowDefinition.getId());
+            result.put("name", workflowDefinition.getName());
+            result.put("code", workflowDefinition.getCode());
         } else {
             String msg = String.format("Can not find valid workflow by name %s", workflowName);
             log.error(msg);
@@ -579,9 +562,9 @@ public class PythonGateway {
      * Get project, workflow, task code.
      * Useful in Python API create dependent task which need workflow information.
      *
-     * @param projectName project name which workflow belongs to
+     * @param projectName  project name which workflow belongs to
      * @param workflowName workflow name
-     * @param taskName task name
+     * @param taskName     task name
      */
     public Map<String, Object> getDependentInfo(String projectName, String workflowName, String taskName) {
         Map<String, Object> result = new HashMap<>();
@@ -595,18 +578,18 @@ public class PythonGateway {
         long projectCode = project.getCode();
         result.put("projectCode", projectCode);
 
-        ProcessDefinition processDefinition =
-                processDefinitionMapper.queryByDefineName(projectCode, workflowName);
-        if (processDefinition == null) {
+        WorkflowDefinition workflowDefinition =
+                workflowDefinitionMapper.queryByDefineName(projectCode, workflowName);
+        if (workflowDefinition == null) {
             String msg = String.format("Can not find valid workflow by name %s", workflowName);
             log.error(msg);
             throw new IllegalArgumentException(msg);
         }
-        result.put("processDefinitionCode", processDefinition.getCode());
+        result.put("workflowDefinitionCode", workflowDefinition.getCode());
 
         if (taskName != null) {
             TaskDefinition taskDefinition =
-                    taskDefinitionMapper.queryByName(projectCode, processDefinition.getCode(), taskName);
+                    taskDefinitionMapper.queryByName(projectCode, workflowDefinition.getCode(), taskName);
             result.put("taskDefinitionCode", taskDefinition.getCode());
         }
         return result;
@@ -616,25 +599,22 @@ public class PythonGateway {
      * Get resource by given program type and full name. It returns map contain resource id, name.
      * Useful in Python API create flink or spark task which need workflow information.
      *
-     * @param programType program type one of SCALA, JAVA and PYTHON
-     * @param fullName full name of the resource
+     * @param fullName    full name of the resource
      */
-    public Map<String, Object> getResourcesFileInfo(String programType, String fullName) {
+    public Map<String, Object> getResourcesFileInfo(String fullName) {
         Map<String, Object> result = new HashMap<>();
 
-        Result<Object> resources = resourceService.queryResourceByProgramType(dummyAdminUser, ResourceType.FILE,
-                ProgramType.valueOf(programType));
-        List<ResourceComponent> resourcesComponent = (List<ResourceComponent>) resources.getData();
-        List<ResourceComponent> namedResources =
-                resourcesComponent.stream().filter(s -> fullName.equals(s.getFullName())).collect(Collectors.toList());
+        List<ResourceComponent> resourceComponents =
+                resourceService.queryResourceFiles(dummyAdminUser, ResourceType.FILE);
+        List<ResourceComponent> namedResources = resourceComponents.stream()
+                .filter(s -> fullName.equals(s.getFullName()))
+                .collect(Collectors.toList());
         if (CollectionUtils.isEmpty(namedResources)) {
-            String msg =
-                    String.format("Can not find valid resource by program type %s and name %s", programType, fullName);
+            String msg = String.format("Can not find valid resource by name %s", fullName);
             log.error(msg);
             throw new IllegalArgumentException(msg);
         }
 
-        result.put("id", namedResources.get(0).getId());
         result.put("name", namedResources.get(0).getName());
         return result;
     }
@@ -673,20 +653,6 @@ public class PythonGateway {
         return PythonGateway.class.getPackage().getImplementationVersion();
     }
 
-    /**
-     * create or update resource.
-     * If the folder is not already created, it will be
-     *
-     * @param userName user who create or update resource
-     * @param fullName The fullname of resource.Includes path and suffix.
-     * @param resourceContent content of resource
-     * @return StorageEntity object which contains necessary information about resource
-     */
-    public StorageEntity createOrUpdateResource(String userName, String fullName,
-                                                String resourceContent) throws Exception {
-        return resourceService.createOrUpdateResource(userName, fullName, resourceContent);
-    }
-
     @PostConstruct
     public void init() {
         if (apiConfig.getPythonGateway().isEnabled()) {
