@@ -26,7 +26,7 @@ public enum AuthenticationType {
 
     PASSWORD(0, "verify via user name and password"),
     LDAP(1, "verify via LDAP server"),
-    ;
+    CASDOOR_SSO(2, "verify via casdoor sso provider");
 
     AuthenticationType(int code, String desc) {
         this.code = code;
