@@ -17,18 +17,18 @@
 
 package org.apache.dolphinscheduler.api.service.impl;
 
-import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.ALART_INSTANCE_CREATE;
+import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.ALERT_INSTANCE_CREATE;
 import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.ALERT_PLUGIN_DELETE;
 import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.ALERT_PLUGIN_UPDATE;
 
 import org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant;
 import org.apache.dolphinscheduler.api.enums.Status;
+import org.apache.dolphinscheduler.api.exceptions.ServiceException;
 import org.apache.dolphinscheduler.api.service.AlertPluginInstanceService;
 import org.apache.dolphinscheduler.api.utils.PageInfo;
-import org.apache.dolphinscheduler.api.utils.Result;
 import org.apache.dolphinscheduler.api.vo.AlertPluginInstanceVO;
-import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.AuthorizationType;
+import org.apache.dolphinscheduler.common.model.Server;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.dao.entity.AlertPluginInstance;
 import org.apache.dolphinscheduler.dao.entity.PluginDefine;
@@ -36,6 +36,13 @@ import org.apache.dolphinscheduler.dao.entity.User;
 import org.apache.dolphinscheduler.dao.mapper.AlertGroupMapper;
 import org.apache.dolphinscheduler.dao.mapper.AlertPluginInstanceMapper;
 import org.apache.dolphinscheduler.dao.mapper.PluginDefineMapper;
+import org.apache.dolphinscheduler.extract.alert.IAlertOperator;
+import org.apache.dolphinscheduler.extract.alert.request.AlertSendResponse;
+import org.apache.dolphinscheduler.extract.alert.request.AlertTestSendRequest;
+import org.apache.dolphinscheduler.extract.base.client.Clients;
+import org.apache.dolphinscheduler.extract.base.utils.Host;
+import org.apache.dolphinscheduler.registry.api.RegistryClient;
+import org.apache.dolphinscheduler.registry.api.enums.RegistryNodeType;
 import org.apache.dolphinscheduler.spi.params.PluginParamsTransfer;
 
 import org.apache.commons.collections4.CollectionUtils;
@@ -43,7 +50,6 @@ import org.apache.commons.collections4.CollectionUtils;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Date;
-import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
@@ -55,6 +61,7 @@ import lombok.extern.slf4j.Slf4j;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.context.annotation.Lazy;
 import org.springframework.stereotype.Service;
+import org.springframework.transaction.annotation.Transactional;
 
 import com.baomidou.mybatisplus.core.metadata.IPage;
 import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
@@ -76,112 +83,96 @@ public class AlertPluginInstanceServiceImpl extends BaseServiceImpl implements A
     @Autowired
     private AlertGroupMapper alertGroupMapper;
 
+    @Autowired
+    private RegistryClient registryClient;
+
     /**
      * creat alert plugin instance
      *
-     * @param loginUser login user
-     * @param pluginDefineId plugin define id
-     * @param instanceName instance name
+     * @param loginUser            login user
+     * @param pluginDefineId       plugin define id
+     * @param instanceName         instance name
      * @param pluginInstanceParams plugin instance params
      */
     @Override
-    public Map<String, Object> create(User loginUser, int pluginDefineId, String instanceName,
+    public AlertPluginInstance create(User loginUser,
+                                      int pluginDefineId,
+                                      String instanceName,
                                       String pluginInstanceParams) {
+
+        if (!canOperatorPermissions(loginUser, null, AuthorizationType.ALERT_PLUGIN_INSTANCE, ALERT_INSTANCE_CREATE)) {
+            throw new ServiceException(Status.USER_NO_OPERATION_PERM);
+        }
+
         AlertPluginInstance alertPluginInstance = new AlertPluginInstance();
         String paramsMapJson = parsePluginParamsMap(pluginInstanceParams);
         alertPluginInstance.setPluginInstanceParams(paramsMapJson);
         alertPluginInstance.setInstanceName(instanceName);
         alertPluginInstance.setPluginDefineId(pluginDefineId);
 
-        Map<String, Object> result = new HashMap<>();
-        if (!canOperatorPermissions(loginUser, null, AuthorizationType.ALERT_PLUGIN_INSTANCE, ALART_INSTANCE_CREATE)) {
-            putMsg(result, Status.USER_NO_OPERATION_PERM);
-            return result;
-        }
         if (alertPluginInstanceMapper.existInstanceName(alertPluginInstance.getInstanceName()) == Boolean.TRUE) {
-            log.error("Plugin instance with the same name already exists, name:{}.",
-                    alertPluginInstance.getInstanceName());
-            putMsg(result, Status.PLUGIN_INSTANCE_ALREADY_EXISTS);
-            return result;
+            throw new ServiceException(Status.PLUGIN_INSTANCE_ALREADY_EXISTS);
         }
 
         int i = alertPluginInstanceMapper.insert(alertPluginInstance);
         if (i > 0) {
             log.info("Create alert plugin instance complete, name:{}", alertPluginInstance.getInstanceName());
-            result.put(Constants.DATA_LIST, alertPluginInstance);
-            putMsg(result, Status.SUCCESS);
-            return result;
+            return alertPluginInstance;
         }
-        log.error("Create alert plugin instance error, name:{}", alertPluginInstance.getInstanceName());
-        putMsg(result, Status.SAVE_ERROR);
-        return result;
+        throw new ServiceException(Status.SAVE_ERROR);
     }
 
     /**
      * update alert plugin instance
      *
-     * @param loginUser login user
-     * @param pluginInstanceId plugin instance id
-     * @param instanceName instance name
+     * @param loginUser            login user
+     * @param pluginInstanceId     plugin instance id
+     * @param instanceName         instance name
      * @param pluginInstanceParams plugin instance params
      */
     @Override
-    public Map<String, Object> update(User loginUser, int pluginInstanceId, String instanceName,
-                                      String pluginInstanceParams) {
+    public AlertPluginInstance updateById(User loginUser, int pluginInstanceId, String instanceName,
+                                          String pluginInstanceParams) {
+
+        if (!canOperatorPermissions(loginUser, null, AuthorizationType.ALERT_PLUGIN_INSTANCE, ALERT_PLUGIN_UPDATE)) {
+            throw new ServiceException(Status.USER_NO_OPERATION_PERM);
+        }
 
         String paramsMapJson = parsePluginParamsMap(pluginInstanceParams);
         AlertPluginInstance alertPluginInstance =
                 new AlertPluginInstance(pluginInstanceId, paramsMapJson, instanceName, new Date());
 
-        Map<String, Object> result = new HashMap<>();
-
-        if (!canOperatorPermissions(loginUser, null, AuthorizationType.ALERT_PLUGIN_INSTANCE, ALERT_PLUGIN_UPDATE)) {
-            putMsg(result, Status.USER_NO_OPERATION_PERM);
-            return result;
-        }
         int i = alertPluginInstanceMapper.updateById(alertPluginInstance);
 
         if (i > 0) {
             log.info("Update alert plugin instance complete, instanceId:{}, name:{}", alertPluginInstance.getId(),
                     alertPluginInstance.getInstanceName());
-            putMsg(result, Status.SUCCESS);
-            return result;
+            return alertPluginInstance;
         }
-        log.error("Update alert plugin instance error, instanceId:{}, name:{}", alertPluginInstance.getId(),
-                alertPluginInstance.getInstanceName());
-        putMsg(result, Status.SAVE_ERROR);
-        return result;
+        throw new ServiceException(Status.SAVE_ERROR);
     }
 
     /**
      * delete alert plugin instance
      *
-     * @param loginUser login user
-     * @param id id
+     * @param loginUser             login user
+     * @param alertPluginInstanceId id
      * @return result
      */
     @Override
-    public Map<String, Object> delete(User loginUser, int id) {
-        Map<String, Object> result = new HashMap<>();
-        // check if there is an associated alert group
-        boolean hasAssociatedAlertGroup = checkHasAssociatedAlertGroup(String.valueOf(id));
-        if (hasAssociatedAlertGroup) {
-            log.warn("Delete alert plugin failed because alert group is using it, pluginId:{}.", id);
-            putMsg(result, Status.DELETE_ALERT_PLUGIN_INSTANCE_ERROR_HAS_ALERT_GROUP_ASSOCIATED);
-            return result;
-        }
+    @Transactional
+    public void deleteById(User loginUser, int alertPluginInstanceId) {
         if (!canOperatorPermissions(loginUser, null, AuthorizationType.ALERT_PLUGIN_INSTANCE, ALERT_PLUGIN_DELETE)) {
-            putMsg(result, Status.USER_NO_OPERATION_PERM);
-            return result;
+            throw new ServiceException(Status.USER_NO_OPERATION_PERM);
         }
 
-        int i = alertPluginInstanceMapper.deleteById(id);
-        if (i > 0) {
-            log.info("Delete alert plugin instance complete, instanceId:{}", id);
-            putMsg(result, Status.SUCCESS);
+        // check if there is an associated alert group
+        boolean hasAssociatedAlertGroup = checkHasAssociatedAlertGroup(String.valueOf(alertPluginInstanceId));
+        if (hasAssociatedAlertGroup) {
+            throw new ServiceException(Status.DELETE_ALERT_PLUGIN_INSTANCE_ERROR_HAS_ALERT_GROUP_ASSOCIATED);
         }
-        log.error("Delete alert plugin instance error, instanceId:{}", id);
-        return result;
+
+        alertPluginInstanceMapper.deleteById(alertPluginInstanceId);
     }
 
     /**
@@ -192,33 +183,18 @@ public class AlertPluginInstanceServiceImpl extends BaseServiceImpl implements A
      * @return alert plugin
      */
     @Override
-    public Map<String, Object> get(User loginUser, int id) {
-        Map<String, Object> result = new HashMap<>();
-        AlertPluginInstance alertPluginInstance = alertPluginInstanceMapper.selectById(id);
+    public AlertPluginInstance getById(User loginUser, int id) {
         if (!canOperatorPermissions(loginUser, null, AuthorizationType.ALERT_PLUGIN_INSTANCE,
                 ApiFuncIdentificationConstant.ALARM_INSTANCE_MANAGE)) {
-            putMsg(result, Status.USER_NO_OPERATION_PERM);
-            return result;
+            throw new ServiceException(Status.USER_NO_OPERATION_PERM);
         }
-
-        if (null != alertPluginInstance) {
-            putMsg(result, Status.SUCCESS);
-            result.put(Constants.DATA_LIST, alertPluginInstance);
-        }
-
-        return result;
+        return alertPluginInstanceMapper.selectById(id);
     }
 
     @Override
-    public Map<String, Object> queryAll() {
-        Map<String, Object> result = new HashMap<>();
+    public List<AlertPluginInstanceVO> queryAll() {
         List<AlertPluginInstance> alertPluginInstances = alertPluginInstanceMapper.queryAllAlertPluginInstanceList();
-        List<AlertPluginInstanceVO> alertPluginInstanceVOS = buildPluginInstanceVOList(alertPluginInstances);
-        if (null != alertPluginInstances) {
-            putMsg(result, Status.SUCCESS);
-            result.put(Constants.DATA_LIST, alertPluginInstanceVOS);
-        }
-        return result;
+        return buildPluginInstanceVOList(alertPluginInstances);
     }
 
     @Override
@@ -227,19 +203,15 @@ public class AlertPluginInstanceServiceImpl extends BaseServiceImpl implements A
     }
 
     @Override
-    public Result listPaging(User loginUser, String searchVal, int pageNo, int pageSize) {
+    public PageInfo<AlertPluginInstanceVO> listPaging(User loginUser, String searchVal, int pageNo, int pageSize) {
 
-        Result result = new Result();
-        Page<AlertPluginInstance> page = new Page<>(pageNo, pageSize);
         IPage<AlertPluginInstance> alertPluginInstanceIPage =
-                alertPluginInstanceMapper.queryByInstanceNamePage(page, searchVal);
+                alertPluginInstanceMapper.queryByInstanceNamePage(new Page<>(pageNo, pageSize), searchVal);
 
         PageInfo<AlertPluginInstanceVO> pageInfo = new PageInfo<>(pageNo, pageSize);
         pageInfo.setTotal((int) alertPluginInstanceIPage.getTotal());
         pageInfo.setTotalList(buildPluginInstanceVOList(alertPluginInstanceIPage.getRecords()));
-        result.setData(pageInfo);
-        putMsg(result, Status.SUCCESS);
-        return result;
+        return pageInfo;
     }
 
     private List<AlertPluginInstanceVO> buildPluginInstanceVOList(List<AlertPluginInstance> alertPluginInstances) {
@@ -255,7 +227,6 @@ public class AlertPluginInstanceServiceImpl extends BaseServiceImpl implements A
                 pluginDefineList.stream().collect(Collectors.toMap(PluginDefine::getId, Function.identity()));
         alertPluginInstances.forEach(alertPluginInstance -> {
             AlertPluginInstanceVO alertPluginInstanceVO = new AlertPluginInstanceVO();
-
             alertPluginInstanceVO.setCreateTime(alertPluginInstance.getCreateTime());
             alertPluginInstanceVO.setUpdateTime(alertPluginInstance.getUpdateTime());
             alertPluginInstanceVO.setPluginDefineId(alertPluginInstance.getPluginDefineId());
@@ -312,4 +283,43 @@ public class AlertPluginInstanceServiceImpl extends BaseServiceImpl implements A
         return first.isPresent();
     }
 
+    public Optional<Host> getAlertServerAddress() {
+        List<Server> serverList = registryClient.getServerList(RegistryNodeType.ALERT_SERVER);
+        if (CollectionUtils.isEmpty(serverList)) {
+            return Optional.empty();
+        }
+        Server server = serverList.get(0);
+        return Optional.of(new Host(server.getHost(), server.getPort()));
+    }
+
+    @Override
+    public void testSend(int pluginDefineId, String pluginInstanceParams) {
+        Optional<Host> alertServerAddressOptional = getAlertServerAddress();
+        if (!alertServerAddressOptional.isPresent()) {
+            throw new ServiceException(Status.ALERT_SERVER_NOT_EXIST);
+        }
+
+        Host alertServerAddress = alertServerAddressOptional.get();
+        AlertTestSendRequest alertTestSendRequest = new AlertTestSendRequest(
+                pluginDefineId,
+                pluginInstanceParams);
+
+        AlertSendResponse alertSendResponse;
+
+        try {
+            alertSendResponse = Clients
+                    .withService(IAlertOperator.class)
+                    .withHost(alertServerAddress.getAddress())
+                    .sendTestAlert(alertTestSendRequest);
+            log.info("Send alert to: {} successfully, response: {}", alertServerAddress, alertSendResponse);
+        } catch (Exception e) {
+            log.error("Send alert: {} to: {} failed", alertTestSendRequest, alertServerAddress, e);
+            throw new ServiceException(Status.ALERT_TEST_SENDING_FAILED, e.getMessage());
+        }
+
+        if (!alertSendResponse.isSuccess()) {
+            throw new ServiceException(Status.ALERT_TEST_SENDING_FAILED,
+                    alertSendResponse.getResResults().get(0).getMessage());
+        }
+    }
 }
