@@ -25,7 +25,6 @@ import org.apache.dolphinscheduler.api.enums.Status;
 import org.apache.dolphinscheduler.api.exceptions.ServiceException;
 import org.apache.dolphinscheduler.api.service.QueueService;
 import org.apache.dolphinscheduler.api.utils.PageInfo;
-import org.apache.dolphinscheduler.api.utils.Result;
 import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.AuthorizationType;
 import org.apache.dolphinscheduler.common.enums.UserType;
@@ -40,11 +39,8 @@ import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
 
 import java.util.ArrayList;
-import java.util.Collections;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
-import java.util.Map;
 import java.util.Objects;
 import java.util.Set;
 
@@ -52,7 +48,6 @@ import lombok.extern.slf4j.Slf4j;
 
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Service;
-import org.springframework.transaction.annotation.Transactional;
 
 import com.baomidou.mybatisplus.core.metadata.IPage;
 import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
@@ -78,7 +73,7 @@ public class QueueServiceImpl extends BaseServiceImpl implements QueueService {
      *
      * @param queue The queue object want to create
      */
-    private void createQueueValid(Queue queue) throws ServiceException {
+    private void validQueue(Queue queue) throws ServiceException {
         if (StringUtils.isEmpty(queue.getQueue())) {
             throw new ServiceException(Status.REQUEST_PARAMS_NOT_VALID_ERROR, Constants.QUEUE);
         } else if (StringUtils.isEmpty(queue.getQueueName())) {
@@ -125,96 +120,79 @@ public class QueueServiceImpl extends BaseServiceImpl implements QueueService {
      * @return queue list
      */
     @Override
-    public Result queryList(User loginUser) {
-        Result result = new Result();
+    public List<Queue> queryList(User loginUser) {
         Set<Integer> ids = resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.QUEUE,
                 loginUser.getId(), log);
         if (loginUser.getUserType().equals(UserType.GENERAL_USER)) {
             ids = ids.isEmpty() ? new HashSet<>() : ids;
             ids.add(Constants.DEFAULT_QUEUE_ID);
         }
-        List<Queue> queueList = queueMapper.selectBatchIds(ids);
-        result.setData(queueList);
-        putMsg(result, Status.SUCCESS);
-        return result;
+        return queueMapper.selectBatchIds(ids);
     }
 
     /**
      * query queue list paging
      *
      * @param loginUser login user
-     * @param pageNo page number
+     * @param pageNo    page number
      * @param searchVal search value
-     * @param pageSize page size
+     * @param pageSize  page size
      * @return queue list
      */
     @Override
-    public Result queryList(User loginUser, String searchVal, Integer pageNo, Integer pageSize) {
-        Result result = new Result();
+    public PageInfo<Queue> queryList(User loginUser, String searchVal, Integer pageNo, Integer pageSize) {
         PageInfo<Queue> pageInfo = new PageInfo<>(pageNo, pageSize);
         Set<Integer> ids = resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.QUEUE,
                 loginUser.getId(), log);
         if (ids.isEmpty()) {
-            result.setData(pageInfo);
-            putMsg(result, Status.SUCCESS);
-            return result;
+            return pageInfo;
         }
         Page<Queue> page = new Page<>(pageNo, pageSize);
         IPage<Queue> queueList = queueMapper.queryQueuePaging(page, new ArrayList<>(ids), searchVal);
         Integer count = (int) queueList.getTotal();
         pageInfo.setTotal(count);
         pageInfo.setTotalList(queueList.getRecords());
-        result.setData(pageInfo);
-        putMsg(result, Status.SUCCESS);
-
-        return result;
+        return pageInfo;
     }
 
     /**
      * create queue
      *
      * @param loginUser login user
-     * @param queue queue
+     * @param queue     queue
      * @param queueName queue name
      * @return create result
      */
     @Override
-    @Transactional
-    public Result createQueue(User loginUser, String queue, String queueName) {
-        Result result = new Result();
+    public Queue createQueue(User loginUser, String queue, String queueName) {
         if (!canOperatorPermissions(loginUser, null, AuthorizationType.QUEUE, YARN_QUEUE_CREATE)) {
             throw new ServiceException(Status.USER_NO_OPERATION_PERM);
         }
 
         Queue queueObj = new Queue(queueName, queue);
-        createQueueValid(queueObj);
+        validQueue(queueObj);
         queueMapper.insert(queueObj);
 
-        result.setData(queueObj);
-        log.info("Queue create complete, queueName:{}.", queueObj.getQueueName());
-        putMsg(result, Status.SUCCESS);
-        permissionPostHandle(AuthorizationType.QUEUE, loginUser.getId(), Collections.singletonList(queueObj.getId()),
-                log);
-        return result;
+        return queueObj;
     }
 
     /**
      * update queue
      *
      * @param loginUser login user
-     * @param queue queue
-     * @param id queue id
+     * @param queue     queue
+     * @param id        queue id
      * @param queueName queue name
      * @return update result code
      */
     @Override
-    public Result updateQueue(User loginUser, int id, String queue, String queueName) {
-        Result result = new Result();
+    public Queue updateQueue(User loginUser, int id, String queue, String queueName) {
         if (!canOperatorPermissions(loginUser, new Object[]{id}, AuthorizationType.QUEUE, YARN_QUEUE_UPDATE)) {
             throw new ServiceException(Status.USER_NO_OPERATION_PERM);
         }
 
         Queue updateQueue = new Queue(id, queueName, queue);
+        updateQueue.setCreateTime(null);
         Queue existsQueue = queueMapper.selectById(id);
         updateQueueValid(existsQueue, updateQueue);
 
@@ -227,23 +205,19 @@ public class QueueServiceImpl extends BaseServiceImpl implements QueueService {
         }
 
         queueMapper.updateById(updateQueue);
-        result.setData(updateQueue);
-        putMsg(result, Status.SUCCESS);
-        return result;
+        return updateQueue;
     }
 
     /**
      * delete queue
      *
      * @param loginUser login user
-     * @param id queue id
+     * @param id        queue id
      * @return delete result code
      * @throws Exception exception
      */
     @Override
-    @Transactional(rollbackFor = Exception.class)
-    public Map<String, Object> deleteQueueById(User loginUser, int id) throws Exception {
-        Map<String, Object> result = new HashMap<>();
+    public void deleteQueueById(User loginUser, int id) throws Exception {
 
         if (!canOperatorPermissions(loginUser, null, AuthorizationType.TENANT, TENANT_DELETE)) {
             throw new ServiceException(Status.USER_NO_OPERATION_PERM);
@@ -268,15 +242,10 @@ public class QueueServiceImpl extends BaseServiceImpl implements QueueService {
         }
 
         int delete = queueMapper.deleteById(id);
-        if (delete > 0) {
-            log.info("Queue is deleted and id is {}.", id);
-            putMsg(result, Status.SUCCESS);
-        } else {
-            log.error("Queue delete failed, queueId:{}.", id);
-            putMsg(result, Status.DELETE_QUEUE_BY_ID_ERROR);
+        if (delete <= 0) {
+            throw new ServiceException(Status.DELETE_QUEUE_BY_ID_ERROR);
         }
 
-        return result;
     }
 
     /**
@@ -287,14 +256,9 @@ public class QueueServiceImpl extends BaseServiceImpl implements QueueService {
      * @return true if the queue name not exists, otherwise return false
      */
     @Override
-    public Result<Object> verifyQueue(String queue, String queueName) {
-        Result<Object> result = new Result<>();
-
+    public void verifyQueue(String queue, String queueName) {
         Queue queueValidator = new Queue(queueName, queue);
-        createQueueValid(queueValidator);
-        result.setData(queueValidator);
-        putMsg(result, Status.SUCCESS);
-        return result;
+        validQueue(queueValidator);
     }
 
     /**
@@ -349,7 +313,7 @@ public class QueueServiceImpl extends BaseServiceImpl implements QueueService {
             return existsQueue;
         }
         Queue queueObj = new Queue(queueName, queue);
-        createQueueValid(queueObj);
+        validQueue(queueObj);
         queueMapper.insert(queueObj);
         log.info("Queue create complete, queueName:{}.", queueObj.getQueueName());
         return queueObj;
