@@ -28,19 +28,19 @@ import org.apache.dolphinscheduler.api.service.QueueService;
 import org.apache.dolphinscheduler.api.service.TenantService;
 import org.apache.dolphinscheduler.api.utils.PageInfo;
 import org.apache.dolphinscheduler.api.utils.RegexUtils;
-import org.apache.dolphinscheduler.api.utils.Result;
 import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.AuthorizationType;
-import org.apache.dolphinscheduler.dao.entity.ProcessInstance;
+import org.apache.dolphinscheduler.common.enums.WorkflowExecutionStatus;
 import org.apache.dolphinscheduler.dao.entity.Queue;
 import org.apache.dolphinscheduler.dao.entity.Schedule;
 import org.apache.dolphinscheduler.dao.entity.Tenant;
 import org.apache.dolphinscheduler.dao.entity.User;
-import org.apache.dolphinscheduler.dao.mapper.ProcessInstanceMapper;
+import org.apache.dolphinscheduler.dao.entity.WorkflowInstance;
 import org.apache.dolphinscheduler.dao.mapper.ScheduleMapper;
 import org.apache.dolphinscheduler.dao.mapper.TenantMapper;
 import org.apache.dolphinscheduler.dao.mapper.UserMapper;
-import org.apache.dolphinscheduler.plugin.storage.api.StorageOperate;
+import org.apache.dolphinscheduler.dao.mapper.WorkflowInstanceMapper;
+import org.apache.dolphinscheduler.plugin.storage.api.StorageOperator;
 
 import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
@@ -62,9 +62,6 @@ import org.springframework.transaction.annotation.Transactional;
 import com.baomidou.mybatisplus.core.metadata.IPage;
 import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
 
-/**
- * tenant service impl
- */
 @Service
 @Slf4j
 public class TenantServiceImpl extends BaseServiceImpl implements TenantService {
@@ -73,7 +70,7 @@ public class TenantServiceImpl extends BaseServiceImpl implements TenantService
     private TenantMapper tenantMapper;
 
     @Autowired
-    private ProcessInstanceMapper processInstanceMapper;
+    private WorkflowInstanceMapper workflowInstanceMapper;
 
     @Autowired
     private ScheduleMapper scheduleMapper;
@@ -85,7 +82,7 @@ public class TenantServiceImpl extends BaseServiceImpl implements TenantService
     private QueueService queueService;
 
     @Autowired(required = false)
-    private StorageOperate storageOperate;
+    private StorageOperator storageOperator;
 
     /**
      * Check the tenant new object valid or not
@@ -137,34 +134,24 @@ public class TenantServiceImpl extends BaseServiceImpl implements TenantService
      * @param queueId queue id
      * @param desc description
      * @return create result code
-     * @throws Exception exception
      */
     @Override
     @Transactional(rollbackFor = Exception.class)
-    public Map<String, Object> createTenant(User loginUser,
-                                            String tenantCode,
-                                            int queueId,
-                                            String desc) throws Exception {
-        Map<String, Object> result = new HashMap<>();
-        result.put(Constants.STATUS, false);
+    public Tenant createTenant(User loginUser,
+                               String tenantCode,
+                               int queueId,
+                               String desc) {
         if (!canOperatorPermissions(loginUser, null, AuthorizationType.TENANT, TENANT_CREATE)) {
             throw new ServiceException(Status.USER_NO_OPERATION_PERM);
         }
         if (checkDescriptionLength(desc)) {
-            log.warn("Parameter description is too long.");
-            putMsg(result, Status.DESCRIPTION_TOO_LONG_ERROR);
-            return result;
+            throw new ServiceException(Status.DESCRIPTION_TOO_LONG_ERROR);
         }
         Tenant tenant = new Tenant(tenantCode, desc, queueId);
         createTenantValid(tenant);
         tenantMapper.insert(tenant);
 
-        storageOperate.createTenantDirIfNotExists(tenantCode);
-        permissionPostHandle(AuthorizationType.TENANT, loginUser.getId(), Collections.singletonList(tenant.getId()),
-                log);
-        result.put(Constants.DATA_LIST, tenant);
-        putMsg(result, Status.SUCCESS);
-        return result;
+        return tenant;
     }
 
     /**
@@ -177,29 +164,20 @@ public class TenantServiceImpl extends BaseServiceImpl implements TenantService
      * @return tenant list page
      */
     @Override
-    public Result<Object> queryTenantList(User loginUser, String searchVal, Integer pageNo, Integer pageSize) {
+    public PageInfo<Tenant> queryTenantList(User loginUser, String searchVal, Integer pageNo, Integer pageSize) {
 
-        Result<Object> result = new Result<>();
-        PageInfo<Tenant> pageInfo = new PageInfo<>(pageNo, pageSize);
         Set<Integer> ids = resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.TENANT,
                 loginUser.getId(), log);
-        if (ids.isEmpty()) {
-            result.setData(pageInfo);
-            putMsg(result, Status.SUCCESS);
-            return result;
+        if (CollectionUtils.isEmpty(ids)) {
+            return new PageInfo<>(pageNo, pageSize);
         }
         Page<Tenant> page = new Page<>(pageNo, pageSize);
         IPage<Tenant> tenantPage = tenantMapper.queryTenantPaging(page, new ArrayList<>(ids), searchVal);
-
-        pageInfo.setTotal((int) tenantPage.getTotal());
-        pageInfo.setTotalList(tenantPage.getRecords());
-        result.setData(pageInfo);
-        putMsg(result, Status.SUCCESS);
-        return result;
+        return PageInfo.of(tenantPage);
     }
 
     /**
-     * updateProcessInstance tenant
+     * updateWorkflowInstance tenant
      *
      * @param loginUser login user
      * @param id tenant id
@@ -210,51 +188,40 @@ public class TenantServiceImpl extends BaseServiceImpl implements TenantService
      * @throws Exception exception
      */
     @Override
-    public Map<String, Object> updateTenant(User loginUser, int id, String tenantCode, int queueId,
-                                            String desc) throws Exception {
-
-        Map<String, Object> result = new HashMap<>();
+    public void updateTenant(User loginUser,
+                             int id,
+                             String tenantCode,
+                             int queueId,
+                             String desc) throws Exception {
 
         if (!canOperatorPermissions(loginUser, null, AuthorizationType.TENANT, TENANT_UPDATE)) {
             throw new ServiceException(Status.USER_NO_OPERATION_PERM);
         }
         if (checkDescriptionLength(desc)) {
-            log.warn("Parameter description is too long.");
-            putMsg(result, Status.DESCRIPTION_TOO_LONG_ERROR);
-            return result;
+            throw new ServiceException(Status.DESCRIPTION_TOO_LONG_ERROR);
         }
         Tenant updateTenant = new Tenant(id, tenantCode, desc, queueId);
         Tenant existsTenant = tenantMapper.queryById(id);
         updateTenantValid(existsTenant, updateTenant);
 
-        // updateProcessInstance tenant
-        // if the tenant code is modified, the original resource needs to be copied to the new tenant.
-        if (!Objects.equals(existsTenant.getTenantCode(), updateTenant.getTenantCode())) {
-            storageOperate.createTenantDirIfNotExists(tenantCode);
-        }
+        updateTenant.setCreateTime(existsTenant.getCreateTime());
         int update = tenantMapper.updateById(updateTenant);
-        if (update > 0) {
-            log.info("Tenant is updated and id is {}.", updateTenant.getId());
-            putMsg(result, Status.SUCCESS);
-        } else {
-            log.error("Tenant update error, id:{}.", updateTenant.getId());
-            putMsg(result, Status.UPDATE_TENANT_ERROR);
+        if (update <= 0) {
+            throw new ServiceException(Status.UPDATE_TENANT_ERROR);
         }
-        return result;
     }
 
     /**
      * delete tenant
      *
      * @param loginUser login user
-     * @param id tenant id
+     * @param id        tenant id
      * @return delete result code
      * @throws Exception exception
      */
     @Override
-    @Transactional(rollbackFor = Exception.class)
-    public Map<String, Object> deleteTenantById(User loginUser, int id) throws Exception {
-        Map<String, Object> result = new HashMap<>();
+    @Transactional()
+    public void deleteTenantById(User loginUser, int id) throws Exception {
 
         if (!canOperatorPermissions(loginUser, null, AuthorizationType.TENANT, TENANT_DELETE)) {
             throw new ServiceException(Status.USER_NO_OPERATION_PERM);
@@ -262,49 +229,36 @@ public class TenantServiceImpl extends BaseServiceImpl implements TenantService
 
         Tenant tenant = tenantMapper.queryById(id);
         if (Objects.isNull(tenant)) {
-            log.error("Tenant does not exist, userId:{}.", id);
             throw new ServiceException(Status.TENANT_NOT_EXIST);
         }
 
-        List<ProcessInstance> processInstances = getProcessInstancesByTenant(tenant);
-        if (CollectionUtils.isNotEmpty(processInstances)) {
-            log.warn("Delete tenant failed, because there are {} executing process instances using it.",
-                    processInstances.size());
-            throw new ServiceException(Status.DELETE_TENANT_BY_ID_FAIL, processInstances.size());
+        List<WorkflowInstance> workflowInstances = getWorkflowInstancesByTenant(tenant);
+        if (CollectionUtils.isNotEmpty(workflowInstances)) {
+            throw new ServiceException(Status.DELETE_TENANT_BY_ID_FAIL, workflowInstances.size());
         }
 
-        List<Schedule> schedules =
-                scheduleMapper.queryScheduleListByTenant(tenant.getTenantCode());
+        List<Schedule> schedules = scheduleMapper.queryScheduleListByTenant(tenant.getTenantCode());
         if (CollectionUtils.isNotEmpty(schedules)) {
-            log.warn("Delete tenant failed, because there are {} schedule using it.",
-                    schedules.size());
             throw new ServiceException(Status.DELETE_TENANT_BY_ID_FAIL_DEFINES, schedules.size());
         }
 
         List<User> userList = userMapper.queryUserListByTenant(tenant.getId());
         if (CollectionUtils.isNotEmpty(userList)) {
-            log.warn("Delete tenant failed, because there are {} users using it.", userList.size());
             throw new ServiceException(Status.DELETE_TENANT_BY_ID_FAIL_USERS, userList.size());
         }
 
-        storageOperate.deleteTenant(tenant.getTenantCode());
-
         int delete = tenantMapper.deleteById(id);
-        if (delete > 0) {
-            processInstanceMapper.updateProcessInstanceByTenantCode(tenant.getTenantCode(), Constants.DEFAULT);
-            log.info("Tenant is deleted and id is {}.", id);
-            putMsg(result, Status.SUCCESS);
-        } else {
-            log.error("Tenant delete failed, tenantId:{}.", id);
-            putMsg(result, Status.DELETE_TENANT_BY_ID_ERROR);
+        if (delete <= 0) {
+            throw new ServiceException(Status.DELETE_TENANT_BY_ID_ERROR);
         }
 
-        return result;
+        workflowInstanceMapper.updateWorkflowInstanceByTenantCode(tenant.getTenantCode(), Constants.DEFAULT);
     }
 
-    private List<ProcessInstance> getProcessInstancesByTenant(Tenant tenant) {
-        return processInstanceMapper.queryByTenantCodeAndStatus(tenant.getTenantCode(),
-                org.apache.dolphinscheduler.service.utils.Constants.NOT_TERMINATED_STATES);
+    private List<WorkflowInstance> getWorkflowInstancesByTenant(Tenant tenant) {
+        return workflowInstanceMapper.queryByTenantCodeAndStatus(
+                tenant.getTenantCode(),
+                WorkflowExecutionStatus.NOT_TERMINAL_STATES);
     }
 
     /**
@@ -314,20 +268,14 @@ public class TenantServiceImpl extends BaseServiceImpl implements TenantService
      * @return tenant list
      */
     @Override
-    public Map<String, Object> queryTenantList(User loginUser) {
+    public List<Tenant> queryTenantList(User loginUser) {
 
-        Map<String, Object> result = new HashMap<>();
         Set<Integer> ids = resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.TENANT,
                 loginUser.getId(), log);
-        if (ids.isEmpty()) {
-            result.put(Constants.DATA_LIST, Collections.emptyList());
-            putMsg(result, Status.SUCCESS);
-            return result;
+        if (CollectionUtils.isEmpty(ids)) {
+            return Collections.emptyList();
         }
-        List<Tenant> resourceList = tenantMapper.selectBatchIds(ids);
-        result.put(Constants.DATA_LIST, resourceList);
-        putMsg(result, Status.SUCCESS);
-        return result;
+        return tenantMapper.selectBatchIds(ids);
     }
 
     /**
@@ -337,13 +285,10 @@ public class TenantServiceImpl extends BaseServiceImpl implements TenantService
      * @return true if tenant code can use, otherwise return false
      */
     @Override
-    public Result<Object> verifyTenantCode(String tenantCode) {
-        Result<Object> result = new Result<>();
+    public void verifyTenantCode(String tenantCode) {
         if (checkTenantExists(tenantCode)) {
             throw new ServiceException(Status.OS_TENANT_CODE_EXIST, tenantCode);
         }
-        putMsg(result, Status.SUCCESS);
-        return result;
     }
 
     /**
