@@ -20,12 +20,16 @@ package org.apache.dolphinscheduler.api.utils;
 import java.util.Collections;
 import java.util.List;
 
+import lombok.AllArgsConstructor;
+import lombok.Builder;
 import lombok.Data;
 import lombok.Setter;
 
 import com.baomidou.mybatisplus.core.metadata.IPage;
 
 @Data
+@Builder
+@AllArgsConstructor
 public class PageInfo<T> {
 
     /**
