@@ -27,20 +27,21 @@ import org.apache.dolphinscheduler.api.enums.Status;
 import org.apache.dolphinscheduler.api.utils.Result;
 import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
-import org.apache.dolphinscheduler.common.utils.OkHttpUtils;
+import org.apache.dolphinscheduler.dao.entity.Session;
+import org.apache.dolphinscheduler.dao.repository.SessionDao;
 
 import org.apache.http.HttpStatus;
 
+import java.util.Date;
 import java.util.Map;
 
 import javax.servlet.http.Cookie;
 
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
-import org.mockito.MockedStatic;
-import org.mockito.Mockito;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.http.MediaType;
 import org.springframework.mock.web.MockHttpServletResponse;
 import org.springframework.test.web.servlet.MvcResult;
@@ -54,6 +55,9 @@ public class LoginControllerTest extends AbstractControllerTest {
 
     private static final Logger logger = LoggerFactory.getLogger(LoginControllerTest.class);
 
+    @Autowired
+    private SessionDao sessionDao;
+
     @Test
     public void testLogin() throws Exception {
         MultiValueMap<String, String> paramsMap = new LinkedMultiValueMap<>();
@@ -90,6 +94,18 @@ public class LoginControllerTest extends AbstractControllerTest {
         logger.info(mvcResult.getResponse().getContentAsString());
     }
 
+    @Test
+    void testSignOutWithExpireSession() throws Exception {
+        final Session session = sessionDao.queryById(sessionId);
+        session.setLastLoginTime(new Date(System.currentTimeMillis() - Constants.SESSION_TIME_OUT * 1000 - 1));
+        sessionDao.updateById(session);
+
+        mockMvc.perform(post("/signOut")
+                .header("sessionId", sessionId))
+                .andExpect(status().is(HttpStatus.SC_UNAUTHORIZED))
+                .andReturn();
+    }
+
     @Test
     void testClearCookie() throws Exception {
         MvcResult mvcResult = mockMvc.perform(delete("/cookies")
@@ -113,39 +129,4 @@ public class LoginControllerTest extends AbstractControllerTest {
         Result result = JSONUtils.parseObject(mvcResult.getResponse().getContentAsString(), Result.class);
         Assertions.assertEquals(Status.SUCCESS.getCode(), result.getCode().intValue());
     }
-
-    @Test
-    void testOauth2Redirect() throws Exception {
-        String tokenResult = "{\"access_token\":\"test-token\"}";
-        String userInfoResult = "{\"login\":\"username\"}";
-        MockedStatic<OkHttpUtils> okHttpUtilsMockedStatic = Mockito.mockStatic(OkHttpUtils.class);
-        okHttpUtilsMockedStatic
-                .when(() -> OkHttpUtils.post(Mockito.notNull(), Mockito.any(), Mockito.any(), Mockito.any()))
-                .thenReturn(tokenResult);
-        okHttpUtilsMockedStatic.when(() -> OkHttpUtils.get(Mockito.notNull(), Mockito.any(), Mockito.any()))
-                .thenReturn(userInfoResult);
-        MvcResult mvcResult = mockMvc.perform(get("/redirect/login/oauth2?code=test&provider=github"))
-                .andExpect(status().is3xxRedirection())
-                .andReturn();
-        MockHttpServletResponse response = mvcResult.getResponse();
-        Assertions.assertEquals(HttpStatus.SC_MOVED_TEMPORARILY, response.getStatus());
-        String redirectedUrl = response.getRedirectedUrl();
-        Assertions.assertTrue(redirectedUrl != null && redirectedUrl.contains("sessionId"));
-        okHttpUtilsMockedStatic.close();
-    }
-
-    @Test
-    void testOauth2RedirectError() throws Exception {
-        MockedStatic<OkHttpUtils> okHttpUtilsMockedStatic = Mockito.mockStatic(OkHttpUtils.class);
-        okHttpUtilsMockedStatic.when(() -> OkHttpUtils.post(Mockito.any(), Mockito.any(), Mockito.any(), Mockito.any()))
-                .thenThrow(new RuntimeException("oauth error"));
-        MvcResult mvcResult = mockMvc.perform(get("/redirect/login/oauth2?code=test&provider=github"))
-                .andExpect(status().is3xxRedirection())
-                .andReturn();
-        MockHttpServletResponse response = mvcResult.getResponse();
-        Assertions.assertEquals(HttpStatus.SC_MOVED_TEMPORARILY, response.getStatus());
-        String redirectedUrl = response.getRedirectedUrl();
-        Assertions.assertTrue(redirectedUrl != null && redirectedUrl.contains("error"));
-        okHttpUtilsMockedStatic.close();
-    }
 }
