@@ -17,7 +17,7 @@
 
 package org.apache.dolphinscheduler.api.interceptor;
 
-import org.apache.dolphinscheduler.api.configuration.TrafficConfiguration;
+import org.apache.dolphinscheduler.api.configuration.ApiConfig;
 
 import java.util.HashMap;
 import java.util.Map;
@@ -26,28 +26,27 @@ import java.util.concurrent.ExecutionException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.junit.Assert;
-import org.junit.Test;
-import org.junit.runner.RunWith;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.ExtendWith;
 import org.mockito.Mockito;
-import org.powermock.api.mockito.PowerMockito;
-import org.powermock.modules.junit4.PowerMockRunner;
+import org.mockito.junit.jupiter.MockitoExtension;
 
-@RunWith(PowerMockRunner.class)
+@ExtendWith(MockitoExtension.class)
 public class RateLimitInterceptorTest {
 
     @Test
     public void testPreHandleWithoutControl() throws ExecutionException {
         HttpServletRequest request = Mockito.mock(HttpServletRequest.class);
         HttpServletResponse response = Mockito.mock(HttpServletResponse.class);
-        RateLimitInterceptor rateLimitInterceptor = new RateLimitInterceptor(new TrafficConfiguration());
-        Assert.assertTrue(rateLimitInterceptor.preHandle(request, response, null));
-        Assert.assertTrue(rateLimitInterceptor.preHandle(request, response, null));
+        RateLimitInterceptor rateLimitInterceptor = new RateLimitInterceptor(new ApiConfig.TrafficConfiguration());
+        Assertions.assertTrue(rateLimitInterceptor.preHandle(request, response, null));
+        Assertions.assertTrue(rateLimitInterceptor.preHandle(request, response, null));
     }
 
     @Test
     public void testPreHandleWithTenantLevenControl() throws ExecutionException {
-        TrafficConfiguration trafficConfiguration = new TrafficConfiguration();
+        ApiConfig.TrafficConfiguration trafficConfiguration = new ApiConfig.TrafficConfiguration();
         trafficConfiguration.setTenantSwitch(true);
         Map<String, Integer> map = new HashMap<>();
         map.put("tenant1", 2);
@@ -58,20 +57,20 @@ public class RateLimitInterceptorTest {
 
         HttpServletRequest tenant1Request = Mockito.mock(HttpServletRequest.class);
         HttpServletRequest tenant2Request = Mockito.mock(HttpServletRequest.class);
-        PowerMockito.when(tenant1Request.getHeader(Mockito.any())).thenReturn("tenant1");
-        PowerMockito.when(tenant2Request.getHeader(Mockito.any())).thenReturn("tenant2");
+        Mockito.when(tenant1Request.getHeader(Mockito.any())).thenReturn("tenant1");
+        Mockito.when(tenant2Request.getHeader(Mockito.any())).thenReturn("tenant2");
         HttpServletResponse response = Mockito.mock(HttpServletResponse.class);
 
         for (int i = 0; i < 2; i++) {
             rateLimitInterceptor.preHandle(tenant1Request, response, null);
         }
-        Assert.assertFalse(rateLimitInterceptor.preHandle(tenant1Request, response, null));
-        Assert.assertTrue(rateLimitInterceptor.preHandle(tenant2Request, response, null));
+        Assertions.assertFalse(rateLimitInterceptor.preHandle(tenant1Request, response, null));
+        Assertions.assertTrue(rateLimitInterceptor.preHandle(tenant2Request, response, null));
     }
 
     @Test
     public void testPreHandleWithGlobalControl() throws ExecutionException {
-        TrafficConfiguration trafficConfiguration = new TrafficConfiguration();
+        ApiConfig.TrafficConfiguration trafficConfiguration = new ApiConfig.TrafficConfiguration();
         trafficConfiguration.setTenantSwitch(true);
         trafficConfiguration.setGlobalSwitch(true);
         trafficConfiguration.setMaxGlobalQpsRate(3);
@@ -83,7 +82,7 @@ public class RateLimitInterceptorTest {
         for (int i = 0; i < 2; i++) {
             rateLimitInterceptor.preHandle(request, response, null);
         }
-        Assert.assertFalse(rateLimitInterceptor.preHandle(request, response, null));
+        Assertions.assertFalse(rateLimitInterceptor.preHandle(request, response, null));
     }
 
 }
