@@ -19,8 +19,8 @@ package org.apache.dolphinscheduler.api.security;
 
 import org.apache.dolphinscheduler.api.controller.AbstractControllerTest;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.test.context.TestPropertySource;
 
@@ -35,6 +35,6 @@ public class SecurityConfigPasswordTest extends AbstractControllerTest {
     @Test
     public void testAuthenticator() {
         Authenticator authenticator = securityConfig.authenticator();
-        Assert.assertNotNull(authenticator);
+        Assertions.assertNotNull(authenticator);
     }
 }
