@@ -17,6 +17,7 @@
 
 package org.apache.dolphinscheduler.api.security.impl.pwd;
 
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.when;
 
 import org.apache.dolphinscheduler.api.controller.AbstractControllerTest;
@@ -81,21 +82,21 @@ public class PasswordAuthenticatorTest extends AbstractControllerTest {
     @Test
     public void testLogin() {
         when(usersService.queryUser("test", "test")).thenReturn(mockUser);
-        User login = authenticator.login("test", "test", "127.0.0.1");
+        User login = authenticator.login("test", "test");
         Assertions.assertNotNull(login);
     }
 
     @Test
     public void testAuthenticate() {
         when(usersService.queryUser("test", "test")).thenReturn(mockUser);
-        when(sessionService.createSession(mockUser, "127.0.0.1")).thenReturn(mockSession.getId());
+        when(sessionService.createSessionIfAbsent(mockUser)).thenReturn(mockSession);
         Result result = authenticator.authenticate("test", "test", "127.0.0.1");
         Assertions.assertEquals(Status.SUCCESS.getCode(), (int) result.getCode());
         logger.info(result.toString());
 
         mockUser.setState(0);
         when(usersService.queryUser("test", "test")).thenReturn(mockUser);
-        when(sessionService.createSession(mockUser, "127.0.0.1")).thenReturn(mockSession.getId());
+        when(sessionService.createSessionIfAbsent(mockUser)).thenReturn(mockSession);
         Result result1 = authenticator.authenticate("test", "test", "127.0.0.1");
         Assertions.assertEquals(Status.USER_DISABLED.getCode(), (int) result1.getCode());
         logger.info(result1.toString());
@@ -105,7 +106,7 @@ public class PasswordAuthenticatorTest extends AbstractControllerTest {
     public void testGetAuthUser() {
         HttpServletRequest request = Mockito.mock(HttpServletRequest.class);
         when(usersService.queryUser(mockUser.getId())).thenReturn(mockUser);
-        when(sessionService.getSession(request)).thenReturn(mockSession);
+        when(sessionService.getSession(any())).thenReturn(mockSession);
 
         User user = authenticator.getAuthUser(request);
         Assertions.assertNotNull(user);
