@@ -17,14 +17,15 @@
 
 package org.apache.dolphinscheduler.api.service;
 
+import static org.apache.dolphinscheduler.api.AssertionsHelper.assertThrowsServiceException;
 import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.FORCED_SUCCESS;
 import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.TASK_INSTANCE;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.eq;
+import static org.mockito.Mockito.doNothing;
+import static org.mockito.Mockito.doThrow;
 import static org.mockito.Mockito.when;
 
-import org.apache.dolphinscheduler.api.ApiApplicationServer;
-import org.apache.dolphinscheduler.api.dto.taskInstance.TaskInstanceRemoveCacheResponse;
 import org.apache.dolphinscheduler.api.enums.Status;
 import org.apache.dolphinscheduler.api.exceptions.ServiceException;
 import org.apache.dolphinscheduler.api.service.impl.ProjectServiceImpl;
@@ -33,16 +34,17 @@ import org.apache.dolphinscheduler.api.utils.Result;
 import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.TaskExecuteType;
 import org.apache.dolphinscheduler.common.enums.UserType;
+import org.apache.dolphinscheduler.common.enums.WorkflowExecutionStatus;
 import org.apache.dolphinscheduler.common.utils.DateUtils;
-import org.apache.dolphinscheduler.dao.entity.ProcessInstance;
 import org.apache.dolphinscheduler.dao.entity.Project;
-import org.apache.dolphinscheduler.dao.entity.TaskDefinition;
 import org.apache.dolphinscheduler.dao.entity.TaskInstance;
 import org.apache.dolphinscheduler.dao.entity.User;
+import org.apache.dolphinscheduler.dao.entity.WorkflowInstance;
 import org.apache.dolphinscheduler.dao.mapper.ProjectMapper;
 import org.apache.dolphinscheduler.dao.mapper.TaskDefinitionMapper;
 import org.apache.dolphinscheduler.dao.mapper.TaskInstanceMapper;
 import org.apache.dolphinscheduler.dao.repository.TaskInstanceDao;
+import org.apache.dolphinscheduler.dao.repository.WorkflowInstanceDao;
 import org.apache.dolphinscheduler.plugin.task.api.enums.TaskExecutionStatus;
 import org.apache.dolphinscheduler.service.process.ProcessService;
 
@@ -63,7 +65,6 @@ import org.mockito.Mockito;
 import org.mockito.junit.jupiter.MockitoExtension;
 import org.mockito.junit.jupiter.MockitoSettings;
 import org.mockito.quality.Strictness;
-import org.springframework.boot.test.context.SpringBootTest;
 
 import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
 
@@ -72,7 +73,6 @@ import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
  */
 @ExtendWith(MockitoExtension.class)
 @MockitoSettings(strictness = Strictness.LENIENT)
-@SpringBootTest(classes = ApiApplicationServer.class)
 public class TaskInstanceServiceTest {
 
     @InjectMocks
@@ -98,6 +98,8 @@ public class TaskInstanceServiceTest {
 
     @Mock
     TaskInstanceDao taskInstanceDao;
+    @Mock
+    WorkflowInstanceDao workflowInstanceDao;
 
     @Test
     public void queryTaskListPaging() {
@@ -108,9 +110,8 @@ public class TaskInstanceServiceTest {
         putMsg(result, Status.PROJECT_NOT_FOUND, projectCode);
 
         // project auth fail
-        when(projectMapper.queryByCode(projectCode)).thenReturn(null);
-        Mockito.doThrow(new ServiceException()).when(projectService).checkProjectAndAuthThrowException(Mockito.any(),
-                Mockito.any(), Mockito.any());
+        doThrow(new ServiceException()).when(projectService).checkProjectAndAuthThrowException(loginUser, projectCode,
+                TASK_INSTANCE);
         Assertions.assertThrows(ServiceException.class, () -> taskInstanceService.queryTaskListPaging(loginUser,
                 projectCode,
                 0,
@@ -153,15 +154,13 @@ public class TaskInstanceServiceTest {
         putMsg(result, Status.SUCCESS, projectCode);
         Date start = DateUtils.stringToDate("2020-01-01 00:00:00");
         Date end = DateUtils.stringToDate("2020-01-02 00:00:00");
-        ProcessInstance processInstance = getProcessInstance();
+        WorkflowInstance workflowInstance = getProcessInstance();
         TaskInstance taskInstance = getTaskInstance();
         List<TaskInstance> taskInstanceList = new ArrayList<>();
         Page<TaskInstance> pageReturn = new Page<>(1, 10);
         taskInstanceList.add(taskInstance);
         pageReturn.setRecords(taskInstanceList);
-        when(projectMapper.queryByCode(projectCode)).thenReturn(project);
-        Mockito.doNothing().when(projectService).checkProjectAndAuthThrowException(Mockito.any(), Mockito.any(),
-                Mockito.any());
+        doNothing().when(projectService).checkProjectAndAuthThrowException(loginUser, projectCode, TASK_INSTANCE);
         when(usersService.queryUser(loginUser.getId())).thenReturn(loginUser);
         when(usersService.getUserIdByName(loginUser.getUserName())).thenReturn(loginUser.getId());
         when(taskInstanceMapper.queryTaskInstanceListPaging(
@@ -179,13 +178,26 @@ public class TaskInstanceServiceTest {
                 Mockito.any(),
                 Mockito.any()))
                         .thenReturn(pageReturn);
-        when(usersService.queryUser(processInstance.getExecutorId())).thenReturn(loginUser);
-        when(processService.findProcessInstanceDetailById(taskInstance.getProcessInstanceId()))
-                .thenReturn(Optional.of(processInstance));
+        when(usersService.queryUser(workflowInstance.getExecutorId())).thenReturn(loginUser);
+        when(processService.findWorkflowInstanceDetailById(taskInstance.getWorkflowInstanceId()))
+                .thenReturn(Optional.of(workflowInstance));
 
-        Result successRes = taskInstanceService.queryTaskListPaging(loginUser, projectCode, 1, "", "", "",
-                null, "test_user", "2020-01-01 00:00:00", "2020-01-02 00:00:00", "", TaskExecutionStatus.SUCCESS,
-                "192.168.xx.xx", TaskExecuteType.BATCH, 1, 20);
+        Result successRes = taskInstanceService.queryTaskListPaging(loginUser,
+                projectCode,
+                1,
+                "",
+                "",
+                "",
+                null,
+                "test_user",
+                "2020-01-01 00:00:00",
+                "2020-01-02 00:00:00",
+                "",
+                TaskExecutionStatus.SUCCESS,
+                "192.168.xx.xx",
+                TaskExecuteType.BATCH,
+                1,
+                20);
         Assertions.assertEquals(Status.SUCCESS.getCode(), (int) successRes.getCode());
 
         // executor name empty
@@ -294,14 +306,14 @@ public class TaskInstanceServiceTest {
      *
      * @return process instance
      */
-    private ProcessInstance getProcessInstance() {
-        ProcessInstance processInstance = new ProcessInstance();
-        processInstance.setId(1);
-        processInstance.setName("test_process_instance");
-        processInstance.setStartTime(new Date());
-        processInstance.setEndTime(new Date());
-        processInstance.setExecutorId(-1);
-        return processInstance;
+    private WorkflowInstance getProcessInstance() {
+        WorkflowInstance workflowInstance = new WorkflowInstance();
+        workflowInstance.setId(1);
+        workflowInstance.setName("test_process_instance");
+        workflowInstance.setStartTime(new Date());
+        workflowInstance.setEndTime(new Date());
+        workflowInstance.setExecutorId(-1);
+        return workflowInstance;
     }
 
     /**
@@ -312,6 +324,7 @@ public class TaskInstanceServiceTest {
     private TaskInstance getTaskInstance() {
         TaskInstance taskInstance = new TaskInstance();
         taskInstance.setId(1);
+        taskInstance.setProjectCode(1L);
         taskInstance.setName("test_task_instance");
         taskInstance.setStartTime(new Date());
         taskInstance.setEndTime(new Date());
@@ -331,87 +344,69 @@ public class TaskInstanceServiceTest {
     }
 
     @Test
-    public void forceTaskSuccess() {
+    public void testForceTaskSuccess_withNoPermission() {
         User user = getAdminUser();
-        long projectCode = 1L;
-        Project project = getProject(projectCode);
-        int taskId = 1;
         TaskInstance task = getTaskInstance();
-
-        Map<String, Object> mockSuccess = new HashMap<>(5);
-        putMsg(mockSuccess, Status.SUCCESS);
-        when(projectMapper.queryByCode(projectCode)).thenReturn(project);
-
-        // user auth failed
-        Map<String, Object> mockFailure = new HashMap<>(5);
-        putMsg(mockFailure, Status.USER_NO_OPERATION_PROJECT_PERM, user.getUserName(), projectCode);
-        when(projectService.checkProjectAndAuth(user, project, projectCode, FORCED_SUCCESS)).thenReturn(mockFailure);
-        Result authFailRes = taskInstanceService.forceTaskSuccess(user, projectCode, taskId);
-        Assertions.assertNotSame(Status.SUCCESS.getCode(), authFailRes.getCode());
-
-        // test task not found
-        when(projectService.checkProjectAndAuth(user, project, projectCode, FORCED_SUCCESS)).thenReturn(mockSuccess);
-        when(taskInstanceMapper.selectById(Mockito.anyInt())).thenReturn(null);
-        TaskDefinition taskDefinition = new TaskDefinition();
-        taskDefinition.setProjectCode(projectCode);
-        when(taskDefinitionMapper.queryByCode(task.getTaskCode())).thenReturn(taskDefinition);
-        Result taskNotFoundRes = taskInstanceService.forceTaskSuccess(user, projectCode, taskId);
-        Assertions.assertEquals(Status.TASK_INSTANCE_NOT_FOUND.getCode(), taskNotFoundRes.getCode().intValue());
-
-        // test task instance state error
-        task.setState(TaskExecutionStatus.SUCCESS);
-        when(taskInstanceMapper.selectById(1)).thenReturn(task);
-        Map<String, Object> result = new HashMap<>();
-        putMsg(result, Status.SUCCESS, projectCode);
-        when(projectMapper.queryByCode(projectCode)).thenReturn(project);
-        when(projectService.checkProjectAndAuth(user, project, projectCode, FORCED_SUCCESS)).thenReturn(result);
-        Result taskStateErrorRes = taskInstanceService.forceTaskSuccess(user, projectCode, taskId);
-        Assertions.assertEquals(Status.TASK_INSTANCE_STATE_OPERATION_ERROR.getCode(),
-                taskStateErrorRes.getCode().intValue());
-
-        // test error
-        task.setState(TaskExecutionStatus.FAILURE);
-        when(taskInstanceMapper.updateById(task)).thenReturn(0);
-        putMsg(result, Status.SUCCESS, projectCode);
-        when(projectMapper.queryByCode(projectCode)).thenReturn(project);
-        when(projectService.checkProjectAndAuth(user, project, projectCode, FORCED_SUCCESS)).thenReturn(result);
-        Result errorRes = taskInstanceService.forceTaskSuccess(user, projectCode, taskId);
-        Assertions.assertEquals(Status.FORCE_TASK_SUCCESS_ERROR.getCode(), errorRes.getCode().intValue());
-
-        // test success
-        task.setState(TaskExecutionStatus.FAILURE);
-        when(taskInstanceMapper.updateById(task)).thenReturn(1);
-        putMsg(result, Status.SUCCESS, projectCode);
-        when(projectMapper.queryByCode(projectCode)).thenReturn(project);
-        when(projectService.checkProjectAndAuth(user, project, projectCode, FORCED_SUCCESS)).thenReturn(result);
-        Result successRes = taskInstanceService.forceTaskSuccess(user, projectCode, taskId);
-        Assertions.assertEquals(Status.SUCCESS.getCode(), successRes.getCode().intValue());
-
+        doThrow(new ServiceException(Status.USER_NO_OPERATION_PROJECT_PERM)).when(projectService)
+                .checkProjectAndAuthThrowException(user, task.getProjectCode(), FORCED_SUCCESS);
+        assertThrowsServiceException(Status.USER_NO_OPERATION_PROJECT_PERM,
+                () -> taskInstanceService.forceTaskSuccess(user, task.getProjectCode(), task.getId()));
     }
 
     @Test
-    public void testRemoveTaskInstanceCache() {
+    public void testForceTaskSuccess_withTaskInstanceNotFound() {
+        User user = getAdminUser();
+        TaskInstance task = getTaskInstance();
+        doNothing().when(projectService).checkProjectAndAuthThrowException(user, task.getProjectCode(), FORCED_SUCCESS);
+        when(taskInstanceDao.queryOptionalById(task.getId())).thenReturn(Optional.empty());
+        assertThrowsServiceException(Status.TASK_INSTANCE_NOT_FOUND,
+                () -> taskInstanceService.forceTaskSuccess(user, task.getProjectCode(), task.getId()));
+    }
+
+    @Test
+    public void testForceTaskSuccess_withWorkflowInstanceNotFound() {
+        User user = getAdminUser();
+        TaskInstance task = getTaskInstance();
+        doNothing().when(projectService).checkProjectAndAuthThrowException(user, task.getProjectCode(), FORCED_SUCCESS);
+        when(taskInstanceDao.queryOptionalById(task.getId())).thenReturn(Optional.of(task));
+        when(workflowInstanceDao.queryOptionalById(task.getWorkflowInstanceId())).thenReturn(Optional.empty());
+
+        assertThrowsServiceException(Status.WORKFLOW_INSTANCE_NOT_EXIST,
+                () -> taskInstanceService.forceTaskSuccess(user, task.getProjectCode(), task.getId()));
+    }
+
+    @Test
+    public void testForceTaskSuccess_withWorkflowInstanceNotFinished() {
         User user = getAdminUser();
         long projectCode = 1L;
-        Project project = getProject(projectCode);
-        int taskId = 1;
         TaskInstance task = getTaskInstance();
-        String cacheKey = "950311f3597f9198976cd3fd69e208e5b9ba6750";
-        task.setCacheKey(cacheKey);
-
-        when(projectMapper.queryByCode(projectCode)).thenReturn(project);
-        when(taskInstanceMapper.selectById(1)).thenReturn(task);
-        when(taskInstanceDao.queryByCacheKey(cacheKey)).thenReturn(task, null);
-        when(taskInstanceDao.updateById(task)).thenReturn(true);
-
-        TaskInstanceRemoveCacheResponse response =
-                taskInstanceService.removeTaskInstanceCache(user, projectCode, taskId);
-        Assertions.assertEquals(Status.SUCCESS.getCode(), response.getCode());
-
-        when(taskInstanceMapper.selectById(1)).thenReturn(null);
-        TaskInstanceRemoveCacheResponse responseNotFoundTask =
-                taskInstanceService.removeTaskInstanceCache(user, projectCode, taskId);
-        Assertions.assertEquals(Status.TASK_INSTANCE_NOT_FOUND.getCode(), responseNotFoundTask.getCode());
+        WorkflowInstance workflowInstance = getProcessInstance();
+        workflowInstance.setState(WorkflowExecutionStatus.RUNNING_EXECUTION);
+        doNothing().when(projectService).checkProjectAndAuthThrowException(user, projectCode, FORCED_SUCCESS);
+        when(taskInstanceDao.queryOptionalById(task.getId())).thenReturn(Optional.of(task));
+        when(workflowInstanceDao.queryOptionalById(task.getWorkflowInstanceId()))
+                .thenReturn(Optional.of(workflowInstance));
 
+        assertThrowsServiceException(
+                "The workflow instance is not finished: " + workflowInstance.getState()
+                        + " cannot force start task instance",
+                () -> taskInstanceService.forceTaskSuccess(user, projectCode, task.getId()));
     }
+
+    @Test
+    public void testForceTaskSuccess_withTaskInstanceNotFinished() {
+        User user = getAdminUser();
+        TaskInstance task = getTaskInstance();
+        WorkflowInstance workflowInstance = getProcessInstance();
+        workflowInstance.setState(WorkflowExecutionStatus.FAILURE);
+        doNothing().when(projectService).checkProjectAndAuthThrowException(user, task.getProjectCode(), FORCED_SUCCESS);
+        when(taskInstanceDao.queryOptionalById(task.getId())).thenReturn(Optional.of(task));
+        when(workflowInstanceDao.queryOptionalById(task.getWorkflowInstanceId()))
+                .thenReturn(Optional.of(workflowInstance));
+
+        assertThrowsServiceException(
+                Status.TASK_INSTANCE_STATE_OPERATION_ERROR,
+                () -> taskInstanceService.forceTaskSuccess(user, task.getProjectCode(), task.getId()));
+    }
+
 }
