@@ -18,8 +18,17 @@
 package org.apache.dolphinscheduler.api.utils;
 
 import org.apache.http.entity.ContentType;
-import org.junit.*;
-import org.junit.rules.TemporaryFolder;
+
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.IOException;
+import java.nio.charset.Charset;
+import java.nio.file.Path;
+
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 import org.mockito.Mockito;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -27,32 +36,18 @@ import org.springframework.core.io.Resource;
 import org.springframework.mock.web.MockMultipartFile;
 import org.springframework.web.multipart.MultipartFile;
 
-import java.io.*;
-
-import static org.junit.Assert.*;
-
 public class FileUtilsTest {
 
     private static final Logger logger = LoggerFactory.getLogger(FileUtilsTest.class);
 
-    @Rule
-    public TemporaryFolder folder = null;
+    @TempDir
+    public Path folder;
 
-    private String rootPath = null;
+    private String rootPath;
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
-
-        folder = new TemporaryFolder();
-        folder.create();
-
-        rootPath = folder.getRoot().getAbsolutePath();
-    }
-
-    @After
-    public void tearDown() throws Exception {
-
-        folder.delete();
+        rootPath = folder.toString();
     }
 
     /**
@@ -62,52 +57,54 @@ public class FileUtilsTest {
     @Test
     public void testCopyFile() throws IOException {
 
-        //Define dest file path
+        // Define dest file path
         String src = rootPath + System.getProperty("file.separator") + "src.txt";
         String destFilename = rootPath + System.getProperty("file.separator") + "data.txt";
-        logger.info("destFilename: "+destFilename);
+        logger.info("destFilename: " + destFilename);
 
-        //Define InputStream for MultipartFile
+        // Define InputStream for MultipartFile
         String data = "data text";
         org.apache.commons.io.FileUtils.writeStringToFile(new File(src), data);
 
-        //Use Mockito to mock MultipartFile
+        // Use Mockito to mock MultipartFile
         MultipartFile file = Mockito.mock(MultipartFile.class, Mockito.RETURNS_DEEP_STUBS);
         Mockito.when(file.getInputStream()).thenReturn(new FileInputStream(src));
 
-        //Invoke copyFile
-        FileUtils.copyInputStreamToFile(file,destFilename);
+        // Invoke copyFile
+        FileUtils.copyInputStreamToFile(file, destFilename);
 
-        //Test file exists
+        // Test file exists
         File destFile = new File(destFilename);
-        assertTrue(destFile.exists());
+        Assertions.assertTrue(destFile.exists());
 
     }
 
     @Test
     public void testFile2Resource() throws IOException {
 
-        //Define dest file path
-        String destFilename = rootPath + System.getProperty("file.separator") + "data.txt";
-        logger.info("destFilename: "+destFilename);
+        // Define dest file path
+        String destFilename = rootPath + System.getProperty("file.separator") + "resource.txt";
+        logger.info("destFilename: " + destFilename);
 
-        //Define test resource
-        File file = folder.newFile("resource.txt");
+        // Define test resource
+        File file = new File(destFilename);
+        org.apache.commons.io.FileUtils.writeStringToFile(file, "test data", Charset.defaultCharset());
 
-        //Invoke file2Resource and test not null
-        Resource resource = FileUtils.file2Resource(file.getAbsolutePath());
-        assertNotNull(resource);
+        // Invoke file2Resource and test not null
+        Resource resource = FileUtils.file2Resource(file.toString());
+        Assertions.assertNotNull(resource);
 
-        //Invoke file2Resource and test null
-        Resource resource1 = FileUtils.file2Resource(file.getAbsolutePath()+"abc");
-        assertNull(resource1);
+        // Invoke file2Resource and test null
+        Resource resource1 = FileUtils.file2Resource(file + "abc");
+        Assertions.assertNull(resource1);
 
     }
 
     @Test
     public void testFile2String() throws IOException {
         String content = "123";
-        org.apache.commons.io.FileUtils.writeStringToFile(new File("/tmp/task.json"),content);
+        org.apache.commons.io.FileUtils.writeStringToFile(new File("/tmp/task.json"), content,
+                Charset.defaultCharset());
 
         File file = new File("/tmp/task.json");
         FileInputStream fileInputStream = new FileInputStream("/tmp/task.json");
@@ -116,10 +113,10 @@ public class FileUtilsTest {
 
         String resultStr = FileUtils.file2String(multipartFile);
 
-        Assert.assertEquals(content, resultStr);
+        Assertions.assertEquals(content, resultStr);
 
         boolean delete = file.delete();
 
-        Assert.assertTrue(delete);
+        Assertions.assertTrue(delete);
     }
 }
