@@ -43,6 +43,7 @@ public class DataSourceConstants {
     public static final String NET_SNOWFLAKE_JDBC_DRIVER = "net.snowflake.client.jdbc.SnowflakeDriver";
     public static final String COM_VERTICA_JDBC_DRIVER = "com.vertica.jdbc.Driver";
     public static final String COM_HANA_DB_JDBC_DRIVER = "com.sap.db.jdbc.Driver";
+    public static final String COM_DOLPHINDB_JDBC_DRIVER = "com.dolphindb.jdbc.Driver";
 
     /**
      * validation Query
@@ -65,7 +66,8 @@ public class DataSourceConstants {
     public static final String KYUUBI_VALIDATION_QUERY = "select 1";
     public static final String VERTICA_VALIDATION_QUERY = "select 1";
 
-    public static final String HANA_VALIDATION_QUERY = "select 1";
+    public static final String HANA_VALIDATION_QUERY = "select 1 from DUMMY";
+    public static final String DOLPHINDB_VALIDATION_QUERY = "select 1";
 
     /**
      * jdbc url
@@ -91,6 +93,7 @@ public class DataSourceConstants {
     public static final String JDBC_SNOWFLAKE = "jdbc:snowflake://";
     public static final String JDBC_VERTICA = "jdbc:vertica://";
     public static final String JDBC_HANA = "jdbc:sap://";
+    public static final String JDBC_DOLPHINDB = "jdbc:dolphindb://";
 
     /**
      * database type
@@ -102,7 +105,7 @@ public class DataSourceConstants {
      * dataSource sensitive param
      */
     public static final String DATASOURCE_PASSWORD_REGEX =
-            "(?<=((?i)password((\":\")|(\\\\\":\\\\\")|(=')))).*?(?=((\")|(\\\\\")|(')))";
+            "(?<=((?i)password((\" : \")|(\":\")|(\\\\\":\\\\\")|(=')))).*?(?=((\")|(\\\\\")|(')))";
 
     /**
      * datasource encryption salt
