@@ -17,11 +17,11 @@
 
 package org.apache.dolphinscheduler.common.enums;
 
+import lombok.Getter;
+
 import com.baomidou.mybatisplus.annotation.EnumValue;
 
-/**
- * Authorization type
- */
+@Getter
 public enum AuthorizationType {
 
     /**
@@ -44,11 +44,13 @@ public enum AuthorizationType {
      * 16 USER;
      * 17 Data_Quality;
      */
+    @Deprecated
     RESOURCE_FILE_ID(0, "resource file id"),
+    @Deprecated
     RESOURCE_FILE_NAME(1, "resource file name"),
+    @Deprecated
     UDF_FILE(2, "udf file"),
     DATASOURCE(3, "data source"),
-    UDF(4, "udf function"),
     PROJECTS(5, "projects"),
     WORKER_GROUP(6, "worker group"),
     ALERT_GROUP(7, "alert group"),
@@ -60,7 +62,6 @@ public enum AuthorizationType {
     MONITOR(13, "monitor"),
     ALERT_PLUGIN_INSTANCE(14, "alert plugin instance"),
     TENANT(15, "tenant"),
-    DATA_QUALITY(16, "data quality"),
     TASK_GROUP(17, "task group"),
     ;
 
@@ -73,11 +74,4 @@ public enum AuthorizationType {
     private final int code;
     private final String descp;
 
-    public int getCode() {
-        return code;
-    }
-
-    public String getDescp() {
-        return descp;
-    }
 }
