@@ -19,6 +19,7 @@ package org.apache.dolphinscheduler.common.enums;
 
 public enum ServerStatus {
 
-    NORMAL, ABNORMAL, BUSY
+    NORMAL,
+    BUSY,
 
 }
