@@ -17,10 +17,10 @@
 
 package org.apache.dolphinscheduler.common.model;
 
+import org.apache.dolphinscheduler.common.enums.ServerStatus;
+
 public interface HeartBeat {
 
-    String getHost();
-
-    int getPort();
+    ServerStatus getServerStatus();
 
 }
