@@ -17,35 +17,18 @@
 
 package org.apache.dolphinscheduler.common.model;
 
-import org.apache.dolphinscheduler.common.enums.ServerStatus;
-
-import lombok.AllArgsConstructor;
-import lombok.Builder;
 import lombok.Data;
+import lombok.EqualsAndHashCode;
 import lombok.NoArgsConstructor;
+import lombok.experimental.SuperBuilder;
 
 @Data
-@Builder
+@EqualsAndHashCode(callSuper = true)
+@SuperBuilder
 @NoArgsConstructor
-@AllArgsConstructor
-public class WorkerHeartBeat implements HeartBeat {
-
-    private long startupTime;
-    private long reportTime;
-    private double cpuUsage;
-    private double memoryUsage;
-    private double loadAverage;
-    private double availablePhysicalMemorySize;
-    private double reservedMemory;
-    private double diskAvailable;
-    private ServerStatus serverStatus;
-    private int processId;
-
-    private String host;
-    private int port;
+public class WorkerHeartBeat extends BaseHeartBeat implements HeartBeat {
 
     private int workerHostWeight; // worker host weight
-    private int workerWaitingTaskCount; // worker waiting task count
-    private int workerExecThreadCount; // worker thread pool thread count
-
+    private double threadPoolUsage; // worker waiting task count
+    private String workerGroup;
 }
