@@ -28,8 +28,7 @@ import java.util.TimerTask;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.atomic.AtomicBoolean;
 
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import lombok.extern.slf4j.Slf4j;
 
 /**
  * A base class for running a Unix command.
@@ -38,11 +37,8 @@ import org.slf4j.LoggerFactory;
  * <code>df</code>. It also offers facilities to gate commands by 
  * time-intervals.
  */
+@Slf4j
 public abstract class AbstractShell {
-  
-    private static final Logger logger = LoggerFactory.getLogger(AbstractShell.class);
-  
-
 
     /**
      * Time after which the executing script would be timedout
@@ -79,11 +75,11 @@ public abstract class AbstractShell {
      * If or not script finished executing
      */
     private AtomicBoolean completed;
-  
+
     public AbstractShell() {
         this(0L);
     }
-  
+
     /**
      * @param interval the minimum duration to wait before re-executing the
      *        command.
@@ -145,7 +141,7 @@ public abstract class AbstractShell {
         if (timeOutInterval > 0) {
             timeOutTimer = new Timer();
             timeoutTimerTask = new ShellTimeoutTimerTask(this);
-            //One time scheduling.
+            // One time scheduling.
             timeOutTimer.schedule(timeoutTimerTask, timeOutInterval);
         }
         final BufferedReader errReader =
@@ -159,6 +155,7 @@ public abstract class AbstractShell {
         // read error and input streams as this would free up the buffers
         // free the error stream buffer
         Thread errThread = new Thread() {
+
             @Override
             public void run() {
                 try {
@@ -169,17 +166,18 @@ public abstract class AbstractShell {
                         line = errReader.readLine();
                     }
                 } catch (IOException ioe) {
-                    logger.warn("Error reading the error stream", ioe);
+                    log.warn("Error reading the error stream", ioe);
                 }
             }
         };
         Thread inThread = new Thread() {
+
             @Override
             public void run() {
                 try {
                     parseExecResult(inReader);
                 } catch (IOException ioe) {
-                    logger.warn("Error reading the in stream", ioe);
+                    log.warn("Error reading the in stream", ioe);
                 }
                 super.run();
             }
@@ -188,7 +186,7 @@ public abstract class AbstractShell {
             errThread.start();
             inThread.start();
         } catch (IllegalStateException ise) {
-            logger.warn("Illegal while starting the error and in thread", ise);
+            log.warn("Illegal while starting the error and in thread", ise);
         }
         try {
             // parse the output
@@ -198,11 +196,11 @@ public abstract class AbstractShell {
                 errThread.join();
                 inThread.join();
             } catch (InterruptedException ie) {
-                logger.warn("Interrupted while reading the error and in stream", ie);
+                log.warn("Interrupted while reading the error and in stream", ie);
             }
-            completed.compareAndSet(false,true);
-            //the timeout thread handling
-            //taken care in finally block
+            completed.compareAndSet(false, true);
+            // the timeout thread handling
+            // taken care in finally block
             if (exitCode != 0 || errMsg.length() > 0) {
                 throw new ExitCodeException(exitCode, errMsg.toString());
             }
@@ -216,7 +214,7 @@ public abstract class AbstractShell {
             try {
                 inReader.close();
             } catch (IOException ioe) {
-                logger.warn("Error while closing the input stream", ioe);
+                log.warn("Error while closing the input stream", ioe);
             }
             if (!completed.get()) {
                 errThread.interrupt();
@@ -224,7 +222,7 @@ public abstract class AbstractShell {
             try {
                 errReader.close();
             } catch (IOException ioe) {
-                logger.warn("Error while closing the error stream", ioe);
+                log.warn("Error while closing the error stream", ioe);
             }
             ProcessContainer.removeProcess(process);
             process.destroy();
@@ -237,7 +235,7 @@ public abstract class AbstractShell {
      * @return an array containing the command name and its parameters
      */
     protected abstract String[] getExecString();
-  
+
     /**
      * Parse the execution result
      * @param lines lines
@@ -285,9 +283,9 @@ public abstract class AbstractShell {
             try {
                 p.exitValue();
             } catch (Exception e) {
-                //Process has not terminated.
-                //So check if it has completed
-                //if not just destroy it.
+                // Process has not terminated.
+                // So check if it has completed
+                // if not just destroy it.
                 if (p != null && !shell.completed.get()) {
                     shell.setTimedOut();
                     p.destroy();
@@ -300,6 +298,7 @@ public abstract class AbstractShell {
      * This is an IOException with exit code added.
      */
     public static class ExitCodeException extends IOException {
+
         int exitCode;
 
         public ExitCodeException(int exitCode, String message) {
@@ -317,6 +316,7 @@ public abstract class AbstractShell {
      *
      */
     public static class ProcessContainer extends ConcurrentHashMap<Integer, Process> {
+
         private static final ProcessContainer container = new ProcessContainer();
 
         private ProcessContainer() {
@@ -345,11 +345,11 @@ public abstract class AbstractShell {
                 try {
                     entry.getValue().destroy();
                 } catch (Exception e) {
-                    logger.error("Destroy All Processes error", e);
+                    log.error("Destroy All Processes error", e);
                 }
             }
 
-            logger.info("close " + set.size() + " executing process tasks");
+            log.info("close " + set.size() + " executing process tasks");
         }
     }
 }
