@@ -44,8 +44,8 @@ public class ShellExecutor extends AbstractShell {
     }
 
     public ShellExecutor(String[] execString, File dir,
-                                Map<String, String> env) {
-        this(execString, dir, env,0L);
+                         Map<String, String> env) {
+        this(execString, dir, env, 0L);
     }
 
     /**
@@ -63,7 +63,7 @@ public class ShellExecutor extends AbstractShell {
      *                If 0, the command will not be timed out.
      */
     public ShellExecutor(String[] execString, File dir,
-                                Map<String, String> env, long timeout) {
+                         Map<String, String> env, long timeout) {
         command = execString.clone();
         if (dir != null) {
             setWorkingDirectory(dir);
@@ -113,8 +113,7 @@ public class ShellExecutor extends AbstractShell {
      * @return the output of the executed command.
      * @throws IOException errors
      */
-    public static String execCommand(Map<String,String> env, String... cmd)
-            throws IOException {
+    public static String execCommand(Map<String, String> env, String... cmd) throws IOException {
         return execCommand(env, cmd, 0L);
     }
 
@@ -138,7 +137,7 @@ public class ShellExecutor extends AbstractShell {
         int nRead;
         String line = "";
         while ((nRead = lines.read(buf, 0, buf.length)) > 0) {
-            line = new String(buf,0,nRead);
+            line = new String(buf, 0, nRead);
             output.append(line);
         }
     }
@@ -151,7 +150,6 @@ public class ShellExecutor extends AbstractShell {
         return (output == null) ? "" : output.toString();
     }
 
-
     /**
      * Returns the commands of this instance.
      * Arguments with spaces in are presented with quotes round; other
