@@ -14,20 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package org.apache.dolphinscheduler.common.utils;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 /**
  * encryption utils
  */
 public class EncryptionUtilsTest {
 
-
     @Test
     public void testGetMd5() {
-        Assert.assertEquals(EncryptionUtils.getMd5(null), EncryptionUtils.getMd5(""));
+        Assertions.assertEquals(EncryptionUtils.getMd5(null), EncryptionUtils.getMd5(""));
     }
 
 }
