@@ -18,6 +18,7 @@
 package org.apache.dolphinscheduler.dao.entity;
 
 import java.util.Date;
+import java.util.Objects;
 
 import lombok.Data;
 
@@ -73,7 +74,7 @@ public class AccessToken {
         }
         AccessToken that = (AccessToken) o;
 
-        if (id != that.id) {
+        if (!Objects.equals(id, that.id)) {
             return false;
         }
         if (userId != that.userId) {
