@@ -18,6 +18,7 @@
 package org.apache.dolphinscheduler.dao.entity;
 
 import java.util.Date;
+import java.util.Objects;
 
 import lombok.Data;
 
@@ -77,7 +78,7 @@ public class AlertGroup {
 
         AlertGroup that = (AlertGroup) o;
 
-        if (id != that.id) {
+        if (!Objects.equals(id, that.id)) {
             return false;
         }
         if (createUserId != that.createUserId) {
