@@ -44,17 +44,6 @@ public class K8sNamespace {
     @TableField(value = "namespace")
     private String namespace;
 
-    /**
-     * total cpu limit
-     */
-    @TableField(value = "limits_cpu")
-    private Double limitsCpu;
-
-    /**
-     * total memory limit,mi
-     */
-    private Integer limitsMemory;
-
     /**
      * owner
      */
@@ -79,24 +68,6 @@ public class K8sNamespace {
     @TableField("update_time")
     private Date updateTime;
 
-    /**
-     * 1.00 = 1 cpu
-     */
-    @TableField("pod_request_cpu")
-    private Double podRequestCpu = 0.0;
-
-    /**
-     * Mi
-     */
-    @TableField("pod_request_memory")
-    private Integer podRequestMemory = 0;
-
-    /**
-     * replicas
-     */
-    @TableField("pod_replicas")
-    private Integer podReplicas = 0;
-
     /**
      * cluster code
      */
