@@ -24,7 +24,10 @@ import org.apache.dolphinscheduler.common.enums.WarningType;
 
 import java.util.Date;
 
+import lombok.AllArgsConstructor;
+import lombok.Builder;
 import lombok.Data;
+import lombok.NoArgsConstructor;
 
 import com.baomidou.mybatisplus.annotation.IdType;
 import com.baomidou.mybatisplus.annotation.TableField;
@@ -32,43 +35,28 @@ import com.baomidou.mybatisplus.annotation.TableId;
 import com.baomidou.mybatisplus.annotation.TableName;
 
 @Data
+@Builder
+@NoArgsConstructor
+@AllArgsConstructor
 @TableName("t_ds_schedules")
 public class Schedule {
 
     @TableId(value = "id", type = IdType.AUTO)
     private Integer id;
 
-    /**
-     * process definition code
-     */
-    private long processDefinitionCode;
+    private long workflowDefinitionCode;
 
-    /**
-     * process definition name
-     */
     @TableField(exist = false)
-    private String processDefinitionName;
+    private String workflowDefinitionName;
 
-    /**
-     * project name
-     */
     @TableField(exist = false)
     private String projectName;
 
-    /**
-     * schedule description
-     */
     @TableField(exist = false)
     private String definitionDescription;
 
-    /**
-     * schedule start time
-     */
     private Date startTime;
 
-    /**
-     * schedule end time
-     */
     private Date endTime;
 
     /**
@@ -77,75 +65,33 @@ public class Schedule {
      */
     private String timezoneId;
 
-    /**
-     * crontab expression
-     */
     private String crontab;
 
-    /**
-     * failure strategy
-     */
     private FailureStrategy failureStrategy;
 
-    /**
-     * warning type
-     */
     private WarningType warningType;
 
-    /**
-     * create time
-     */
     private Date createTime;
 
-    /**
-     * update time
-     */
     private Date updateTime;
 
-    /**
-     * created user id
-     */
     private int userId;
 
-    /**
-     * created user name
-     */
     @TableField(exist = false)
     private String userName;
 
-    /**
-     * release state
-     */
     private ReleaseState releaseState;
 
-    /**
-     * warning group id
-     */
     private int warningGroupId;
 
-    /**
-     * process instance priority
-     */
-    private Priority processInstancePriority;
+    private Priority workflowInstancePriority;
 
-    /**
-     *  worker group
-     */
     private String workerGroup;
 
-    /**
-     * tenant code
-     */
     private String tenantCode;
 
-    /**
-     * environment code
-     */
     private Long environmentCode;
 
-    /**
-     * environment name
-     */
     @TableField(exist = false)
     private String environmentName;
 }
