@@ -62,6 +62,11 @@ public class TaskMainInfo {
      */
     private Date taskUpdateTime;
 
+    /**
+     * projectCode
+     */
+    private long projectCode;
+
     /**
      * processDefinitionCode
      */
