@@ -17,11 +17,6 @@
 
 package org.apache.dolphinscheduler.dao.mapper;
 
-import static org.hamcrest.Matchers.greaterThan;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertThat;
-
 import org.apache.dolphinscheduler.common.enums.AlertStatus;
 import org.apache.dolphinscheduler.common.enums.WarningType;
 import org.apache.dolphinscheduler.common.utils.DateUtils;
@@ -33,7 +28,8 @@ import org.apache.commons.codec.digest.DigestUtils;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.springframework.beans.factory.annotation.Autowired;
 
 /**
@@ -52,7 +48,7 @@ public class AlertMapperTest extends BaseDaoTest {
     @Test
     public void testInsert() {
         Alert expectedAlert = createAlert();
-        assertThat(expectedAlert.getId(), greaterThan(0));
+        Assertions.assertTrue(expectedAlert.getId() > 0);
     }
 
     /**
@@ -64,7 +60,7 @@ public class AlertMapperTest extends BaseDaoTest {
     public void testSelectById() {
         Alert expectedAlert = createAlert();
         Alert actualAlert = alertMapper.selectById(expectedAlert.getId());
-        assertEquals(expectedAlert, actualAlert);
+        Assertions.assertEquals(expectedAlert, actualAlert);
     }
 
     /**
@@ -83,7 +79,7 @@ public class AlertMapperTest extends BaseDaoTest {
 
         Alert actualAlert = alertMapper.selectById(expectedAlert.getId());
 
-        assertEquals(expectedAlert, actualAlert);
+        Assertions.assertEquals(expectedAlert, actualAlert);
     }
 
     /**
@@ -97,7 +93,7 @@ public class AlertMapperTest extends BaseDaoTest {
 
         Alert actualAlert = alertMapper.selectById(expectedAlert.getId());
 
-        assertNull(actualAlert);
+        Assertions.assertNull(actualAlert);
     }
 
     /**
