@@ -19,10 +19,10 @@ package org.apache.dolphinscheduler.dao.mapper;
 
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.dao.BaseDaoTest;
-import org.apache.dolphinscheduler.dao.entity.DefinitionGroupByUser;
-import org.apache.dolphinscheduler.dao.entity.ProcessTaskRelation;
 import org.apache.dolphinscheduler.dao.entity.TaskDefinition;
 import org.apache.dolphinscheduler.dao.entity.User;
+import org.apache.dolphinscheduler.dao.entity.WorkflowTaskRelation;
+import org.apache.dolphinscheduler.dao.model.WorkflowDefinitionCountDto;
 
 import java.util.Date;
 import java.util.List;
@@ -38,7 +38,7 @@ public class TaskDefinitionMapperTest extends BaseDaoTest {
     private TaskDefinitionMapper taskDefinitionMapper;
 
     @Autowired
-    private ProcessTaskRelationMapper processTaskRelationMapper;
+    private WorkflowTaskRelationMapper workflowTaskRelationMapper;
 
     @Autowired
     private UserMapper userMapper;
@@ -69,17 +69,17 @@ public class TaskDefinitionMapperTest extends BaseDaoTest {
      *
      * @return ProcessDefinition
      */
-    private ProcessTaskRelation insertTaskRelation(long postTaskCode) {
-        ProcessTaskRelation processTaskRelation = new ProcessTaskRelation();
-        processTaskRelation.setName("def 1");
-        processTaskRelation.setProjectCode(1L);
-        processTaskRelation.setProcessDefinitionCode(1L);
-        processTaskRelation.setPostTaskCode(postTaskCode);
-        processTaskRelation.setPreTaskCode(0L);
-        processTaskRelation.setUpdateTime(new Date());
-        processTaskRelation.setCreateTime(new Date());
-        processTaskRelationMapper.insert(processTaskRelation);
-        return processTaskRelation;
+    private WorkflowTaskRelation insertTaskRelation(long postTaskCode) {
+        WorkflowTaskRelation workflowTaskRelation = new WorkflowTaskRelation();
+        workflowTaskRelation.setName("def 1");
+        workflowTaskRelation.setProjectCode(1L);
+        workflowTaskRelation.setWorkflowDefinitionCode(1L);
+        workflowTaskRelation.setPostTaskCode(postTaskCode);
+        workflowTaskRelation.setPreTaskCode(0L);
+        workflowTaskRelation.setUpdateTime(new Date());
+        workflowTaskRelation.setCreateTime(new Date());
+        workflowTaskRelationMapper.insert(workflowTaskRelation);
+        return workflowTaskRelation;
     }
 
     @Test
@@ -91,9 +91,9 @@ public class TaskDefinitionMapperTest extends BaseDaoTest {
     @Test
     public void testQueryByDefinitionName() {
         TaskDefinition taskDefinition = insertOne();
-        ProcessTaskRelation processTaskRelation = insertTaskRelation(taskDefinition.getCode());
+        WorkflowTaskRelation workflowTaskRelation = insertTaskRelation(taskDefinition.getCode());
         TaskDefinition result = taskDefinitionMapper.queryByName(taskDefinition.getProjectCode(),
-                processTaskRelation.getProcessDefinitionCode(), taskDefinition.getName());
+                workflowTaskRelation.getWorkflowDefinitionCode(), taskDefinition.getName());
 
         Assertions.assertNotNull(result);
     }
@@ -107,10 +107,10 @@ public class TaskDefinitionMapperTest extends BaseDaoTest {
     }
 
     @Test
-    public void testQueryAllDefinitionList() {
+    public void testQueryAllTaskDefinitionWorkerGroups() {
         TaskDefinition taskDefinition = insertOne();
-        List<TaskDefinition> taskDefinitions =
-                taskDefinitionMapper.queryAllDefinitionList(taskDefinition.getProjectCode());
+        List<String> taskDefinitions =
+                taskDefinitionMapper.queryAllTaskDefinitionWorkerGroups(taskDefinition.getProjectCode());
         Assertions.assertNotEquals(0, taskDefinitions.size());
 
     }
@@ -123,33 +123,12 @@ public class TaskDefinitionMapperTest extends BaseDaoTest {
         User un = userMapper.queryByUserNameAccurately("un");
         TaskDefinition taskDefinition = insertOne(un.getId());
 
-        List<DefinitionGroupByUser> users =
+        List<WorkflowDefinitionCountDto> users =
                 taskDefinitionMapper.countDefinitionGroupByUser(new Long[]{taskDefinition.getProjectCode()});
         Assertions.assertNotEquals(0, users.size());
 
     }
 
-    @Test
-    public void testListResources() {
-        TaskDefinition taskDefinition = insertOne();
-        List<Map<String, Object>> maps = taskDefinitionMapper.listResources();
-        Assertions.assertNotEquals(0, maps.size());
-
-    }
-
-    @Test
-    public void testListResourcesByUser() {
-        User user = new User();
-        user.setUserName("un");
-        userMapper.insert(user);
-        User un = userMapper.queryByUserNameAccurately("un");
-        TaskDefinition taskDefinition = insertOne(un.getId());
-
-        List<Map<String, Object>> maps = taskDefinitionMapper.listResourcesByUser(taskDefinition.getUserId());
-        Assertions.assertNotEquals(0, maps.size());
-
-    }
-
     @Test
     public void testDeleteByCode() {
         TaskDefinition taskDefinition = insertOne();
