@@ -17,7 +17,6 @@
 
 package org.apache.dolphinscheduler.plugin.datasource.api.utils;
 
-import com.fasterxml.jackson.databind.JsonNode;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.plugin.datasource.api.datasource.BaseDataSourceParamDTO;
 import org.apache.dolphinscheduler.plugin.datasource.api.datasource.DataSourceProcessor;
@@ -28,16 +27,16 @@ import org.apache.dolphinscheduler.spi.enums.DbType;
 import java.sql.Connection;
 import java.util.Map;
 
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import lombok.extern.slf4j.Slf4j;
 
+import com.fasterxml.jackson.databind.JsonNode;
+
+@Slf4j
 public class DataSourceUtils {
 
     public DataSourceUtils() {
     }
 
-    private static final Logger logger = LoggerFactory.getLogger(DataSourceUtils.class);
-
     /**
      * check datasource param
      *
@@ -47,16 +46,8 @@ public class DataSourceUtils {
         getDatasourceProcessor(baseDataSourceParamDTO.getType()).checkDatasourceParam(baseDataSourceParamDTO);
     }
 
-    /**
-     * build connection url
-     *
-     * @param baseDataSourceParamDTO datasourceParam
-     */
     public static ConnectionParam buildConnectionParams(BaseDataSourceParamDTO baseDataSourceParamDTO) {
-        ConnectionParam connectionParams = getDatasourceProcessor(baseDataSourceParamDTO.getType())
-                .createConnectionParams(baseDataSourceParamDTO);
-        logger.info("parameters map:{}", connectionParams);
-        return connectionParams;
+        return getDatasourceProcessor(baseDataSourceParamDTO.getType()).createConnectionParams(baseDataSourceParamDTO);
     }
 
     public static ConnectionParam buildConnectionParams(DbType dbType, String connectionJson) {
@@ -84,7 +75,8 @@ public class DataSourceUtils {
     }
 
     public static DataSourceProcessor getDatasourceProcessor(DbType dbType) {
-        Map<String, DataSourceProcessor> dataSourceProcessorMap = DataSourceProcessorProvider.getInstance().getDataSourceProcessorMap();
+        Map<String, DataSourceProcessor> dataSourceProcessorMap =
+                DataSourceProcessorProvider.getDataSourceProcessorMap();
         if (!dataSourceProcessorMap.containsKey(dbType.name())) {
             throw new IllegalArgumentException("illegal datasource type");
         }
