@@ -19,6 +19,7 @@ package org.apache.dolphinscheduler.plugin.datasource.databend;
 
 import org.apache.dolphinscheduler.spi.datasource.DataSourceChannel;
 import org.apache.dolphinscheduler.spi.datasource.DataSourceChannelFactory;
+import org.apache.dolphinscheduler.spi.enums.DbType;
 
 import com.google.auto.service.AutoService;
 
@@ -27,7 +28,7 @@ public class DatabendDataSourceChannelFactory implements DataSourceChannelFactor
 
     @Override
     public String getName() {
-        return "databend";
+        return DbType.DATABEND.getName();
     }
 
     @Override
