@@ -19,6 +19,7 @@ package org.apache.dolphinscheduler.plugin.datasource.db2;
 
 import org.apache.dolphinscheduler.spi.datasource.DataSourceChannel;
 import org.apache.dolphinscheduler.spi.datasource.DataSourceChannelFactory;
+import org.apache.dolphinscheduler.spi.enums.DbType;
 
 import com.google.auto.service.AutoService;
 
@@ -27,7 +28,7 @@ public class DB2DataSourceChannelFactory implements DataSourceChannelFactory {
 
     @Override
     public String getName() {
-        return "db2";
+        return DbType.DB2.getName();
     }
 
     @Override
