@@ -19,8 +19,8 @@ package org.apache.dolphinscheduler.plugin.datasource.db2;
 
 import org.apache.dolphinscheduler.spi.datasource.DataSourceChannel;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 public class DB2DataSourceChannelFactoryTest {
 
@@ -28,6 +28,6 @@ public class DB2DataSourceChannelFactoryTest {
     public void testCreate() {
         DB2DataSourceChannelFactory sourceChannelFactory = new DB2DataSourceChannelFactory();
         DataSourceChannel dataSourceChannel = sourceChannelFactory.create();
-        Assert.assertNotNull(dataSourceChannel);
+        Assertions.assertNotNull(dataSourceChannel);
     }
 }
