@@ -23,6 +23,7 @@ import org.apache.dolphinscheduler.spi.enums.DbConnectType;
 import org.apache.dolphinscheduler.spi.enums.DbType;
 
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 
 import org.junit.jupiter.api.Assertions;
@@ -101,4 +102,69 @@ public class OracleDataSourceProcessorTest {
         Assertions.assertEquals(DataSourceConstants.ORACLE_VALIDATION_QUERY,
                 oracleDatasourceProcessor.getValidationQuery());
     }
+
+    @Test
+    void splitAndRemoveComment_PLSQL() {
+        String plSql = "DECLARE\n" +
+                "  bonus   NUMBER(8,2);\n" +
+                "BEGIN\n" +
+                "  SELECT salary * 0.10 INTO bonus\n" +
+                "  FROM employees\n" +
+                "  WHERE employee_id = 100;\n" +
+                "END;\n" +
+                "\n" +
+                "DBMS_OUTPUT.PUT_LINE('bonus = ' || TO_CHAR(bonus));\n";
+        List<String> sqls = oracleDatasourceProcessor.splitAndRemoveComment(plSql);
+        // We will not split the plsql
+        Assertions.assertEquals(2, sqls.size());
+        Assertions.assertEquals("DECLARE\n" +
+                "\tbonus NUMBER(8, 2);\n" +
+                "BEGIN\n" +
+                "\tSELECT salary * 0.10\n" +
+                "\tINTO bonus\n" +
+                "\tFROM employees\n" +
+                "\tWHERE employee_id = 100;\n" +
+                "END;", sqls.get(0));
+        Assertions.assertEquals("DBMS_OUTPUT.PUT_LINE('bonus = ' || TO_CHAR(bonus));", sqls.get(1));
+    }
+
+    @Test
+    void splitAndRemoveComment_PLSQLWithComment() {
+        String plSql = "DECLARE\n" +
+                "   CURSOR my_cursor IS SELECT column1, column2 FROM my_table;\n" +
+                "   -- Declare variables to hold column values\n" +
+                "BEGIN\n" +
+                "   OPEN my_cursor;\n" +
+                "   FETCH my_cursor INTO variable1, variable2;\n" +
+                "   -- Process data\n" +
+                "   CLOSE my_cursor;\n" +
+                "END;";
+        List<String> sqls = oracleDatasourceProcessor.splitAndRemoveComment(plSql);
+        // We will not split the plsql
+        Assertions.assertEquals(1, sqls.size());
+        Assertions.assertEquals("DECLARE\n" +
+                "\tCURSOR my_cursor IS\n" +
+                "\t\tSELECT column1, column2\n" +
+                "\t\tFROM my_table;\n" +
+                "BEGIN\n" +
+                "\tOPEN my_cursor;\n" +
+                "\tFETCH my_cursor INTO variable1, variable2;\n" +
+                "\tCLOSE my_cursor;\n" +
+                "END;", sqls.get(0));
+    }
+
+    @Test
+    void splitAndRemoveComment_MultipleSql() {
+        String plSql =
+                "select a,a-a as b from (select 1 as a,2 as b from dual) union all select 1 as a,2 as b from dual;select * from dual; -- this comment";
+        List<String> sqls = oracleDatasourceProcessor.splitAndRemoveComment(plSql);
+        // We will not split the plsql
+        Assertions.assertEquals(2, sqls.size());
+        System.out.println(sqls.get(0));
+        System.out.println(sqls.get(1));
+        Assertions.assertEquals(
+                "select a,a-a as b from (select 1 as a,2 as b from dual) union all select 1 as a,2 as b from dual",
+                sqls.get(0));
+        Assertions.assertEquals("select * from dual", sqls.get(1));
+    }
 }
