@@ -1,25 +1,26 @@
 /*
- * Licensed to Apache Software Foundation (ASF) under one or more contributor
- * license agreements. See the NOTICE file distributed with
- * this work for additional information regarding copyright
- * ownership. Apache Software Foundation (ASF) licenses this file to you under
- * the Apache License, Version 2.0 (the "License"); you may
- * not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *    http://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.dolphinscheduler.e2e.cases;
 
+import static org.assertj.core.api.Assertions.assertThat;
+
 import org.apache.dolphinscheduler.e2e.core.DolphinScheduler;
+import org.apache.dolphinscheduler.e2e.core.WebDriverWaitFactory;
 import org.apache.dolphinscheduler.e2e.pages.LoginPage;
 import org.apache.dolphinscheduler.e2e.pages.common.NavBarPage;
 import org.apache.dolphinscheduler.e2e.pages.project.ProjectDetailPage;
@@ -33,22 +34,25 @@ import org.apache.dolphinscheduler.e2e.pages.project.workflow.task.SubWorkflowTa
 import org.apache.dolphinscheduler.e2e.pages.security.SecurityPage;
 import org.apache.dolphinscheduler.e2e.pages.security.TenantPage;
 import org.apache.dolphinscheduler.e2e.pages.security.UserPage;
+
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Order;
 import org.junit.jupiter.api.Test;
+import org.junitpioneer.jupiter.DisableIfTestFails;
 import org.openqa.selenium.By;
 import org.openqa.selenium.remote.RemoteWebDriver;
 import org.openqa.selenium.support.ui.ExpectedConditions;
-import org.openqa.selenium.support.ui.WebDriverWait;
-
-import static org.assertj.core.api.Assertions.assertThat;
-import static org.awaitility.Awaitility.await;
+import org.testcontainers.shaded.org.awaitility.Awaitility;
 
 @DolphinScheduler(composeFiles = "docker/basic/docker-compose.yaml")
+@DisableIfTestFails
 class WorkflowE2ETest {
+
     private static final String project = "test-workflow-1";
 
+    private static final String workflow = "test-workflow-1";
+
     private static final String user = "admin";
 
     private static final String password = "dolphinscheduler123";
@@ -71,63 +75,60 @@ class WorkflowE2ETest {
                 .goToNav(SecurityPage.class)
                 .goToTab(UserPage.class);
 
-        new WebDriverWait(userPage.driver(), 20).until(ExpectedConditions.visibilityOfElementLocated(
+        WebDriverWaitFactory.createWebDriverWait(userPage.driver()).until(ExpectedConditions.visibilityOfElementLocated(
                 new By.ByClassName("name")));
 
         userPage.update(user, user, email, phone, tenant)
                 .goToNav(ProjectPage.class)
-                .create(project)
-        ;
+                .create(project);
     }
 
     @AfterAll
     public static void cleanup() {
         new NavBarPage(browser)
-            .goToNav(ProjectPage.class)
-            .goTo(project)
-            .goToTab(WorkflowDefinitionTab.class)
-            .cancelPublishAll()
-            .deleteAll()
-        ;
+                .goToNav(ProjectPage.class)
+                .goTo(project)
+                .goToTab(WorkflowDefinitionTab.class)
+                .delete(workflow);
+
         new NavBarPage(browser)
-            .goToNav(ProjectPage.class)
-            .delete(project)
-            .goToNav(SecurityPage.class)
-            .goToTab(TenantPage.class)
-            .delete(tenant)
-        ;
+                .goToNav(ProjectPage.class)
+                .delete(project);
+
+        browser.navigate().refresh();
+
+        new NavBarPage(browser)
+                .goToNav(SecurityPage.class)
+                .goToTab(TenantPage.class)
+                .delete(tenant);
     }
 
     @Test
     @Order(1)
     void testCreateWorkflow() {
-        final String workflow = "test-workflow-1";
         WorkflowDefinitionTab workflowDefinitionPage =
-            new ProjectPage(browser)
-                .goTo(project)
-                .goToTab(WorkflowDefinitionTab.class);
+                new ProjectPage(browser)
+                        .goTo(project)
+                        .goToTab(WorkflowDefinitionTab.class);
 
         workflowDefinitionPage
-            .createWorkflow()
+                .createWorkflow()
 
-            .<ShellTaskForm> addTask(TaskType.SHELL)
-            .script("echo ${today}\necho ${global_param}\n")
-            .name("test-1")
-            .addParam("today", "${system.datetime}")
-            .submit()
+                .<ShellTaskForm>addTask(TaskType.SHELL)
+                .script("echo ${today}\necho ${global_param}\n")
+                .name("test-1")
+                .addParam("today", "${system.datetime}")
+                .submit()
 
-            .submit()
-            .name(workflow)
-            .tenant(tenant)
-            .addGlobalParam("global_param", "hello world")
-            .submit()
-        ;
+                .submit()
+                .name(workflow)
+                .addGlobalParam("global_param", "hello world")
+                .submit();
 
-        await().untilAsserted(() -> assertThat(workflowDefinitionPage.workflowList())
+        Awaitility.await().untilAsserted(() -> assertThat(workflowDefinitionPage.workflowList())
                 .as("Workflow list should contain newly-created workflow")
                 .anyMatch(
-                        it -> it.getText().contains(workflow)
-                ));
+                        it -> it.getText().contains(workflow)));
         workflowDefinitionPage.publish(workflow);
     }
 
@@ -136,36 +137,32 @@ class WorkflowE2ETest {
     void testCreateSubWorkflow() {
         final String workflow = "test-sub-workflow-1";
         WorkflowDefinitionTab workflowDefinitionPage =
-            new ProjectPage(browser)
-                .goToNav(ProjectPage.class)
-                .goTo(project)
-                .goToTab(WorkflowDefinitionTab.class);
+                new ProjectPage(browser)
+                        .goToNav(ProjectPage.class)
+                        .goTo(project)
+                        .goToTab(WorkflowDefinitionTab.class);
 
         workflowDefinitionPage
-            .createWorkflow()
+                .createSubWorkflowTask()
 
-            .<SubWorkflowTaskForm> addTask(TaskType.SUB_PROCESS)
-            .childNode("test-workflow-1")
-            .name("test-sub-1")
-            .submit()
+                .<SubWorkflowTaskForm>addTask(TaskType.SUB_WORKFLOW)
+                .childNode("test-workflow-1")
+                .name("test-sub-1")
+                .submit()
 
-            .submit()
-            .name(workflow)
-            .tenant(tenant)
-            .addGlobalParam("global_param", "hello world")
-            .submit()
-        ;
+                .submit()
+                .name(workflow)
+                .addGlobalParam("global_param", "hello world")
+                .submit();
 
-        await().untilAsserted(() -> assertThat(
-            workflowDefinitionPage.workflowList()
-        ).anyMatch(it -> it.getText().contains(workflow)));
+        Awaitility.await().untilAsserted(() -> assertThat(
+                workflowDefinitionPage.workflowList()).anyMatch(it -> it.getText().contains(workflow)));
         workflowDefinitionPage.publish(workflow);
     }
 
     @Test
     @Order(30)
     void testRunWorkflow() {
-        final String workflow = "test-workflow-1";
         final ProjectDetailPage projectPage =
                 new ProjectPage(browser)
                         .goToNav(ProjectPage.class)
@@ -179,7 +176,7 @@ class WorkflowE2ETest {
                 .run(workflow)
                 .submit();
 
-        await().untilAsserted(() -> {
+        Awaitility.await().untilAsserted(() -> {
             browser.navigate().refresh();
 
             final Row row = projectPage
@@ -201,7 +198,7 @@ class WorkflowE2ETest {
                 .next()
                 .rerun();
 
-        await().untilAsserted(() -> {
+        Awaitility.await().untilAsserted(() -> {
             browser.navigate().refresh();
 
             final Row row = projectPage
