@@ -1,46 +1,38 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
+ *    http://www.apache.org/licenses/LICENSE-2.0
  *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.dolphinscheduler.e2e.pages.datasource;
 
-import lombok.Getter;
-
+import org.apache.dolphinscheduler.e2e.core.WebDriverWaitFactory;
 import org.apache.dolphinscheduler.e2e.pages.common.NavBarPage;
 
-import java.security.Key;
-import java.time.Duration;
 import java.util.List;
 
+import lombok.Getter;
+
 import org.openqa.selenium.By;
 import org.openqa.selenium.JavascriptExecutor;
 import org.openqa.selenium.Keys;
-import org.openqa.selenium.WebDriver;
 import org.openqa.selenium.WebElement;
 import org.openqa.selenium.remote.RemoteWebDriver;
 import org.openqa.selenium.support.FindBy;
 import org.openqa.selenium.support.FindBys;
 import org.openqa.selenium.support.PageFactory;
-import org.openqa.selenium.support.ui.ExpectedCondition;
 import org.openqa.selenium.support.ui.ExpectedConditions;
-import org.openqa.selenium.support.ui.WebDriverWait;
-
 
 @Getter
 public class DataSourcePage extends NavBarPage implements NavBarPage.NavBarItem {
@@ -57,9 +49,7 @@ public class DataSourcePage extends NavBarPage implements NavBarPage.NavBarItem
     })
     private WebElement buttonConfirm;
 
-    @FindBys({
-        @FindBy(className = "dialog-source-modal"),
-    })
+    @FindBy(className = "dialog-source-modal")
     private WebElement dataSourceModal;
 
     private final CreateDataSourceForm createDataSourceForm;
@@ -70,16 +60,19 @@ public class DataSourcePage extends NavBarPage implements NavBarPage.NavBarItem
         createDataSourceForm = new CreateDataSourceForm();
     }
 
-    public DataSourcePage createDataSource(String dataSourceType, String dataSourceName, String dataSourceDescription, String ip, String port, String userName, String password, String database,
+    public DataSourcePage createDataSource(String dataSourceType, String dataSourceName, String dataSourceDescription,
+                                           String ip, String port, String userName, String password, String database,
                                            String jdbcParams) {
         buttonCreateDataSource().click();
 
-        new WebDriverWait(driver, Duration.ofSeconds(10)).until(ExpectedConditions.visibilityOfElementLocated(
-            new By.ByClassName("dialog-source-modal")));
+        WebDriverWaitFactory.createWebDriverWait(driver).until(ExpectedConditions.visibilityOf(dataSourceModal));
+        WebElement dataSourceTypeButton = By.className(dataSourceType.toUpperCase() + "-box").findElement(driver);
+        WebDriverWaitFactory.createWebDriverWait(driver)
+                .until(ExpectedConditions.elementToBeClickable(dataSourceTypeButton));
+        dataSourceTypeButton.click();
 
-        dataSourceModal().findElement(By.className(dataSourceType.toUpperCase()+"-box")).click();
-
-        new WebDriverWait(driver, Duration.ofSeconds(10)).until(ExpectedConditions.textToBePresentInElement(driver.findElement(By.className("dialog-create-data-source")), dataSourceType.toUpperCase()));
+        WebDriverWaitFactory.createWebDriverWait(driver).until(ExpectedConditions.textToBePresentInElement(
+                driver.findElement(By.className("dialog-create-data-source")), dataSourceType.toUpperCase()));
 
         createDataSourceForm().inputDataSourceName().sendKeys(dataSourceName);
         createDataSourceForm().inputDataSourceDescription().sendKeys(dataSourceDescription);
@@ -89,7 +82,9 @@ public class DataSourcePage extends NavBarPage implements NavBarPage.NavBarItem
         createDataSourceForm().inputPort().sendKeys(port);
         createDataSourceForm().inputUserName().sendKeys(userName);
         createDataSourceForm().inputPassword().sendKeys(password);
-        createDataSourceForm().inputDataBase().sendKeys(database);
+        if (createDataSourceForm().inputDataBase().isDisplayed()) {
+            createDataSourceForm().inputDataBase().sendKeys(database);
+        }
 
         if (!"".equals(jdbcParams)) {
             createDataSourceForm().inputJdbcParams().sendKeys(jdbcParams);
@@ -102,13 +97,13 @@ public class DataSourcePage extends NavBarPage implements NavBarPage.NavBarItem
 
     public DataSourcePage delete(String name) {
         dataSourceItemsList()
-            .stream()
-            .filter(it -> it.getText().contains(name))
-            .flatMap(it -> it.findElements(By.className("btn-delete")).stream())
-            .filter(WebElement::isDisplayed)
-            .findFirst()
-            .orElseThrow(() -> new RuntimeException("No delete button in data source list"))
-            .click();
+                .stream()
+                .filter(it -> it.getText().contains(name))
+                .flatMap(it -> it.findElements(By.className("btn-delete")).stream())
+                .filter(WebElement::isDisplayed)
+                .findFirst()
+                .orElseThrow(() -> new RuntimeException("No delete button in data source list"))
+                .click();
 
         ((JavascriptExecutor) driver).executeScript("arguments[0].click();", buttonConfirm());
 
@@ -117,6 +112,7 @@ public class DataSourcePage extends NavBarPage implements NavBarPage.NavBarItem
 
     @Getter
     public class CreateDataSourceForm {
+
         CreateDataSourceForm() {
             PageFactory.initElements(driver, this);
         }
@@ -192,5 +188,12 @@ public class DataSourcePage extends NavBarPage implements NavBarPage.NavBarItem
                 @FindBy(tagName = "input"),
         })
         private WebElement inputZeppelinRestEndpoint;
+
+        @FindBys({
+                @FindBy(className = "input-kubeConfig"),
+                @FindBy(tagName = "textarea"),
+        })
+        private WebElement inputKubeConfig;
+
     }
 }
