@@ -19,6 +19,8 @@ package org.apache.dolphinscheduler.extract.master.command;
 
 import org.apache.dolphinscheduler.common.enums.CommandType;
 
+import java.util.List;
+
 import lombok.Data;
 import lombok.EqualsAndHashCode;
 import lombok.NoArgsConstructor;
@@ -35,4 +37,9 @@ public class RunWorkflowCommandParam extends AbstractCommandParam {
         return CommandType.START_PROCESS;
     }
 
+    public RunWorkflowCommandParam withStartNodes(List<Long> startNodes) {
+        this.startNodes = startNodes;
+        return this;
+    }
+
 }
