@@ -22,8 +22,11 @@
 -XX:+IgnoreUnrecognizedVMOptions
 -XX:+PrintGCDateStamps
 -XX:+PrintGCDetails
--Xloggc:gc.log
+-Xloggc:gc-%t.log
+-XX:ErrorFile=java_error-%p.log
 
+-XX:-OmitStackTraceInFastThrow
+-XX:+ExitOnOutOfMemoryError
 -XX:+HeapDumpOnOutOfMemoryError
 -XX:HeapDumpPath=dump.hprof
 
