@@ -71,4 +71,16 @@ public class SwitchTaskUtilsTest {
         });
 
     }
+
+    @Test
+    public void testIncludes() throws ScriptException {
+        String content = "['abc','def'].includes('abc')";
+        boolean result = SwitchTaskUtils.evaluate(content);
+        Assertions.assertTrue(result);
+
+        SwitchTaskUtils.evaluate(SwitchTaskUtils.NASHORN_POLYFILL_ARRAY_PROTOTYPE_INCLUDES);
+        result = SwitchTaskUtils.evaluate(content);
+        Assertions.assertTrue(result);
+    }
+
 }
