@@ -21,13 +21,11 @@ import java.time.Duration;
 
 import lombok.Data;
 
-import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
 import org.springframework.boot.context.properties.ConfigurationProperties;
 import org.springframework.context.annotation.Configuration;
 
 @Data
 @Configuration
-@ConditionalOnProperty(prefix = "registry", name = "type", havingValue = "etcd")
 @ConfigurationProperties(prefix = "registry")
 public class EtcdRegistryProperties {
 
@@ -35,6 +33,8 @@ public class EtcdRegistryProperties {
     private String namespace = "dolphinscheduler";
     private Duration connectionTimeout = Duration.ofSeconds(9);
 
+    private Duration ttl = Duration.ofSeconds(30);
+
     // auth
     private String user;
     private String password;
