@@ -17,14 +17,12 @@
 
 package org.apache.dolphinscheduler.plugin.registry.jdbc.mapper;
 
-import org.apache.dolphinscheduler.plugin.registry.jdbc.model.JdbcRegistryData;
+import org.apache.dolphinscheduler.plugin.registry.jdbc.model.DO.JdbcRegistryData;
 
 import org.apache.ibatis.annotations.Delete;
 import org.apache.ibatis.annotations.Param;
 import org.apache.ibatis.annotations.Select;
-import org.apache.ibatis.annotations.Update;
 
-import java.util.Collection;
 import java.util.List;
 
 import com.baomidou.mybatisplus.core.mapper.BaseMapper;
@@ -37,22 +35,17 @@ public interface JdbcRegistryDataMapper extends BaseMapper<JdbcRegistryData> {
     @Select("select * from t_ds_jdbc_registry_data where data_key = #{key}")
     JdbcRegistryData selectByKey(@Param("key") String key);
 
-    @Select("select * from t_ds_jdbc_registry_data where data_key like CONCAT (#{key}, '%')")
-    List<JdbcRegistryData> fuzzyQueryByKey(@Param("key") String key);
-
     @Delete("delete from t_ds_jdbc_registry_data where data_key = #{key}")
     void deleteByKey(@Param("key") String key);
 
-    @Delete("delete from t_ds_jdbc_registry_data where last_term < #{term} and data_type = #{type}")
-    void clearExpireEphemeralDate(@Param("term") long term, @Param("type") int type);
-
-    @Update({"<script>",
-            "update t_ds_jdbc_registry_data",
-            "set last_term = #{term}",
-            "where id IN ",
-            "<foreach item='id' index='index' collection='ids' open='(' separator=',' close=')'>",
-            "   #{id}",
+    @Delete({"<script>",
+            "delete from t_ds_jdbc_registry_data",
+            "where client_id IN ",
+            "<foreach item='clientId' index='index' collection='clientIds' open='(' separator=',' close=')'>",
+            "   #{clientId}",
             "</foreach>",
+            "and data_type = #{dataType}",
             "</script>"})
-    int updateTermByIds(@Param("ids") Collection<Long> ids, @Param("term") long term);
+    void deleteByClientIds(@Param("clientIds") List<Long> clientIds, @Param("dataType") String dataType);
+
 }
