@@ -20,17 +20,16 @@ package org.apache.dolphinscheduler.plugin.registry.zookeeper;
 import static java.util.concurrent.TimeUnit.MILLISECONDS;
 
 import org.apache.dolphinscheduler.registry.api.ConnectionListener;
-import org.apache.dolphinscheduler.registry.api.Event;
 import org.apache.dolphinscheduler.registry.api.Registry;
 import org.apache.dolphinscheduler.registry.api.RegistryException;
 import org.apache.dolphinscheduler.registry.api.SubscribeListener;
 
+import org.apache.commons.lang3.time.DurationUtils;
+import org.apache.commons.lang3.time.StopWatch;
 import org.apache.curator.framework.CuratorFramework;
 import org.apache.curator.framework.CuratorFrameworkFactory;
 import org.apache.curator.framework.api.ACLProvider;
-import org.apache.curator.framework.recipes.cache.ChildData;
 import org.apache.curator.framework.recipes.cache.TreeCache;
-import org.apache.curator.framework.recipes.cache.TreeCacheEvent;
 import org.apache.curator.framework.recipes.locks.InterProcessMutex;
 import org.apache.curator.retry.ExponentialBackoffRetry;
 import org.apache.curator.utils.CloseableUtils;
@@ -45,20 +44,16 @@ import java.util.Comparator;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.concurrent.ConcurrentHashMap;
 
-import javax.annotation.PostConstruct;
-
 import lombok.NonNull;
-
-import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
-import org.springframework.stereotype.Component;
+import lombok.extern.slf4j.Slf4j;
 
 import com.google.common.base.Strings;
 
-@Component
-@ConditionalOnProperty(prefix = "registry", name = "type", havingValue = "zookeeper")
-public final class ZookeeperRegistry implements Registry {
+@Slf4j
+final class ZookeeperRegistry implements Registry {
 
     private final ZookeeperRegistryProperties.ZookeeperProperties properties;
     private final CuratorFramework client;
@@ -67,7 +62,7 @@ public final class ZookeeperRegistry implements Registry {
 
     private static final ThreadLocal<Map<String, InterProcessMutex>> threadLocalLockMap = new ThreadLocal<>();
 
-    public ZookeeperRegistry(ZookeeperRegistryProperties registryProperties) {
+    ZookeeperRegistry(ZookeeperRegistryProperties registryProperties) {
         properties = registryProperties.getZookeeper();
 
         final ExponentialBackoffRetry retryPolicy = new ExponentialBackoffRetry(
@@ -80,40 +75,42 @@ public final class ZookeeperRegistry implements Registry {
                         .connectString(properties.getConnectString())
                         .retryPolicy(retryPolicy)
                         .namespace(properties.getNamespace())
-                        .sessionTimeoutMs((int) properties.getSessionTimeout().toMillis())
-                        .connectionTimeoutMs((int) properties.getConnectionTimeout().toMillis());
+                        .sessionTimeoutMs(DurationUtils.toMillisInt(properties.getSessionTimeout()))
+                        .connectionTimeoutMs(DurationUtils.toMillisInt(properties.getConnectionTimeout()));
 
         final String digest = properties.getDigest();
         if (!Strings.isNullOrEmpty(digest)) {
-            buildDigest(builder, digest);
+            builder.authorization("digest", digest.getBytes(StandardCharsets.UTF_8))
+                    .aclProvider(new ACLProvider() {
+
+                        @Override
+                        public List<ACL> getDefaultAcl() {
+                            return ZooDefs.Ids.CREATOR_ALL_ACL;
+                        }
+
+                        @Override
+                        public List<ACL> getAclForPath(final String path) {
+                            return ZooDefs.Ids.CREATOR_ALL_ACL;
+                        }
+                    });
         }
         client = builder.build();
     }
 
-    private void buildDigest(CuratorFrameworkFactory.Builder builder, String digest) {
-        builder.authorization("digest", digest.getBytes(StandardCharsets.UTF_8))
-                .aclProvider(new ACLProvider() {
-
-                    @Override
-                    public List<ACL> getDefaultAcl() {
-                        return ZooDefs.Ids.CREATOR_ALL_ACL;
-                    }
-
-                    @Override
-                    public List<ACL> getAclForPath(final String path) {
-                        return ZooDefs.Ids.CREATOR_ALL_ACL;
-                    }
-                });
-    }
-
-    @PostConstruct
+    @Override
     public void start() {
+        final StopWatch stopWatch = StopWatch.createStarted();
         client.start();
         try {
-            if (!client.blockUntilConnected((int) properties.getBlockUntilConnected().toMillis(), MILLISECONDS)) {
+            if (!client.blockUntilConnected(DurationUtils.toMillisInt(properties.getBlockUntilConnected()),
+                    MILLISECONDS)) {
                 client.close();
-                throw new RegistryException("zookeeper connect timeout: " + properties.getConnectString());
+                throw new RegistryException(
+                        "zookeeper connect failed to: " + properties.getConnectString() + " in : "
+                                + properties.getBlockUntilConnected().toMillis() + "ms");
             }
+            stopWatch.stop();
+            log.info("ZookeeperRegistry started at: {}/ms", stopWatch.getTime());
         } catch (InterruptedException e) {
             Thread.currentThread().interrupt();
             throw new RegistryException("Zookeeper registry start failed", e);
@@ -128,35 +125,29 @@ public final class ZookeeperRegistry implements Registry {
     @Override
     public void connectUntilTimeout(@NonNull Duration timeout) throws RegistryException {
         try {
-            if (!client.blockUntilConnected((int) timeout.toMillis(), MILLISECONDS)) {
+            if (!client.blockUntilConnected(DurationUtils.toMillisInt(timeout), MILLISECONDS)) {
                 throw new RegistryException(
-                        String.format("Cannot connect to the Zookeeper registry in %s s", timeout.getSeconds()));
+                        String.format("Cannot connect to registry in %s s", timeout.getSeconds()));
             }
         } catch (RegistryException e) {
             throw e;
         } catch (InterruptedException e) {
             Thread.currentThread().interrupt();
             throw new RegistryException(
-                    String.format("Cannot connect to the Zookeeper registry in %s s", timeout.getSeconds()), e);
+                    String.format("Cannot connect to registry in %s s", timeout.getSeconds()), e);
         }
     }
 
     @Override
-    public boolean subscribe(String path, SubscribeListener listener) {
+    public void subscribe(final String path, final SubscribeListener listener) {
         final TreeCache treeCache = treeCacheMap.computeIfAbsent(path, $ -> new TreeCache(client, path));
-        treeCache.getListenable().addListener(($, event) -> listener.notify(new EventAdaptor(event, path)));
+        treeCache.getListenable().addListener(new ZookeeperTreeCacheListenerAdapter(path, listener));
         try {
             treeCache.start();
         } catch (Exception e) {
             treeCacheMap.remove(path);
             throw new RegistryException("Failed to subscribe listener for key: " + path, e);
         }
-        return true;
-    }
-
-    @Override
-    public void unsubscribe(String path) {
-        CloseableUtils.closeQuietly(treeCacheMap.get(path));
     }
 
     @Override
@@ -218,17 +209,60 @@ public final class ZookeeperRegistry implements Registry {
 
     @Override
     public boolean acquireLock(String key) {
-        InterProcessMutex interProcessMutex = new InterProcessMutex(client, key);
+        Map<String, InterProcessMutex> processMutexMap = threadLocalLockMap.get();
+        if (null == processMutexMap) {
+            processMutexMap = new HashMap<>();
+            threadLocalLockMap.set(processMutexMap);
+        }
+        InterProcessMutex interProcessMutex = null;
         try {
-            interProcessMutex.acquire();
-            if (null == threadLocalLockMap.get()) {
-                threadLocalLockMap.set(new HashMap<>(3));
+            interProcessMutex =
+                    Optional.ofNullable(processMutexMap.get(key)).orElse(new InterProcessMutex(client, key));
+            if (interProcessMutex.isAcquiredInThisProcess()) {
+                // Since etcd/jdbc cannot implement a reentrant lock, we need to check if the lock is already acquired
+                // If it is already acquired, return true directly
+                // This means you only need to release once when you acquire multiple times
+                return true;
             }
-            threadLocalLockMap.get().put(key, interProcessMutex);
+            interProcessMutex.acquire();
+            processMutexMap.put(key, interProcessMutex);
             return true;
         } catch (Exception e) {
             try {
-                interProcessMutex.release();
+                if (interProcessMutex != null) {
+                    interProcessMutex.release();
+                }
+                throw new RegistryException(String.format("zookeeper get lock: %s error", key), e);
+            } catch (Exception exception) {
+                throw new RegistryException(String.format("zookeeper get lock: %s error", key), e);
+            }
+        }
+    }
+
+    @Override
+    public boolean acquireLock(String key, long timeout) {
+        Map<String, InterProcessMutex> processMutexMap = threadLocalLockMap.get();
+        if (null == processMutexMap) {
+            processMutexMap = new HashMap<>();
+            threadLocalLockMap.set(processMutexMap);
+        }
+        InterProcessMutex interProcessMutex = null;
+        try {
+            interProcessMutex =
+                    Optional.ofNullable(processMutexMap.get(key)).orElse(new InterProcessMutex(client, key));
+            if (interProcessMutex.isAcquiredInThisProcess()) {
+                return true;
+            }
+            if (interProcessMutex.acquire(timeout, MILLISECONDS)) {
+                processMutexMap.put(key, interProcessMutex);
+                return true;
+            }
+            return false;
+        } catch (Exception e) {
+            try {
+                if (interProcessMutex != null) {
+                    interProcessMutex.release();
+                }
                 throw new RegistryException(String.format("zookeeper get lock: %s error", key), e);
             } catch (Exception exception) {
                 throw new RegistryException(String.format("zookeeper get lock: %s error", key), e);
@@ -238,13 +272,18 @@ public final class ZookeeperRegistry implements Registry {
 
     @Override
     public boolean releaseLock(String key) {
-        if (null == threadLocalLockMap.get().get(key)) {
+        Map<String, InterProcessMutex> processMutexMap = threadLocalLockMap.get();
+        if (processMutexMap == null) {
+            return true;
+        }
+        InterProcessMutex interProcessMutex = processMutexMap.get(key);
+        if (null == interProcessMutex) {
             return false;
         }
         try {
-            threadLocalLockMap.get().get(key).release();
-            threadLocalLockMap.get().remove(key);
-            if (threadLocalLockMap.get().isEmpty()) {
+            interProcessMutex.release();
+            processMutexMap.remove(key);
+            if (processMutexMap.isEmpty()) {
                 threadLocalLockMap.remove();
             }
         } catch (Exception e) {
@@ -253,36 +292,14 @@ public final class ZookeeperRegistry implements Registry {
         return true;
     }
 
+    @Override
+    public boolean isConnected() {
+        return client.getZookeeperClient().isConnected();
+    }
+
     @Override
     public void close() {
         treeCacheMap.values().forEach(CloseableUtils::closeQuietly);
         CloseableUtils.closeQuietly(client);
     }
-
-    static final class EventAdaptor extends Event {
-
-        public EventAdaptor(TreeCacheEvent event, String key) {
-            key(key);
-
-            switch (event.getType()) {
-                case NODE_ADDED:
-                    type(Type.ADD);
-                    break;
-                case NODE_UPDATED:
-                    type(Type.UPDATE);
-                    break;
-                case NODE_REMOVED:
-                    type(Type.REMOVE);
-                    break;
-                default:
-                    break;
-            }
-
-            final ChildData data = event.getData();
-            if (data != null) {
-                path(data.getPath());
-                data(new String(data.getData()));
-            }
-        }
-    }
 }
