@@ -18,8 +18,8 @@
 package org.apache.dolphinscheduler.service.expand;
 
 import org.apache.dolphinscheduler.common.enums.CommandType;
-import org.apache.dolphinscheduler.dao.entity.ProcessInstance;
 import org.apache.dolphinscheduler.dao.entity.TaskInstance;
+import org.apache.dolphinscheduler.dao.entity.WorkflowInstance;
 import org.apache.dolphinscheduler.plugin.task.api.model.Property;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.AbstractParameters;
 
@@ -27,26 +27,12 @@ import java.util.Date;
 import java.util.List;
 import java.util.Map;
 
+import javax.annotation.Nullable;
+
 import lombok.NonNull;
 
 public interface CuringParamsService {
 
-    /**
-     * time function need expand
-     * @param placeholderName
-     * @return
-     */
-    boolean timeFunctionNeedExpand(String placeholderName);
-
-    /**
-     * time function extension
-     * @param processInstanceId
-     * @param timezone
-     * @param placeholderName
-     * @return
-     */
-    String timeFunctionExtension(Integer processInstanceId, String timezone, String placeholderName);
-
     /**
      * convert parameter placeholders
      * @param val
@@ -57,7 +43,7 @@ public interface CuringParamsService {
 
     /**
      * curing global params
-     * @param processInstanceId
+     * @param workflowInstanceId
      * @param globalParamMap
      * @param globalParamList
      * @param commandType
@@ -65,7 +51,7 @@ public interface CuringParamsService {
      * @param timezone
      * @return
      */
-    String curingGlobalParams(Integer processInstanceId, Map<String, String> globalParamMap,
+    String curingGlobalParams(Integer workflowInstanceId, Map<String, String> globalParamMap,
                               List<Property> globalParamList, CommandType commandType, Date scheduleTime,
                               String timezone);
 
@@ -73,19 +59,33 @@ public interface CuringParamsService {
      * param parsing preparation
      * @param parameters
      * @param taskInstance
-     * @param processInstance
+     * @param workflowInstance
+     * @param projectName
+     * @param workflowDefinitionName
      * @return
      */
     Map<String, Property> paramParsingPreparation(@NonNull TaskInstance taskInstance,
                                                   @NonNull AbstractParameters parameters,
-                                                  @NonNull ProcessInstance processInstance);
+                                                  @NonNull WorkflowInstance workflowInstance,
+                                                  String projectName,
+                                                  String workflowDefinitionName);
+
+    /**
+     * Parse workflow star parameter
+     */
+    Map<String, Property> parseWorkflowStartParam(@Nullable Map<String, String> cmdParam);
+
+    /**
+     * Parse workflow father parameter
+     */
+    Map<String, Property> parseWorkflowFatherParam(@Nullable Map<String, String> cmdParam);
 
     /**
      * preBuildBusinessParams
-     * @param processInstance
+     * @param workflowInstance
      * @return
      */
-    Map<String, Property> preBuildBusinessParams(ProcessInstance processInstance);
+    Map<String, Property> preBuildBusinessParams(WorkflowInstance workflowInstance);
 
     Map<String, Property> getProjectParameterMap(long projectCode);
 }
