@@ -30,8 +30,8 @@ import java.time.ZoneId;
 import java.time.ZonedDateTime;
 import java.util.Date;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -61,16 +61,15 @@ public class CronUtilsTest {
     @Test
     public void testCronAsString() {
         Cron cron = CronBuilder.cron(CronDefinitionBuilder.instanceDefinitionFor(CronType.QUARTZ)).withYear(always())
-            .withDoW(questionMark()).withMonth(always()).withDoM(always()).withHour(always()).withMinute(every(5))
-            .withSecond(on(0)).instance();
+                .withDoW(questionMark()).withMonth(always()).withDoM(always()).withHour(always()).withMinute(every(5))
+                .withSecond(on(0)).instance();
         // Obtain the string expression
         String cronAsString = cron.asString();
 
-        // 0 */5 * * * ? *  Every five minutes(once every 5 minutes)
-        Assert.assertEquals("0 */5 * * * ? *", cronAsString);
+        // 0 */5 * * * ? * Every five minutes(once every 5 minutes)
+        Assertions.assertEquals("0 */5 * * * ? *", cronAsString);
     }
 
-
     /**
      * cron parse test
      */
@@ -79,12 +78,12 @@ public class CronUtilsTest {
         String strCrontab = "0 1 2 3 * ? *";
 
         Cron depCron = CronUtils.parse2Cron(strCrontab);
-        Assert.assertEquals("0", depCron.retrieve(CronFieldName.SECOND).getExpression().asString());
-        Assert.assertEquals("1", depCron.retrieve(CronFieldName.MINUTE).getExpression().asString());
-        Assert.assertEquals("2", depCron.retrieve(CronFieldName.HOUR).getExpression().asString());
-        Assert.assertEquals("3", depCron.retrieve(CronFieldName.DAY_OF_MONTH).getExpression().asString());
-        Assert.assertEquals("*", depCron.retrieve(CronFieldName.MONTH).getExpression().asString());
-        Assert.assertEquals("*", depCron.retrieve(CronFieldName.YEAR).getExpression().asString());
+        Assertions.assertEquals("0", depCron.retrieve(CronFieldName.SECOND).getExpression().asString());
+        Assertions.assertEquals("1", depCron.retrieve(CronFieldName.MINUTE).getExpression().asString());
+        Assertions.assertEquals("2", depCron.retrieve(CronFieldName.HOUR).getExpression().asString());
+        Assertions.assertEquals("3", depCron.retrieve(CronFieldName.DAY_OF_MONTH).getExpression().asString());
+        Assertions.assertEquals("*", depCron.retrieve(CronFieldName.MONTH).getExpression().asString());
+        Assertions.assertEquals("*", depCron.retrieve(CronFieldName.YEAR).getExpression().asString());
     }
 
     /**
@@ -93,27 +92,27 @@ public class CronUtilsTest {
     @Test
     public void testScheduleType() throws CronParseException {
         CycleEnum cycleEnum = CronUtils.getMaxCycle(CronUtils.parse2Cron("0 */1 * * * ? *"));
-        Assert.assertEquals("MINUTE", cycleEnum.name());
+        Assertions.assertEquals("MINUTE", cycleEnum.name());
 
         CycleEnum cycleEnum2 = CronUtils.getMaxCycle("0 * * * * ? *");
-        Assert.assertEquals("MINUTE", cycleEnum2.name());
+        Assertions.assertEquals("MINUTE", cycleEnum2.name());
 
         CycleEnum cycleEnum3 = CronUtils.getMiniCycle(CronUtils.parse2Cron("0 * * * * ? *"));
-        Assert.assertEquals("MINUTE", cycleEnum3.name());
+        Assertions.assertEquals("MINUTE", cycleEnum3.name());
 
         CycleEnum cycleEnum4 = CronUtils.getMaxCycle(CronUtils.parse2Cron("0 0 7 * 1 ? *"));
-        Assert.assertEquals("YEAR", cycleEnum4.name());
+        Assertions.assertEquals("YEAR", cycleEnum4.name());
         cycleEnum4 = CronUtils.getMiniCycle(CronUtils.parse2Cron("0 0 7 * 1 ? *"));
-        Assert.assertEquals("DAY", cycleEnum4.name());
+        Assertions.assertEquals("DAY", cycleEnum4.name());
 
         CycleEnum cycleEnum5 = CronUtils.getMaxCycle(CronUtils.parse2Cron("0 0 7 * 1/1 ? *"));
-        Assert.assertEquals("MONTH", cycleEnum5.name());
+        Assertions.assertEquals("MONTH", cycleEnum5.name());
 
         CycleEnum cycleEnum6 = CronUtils.getMaxCycle(CronUtils.parse2Cron("0 0 7 * 1-2 ? *"));
-        Assert.assertEquals("YEAR", cycleEnum6.name());
+        Assertions.assertEquals("YEAR", cycleEnum6.name());
 
         CycleEnum cycleEnum7 = CronUtils.getMaxCycle(CronUtils.parse2Cron("0 0 7 * 1,2 ? *"));
-        Assert.assertEquals("YEAR", cycleEnum7.name());
+        Assertions.assertEquals("YEAR", cycleEnum7.name());
     }
 
     /**
@@ -122,12 +121,12 @@ public class CronUtilsTest {
     @Test
     public void test2() throws CronParseException {
         Cron cron1 = CronBuilder.cron(CronDefinitionBuilder.instanceDefinitionFor(CronType.QUARTZ)).withYear(always())
-            .withDoW(questionMark()).withMonth(always()).withDoM(always()).withHour(always()).withMinute(every(5))
-            .withSecond(on(0)).instance();
+                .withDoW(questionMark()).withMonth(always()).withDoM(always()).withHour(always()).withMinute(every(5))
+                .withSecond(on(0)).instance();
         // minute cycle
         String[] cronArayy =
-            new String[] {"* * * * * ? *", "* 0 * * * ? *", "* 5 * * 3/5 ? *", "0 0 * * * ? *", "0 0 7 * 1 ? *",
-                "0 0 7 * 1/1 ? *", "0 0 7 * 1-2 ? *", "0 0 7 * 1,2 ? *"};
+                new String[]{"* * * * * ? *", "* 0 * * * ? *", "* 5 * * 3/5 ? *", "0 0 * * * ? *", "0 0 7 * 1 ? *",
+                        "0 0 7 * 1/1 ? *", "0 0 7 * 1-2 ? *", "0 0 7 * 1,2 ? *"};
         for (String minCrontab : cronArayy) {
             Cron cron = CronUtils.parse2Cron(minCrontab);
             CronField minField = cron.retrieve(CronFieldName.MINUTE);
@@ -150,7 +149,8 @@ public class CronUtilsTest {
             logger.info("dayOfMonthField instanceof On:" + (dayOfMonthField.getExpression() instanceof On));
             logger.info("dayOfMonthField instanceof And:" + (dayOfMonthField.getExpression() instanceof And));
             logger.info(
-                "dayOfMonthField instanceof QuestionMark:" + (dayOfMonthField.getExpression() instanceof QuestionMark));
+                    "dayOfMonthField instanceof QuestionMark:"
+                            + (dayOfMonthField.getExpression() instanceof QuestionMark));
 
             CronField monthField = cron.retrieve(CronFieldName.MONTH);
             logger.info("monthField instanceof Between:" + (monthField.getExpression() instanceof Between));
@@ -167,7 +167,8 @@ public class CronUtilsTest {
             logger.info("dayOfWeekField instanceof On:" + (dayOfWeekField.getExpression() instanceof On));
             logger.info("dayOfWeekField instanceof And:" + (dayOfWeekField.getExpression() instanceof And));
             logger.info(
-                "dayOfWeekField instanceof QuestionMark:" + (dayOfWeekField.getExpression() instanceof QuestionMark));
+                    "dayOfWeekField instanceof QuestionMark:"
+                            + (dayOfWeekField.getExpression() instanceof QuestionMark));
 
             CronField yearField = cron.retrieve(CronFieldName.YEAR);
             logger.info("yearField instanceof Between:" + (yearField.getExpression() instanceof Between));
@@ -184,63 +185,70 @@ public class CronUtilsTest {
                 logger.info("can't get scheduleType");
             }
         }
-        Assert.assertTrue(true);
+        Assertions.assertTrue(true);
     }
 
     @Test
     public void getSelfFireDateList() throws CronParseException {
         ZonedDateTime from =
-            ZonedDateTime.ofInstant(DateUtils.stringToDate("2020-01-01 00:00:00").toInstant(), ZoneId.systemDefault());
+                ZonedDateTime.ofInstant(DateUtils.stringToDate("2020-01-01 00:00:00").toInstant(),
+                        ZoneId.systemDefault());
         ZonedDateTime to =
-            ZonedDateTime.ofInstant(DateUtils.stringToDate("2020-01-31 00:00:00").toInstant(), ZoneId.systemDefault());
+                ZonedDateTime.ofInstant(DateUtils.stringToDate("2020-01-31 00:00:00").toInstant(),
+                        ZoneId.systemDefault());
         // test date
-        Assert.assertEquals(0, CronUtils.getFireDateList(to, from, "0 0 0 * * ? ").size());
+        Assertions.assertEquals(0, CronUtils.getFireDateList(to, from, "0 0 0 * * ? ").size());
         try {
             // test error cron
             // should throw exception
             CronUtils.getFireDateList(from, to, "0 0 0 * *").size();
-            Assert.assertTrue(false);
+            Assertions.fail();
         } catch (CronParseException cronParseException) {
-            Assert.assertTrue(true);
+            Assertions.assertTrue(true);
         }
         // test cron
-        Assert.assertEquals(30, CronUtils.getFireDateList(from, to, "0 0 0 * * ? ").size());
+        Assertions.assertEquals(30, CronUtils.getFireDateList(from, to, "0 0 0 * * ? ").size());
         // test other
-        Assert.assertEquals(30, CronUtils.getFireDateList(from, to, CronUtils.parse2Cron("0 0 0 * * ? ")).size());
-        Assert.assertEquals(5, CronUtils.getSelfFireDateList(from, to, CronUtils.parse2Cron("0 0 0 * * ? "), 5).size());
+        Assertions.assertEquals(30, CronUtils.getFireDateList(from, to, CronUtils.parse2Cron("0 0 0 * * ? ")).size());
+        Assertions.assertEquals(5,
+                CronUtils.getSelfFireDateList(from, to, CronUtils.parse2Cron("0 0 0 * * ? "), 5).size());
         from =
-            ZonedDateTime.ofInstant(DateUtils.stringToDate("2020-01-01 00:02:00").toInstant(), ZoneId.systemDefault());
+                ZonedDateTime.ofInstant(DateUtils.stringToDate("2020-01-01 00:02:00").toInstant(),
+                        ZoneId.systemDefault());
         to = ZonedDateTime.ofInstant(DateUtils.stringToDate("2020-01-01 00:02:00").toInstant(), ZoneId.systemDefault());
-        Assert.assertEquals(1,
-            CronUtils.getFireDateList(from.minusSeconds(1L), to, CronUtils.parse2Cron("0 * * * * ? ")).size());
+        Assertions.assertEquals(1,
+                CronUtils.getFireDateList(from.minusSeconds(1L), to, CronUtils.parse2Cron("0 * * * * ? ")).size());
 
         from =
-            ZonedDateTime.ofInstant(DateUtils.stringToDate("2020-01-01 00:02:00").toInstant(), ZoneId.systemDefault());
+                ZonedDateTime.ofInstant(DateUtils.stringToDate("2020-01-01 00:02:00").toInstant(),
+                        ZoneId.systemDefault());
         to = ZonedDateTime.ofInstant(DateUtils.stringToDate("2020-01-01 00:04:00").toInstant(),
-            ZoneId.systemDefault());
-        Assert.assertEquals(2,
-            CronUtils.getFireDateList(from.minusSeconds(1L), to.minusSeconds(1L), CronUtils.parse2Cron("0 * * * * ? "))
-                .size());
+                ZoneId.systemDefault());
+        Assertions.assertEquals(2,
+                CronUtils
+                        .getFireDateList(from.minusSeconds(1L), to.minusSeconds(1L),
+                                CronUtils.parse2Cron("0 * * * * ? "))
+                        .size());
     }
 
     @Test
     public void getExpirationTime() {
         Date startTime = DateUtils.stringToDate("2020-02-07 18:30:00");
         Date expirationTime = CronUtils.getExpirationTime(startTime, CycleEnum.HOUR);
-        Assert.assertEquals("2020-02-07 19:30:00", DateUtils.dateToString(expirationTime));
+        Assertions.assertEquals("2020-02-07 19:30:00", DateUtils.dateToString(expirationTime));
         expirationTime = CronUtils.getExpirationTime(startTime, CycleEnum.DAY);
-        Assert.assertEquals("2020-02-07 23:59:59", DateUtils.dateToString(expirationTime));
+        Assertions.assertEquals("2020-02-07 23:59:59", DateUtils.dateToString(expirationTime));
         expirationTime = CronUtils.getExpirationTime(startTime, CycleEnum.WEEK);
-        Assert.assertEquals("2020-02-07 23:59:59", DateUtils.dateToString(expirationTime));
+        Assertions.assertEquals("2020-02-07 23:59:59", DateUtils.dateToString(expirationTime));
         expirationTime = CronUtils.getExpirationTime(startTime, CycleEnum.MONTH);
-        Assert.assertEquals("2020-02-07 23:59:59", DateUtils.dateToString(expirationTime));
+        Assertions.assertEquals("2020-02-07 23:59:59", DateUtils.dateToString(expirationTime));
         expirationTime = CronUtils.getExpirationTime(startTime, CycleEnum.YEAR);
-        Assert.assertEquals("2020-02-07 18:30:00", DateUtils.dateToString(expirationTime));
+        Assertions.assertEquals("2020-02-07 18:30:00", DateUtils.dateToString(expirationTime));
     }
 
     @Test
     public void testValid() {
-        Assert.assertFalse(CronUtils.isValidExpression("0 0 13/0 * * ? *"));
-        Assert.assertTrue(CronUtils.isValidExpression("0 0 13-0 * * ? *"));
+        Assertions.assertFalse(CronUtils.isValidExpression("0 0 13/0 * * ? *"));
+        Assertions.assertTrue(CronUtils.isValidExpression("0 0 13-0 * * ? *"));
     }
 }
