@@ -62,7 +62,8 @@ public class PluginParamsTransfer {
      * @return return plugin params value
      */
     public static List<Map<String, Object>> generatePluginParams(String paramsJsonStr, String pluginParamsTemplate) {
-        Map<String, Object> paramsMap = JSONUtils.toMap(paramsJsonStr, String.class, Object.class);
+        Map<String, Object> paramsMap = JSONUtils.parseObject(paramsJsonStr, new TypeReference<Map<String, Object>>() {
+        });
         return generatePluginParams(paramsMap, pluginParamsTemplate);
     }
 
@@ -73,12 +74,16 @@ public class PluginParamsTransfer {
      * @param pluginParamsTemplate pluginParamsTemplate
      * @return return plugin params value
      */
-    public static List<Map<String, Object>> generatePluginParams(Map<String, Object> paramsMap, String pluginParamsTemplate) {
+    public static List<Map<String, Object>> generatePluginParams(Map<String, Object> paramsMap,
+                                                                 String pluginParamsTemplate) {
         if (paramsMap == null || paramsMap.isEmpty()) {
             return null;
         }
-        List<Map<String, Object>> pluginParamsList = JSONUtils.parseObject(pluginParamsTemplate, new TypeReference<List<Map<String, Object>>>() {});
-        pluginParamsList.forEach(pluginParams -> pluginParams.put(STRING_PLUGIN_PARAM_VALUE, paramsMap.get(pluginParams.get(STRING_PLUGIN_PARAM_FIELD))));
+        List<Map<String, Object>> pluginParamsList =
+                JSONUtils.parseObject(pluginParamsTemplate, new TypeReference<List<Map<String, Object>>>() {
+                });
+        pluginParamsList.forEach(pluginParams -> pluginParams.put(STRING_PLUGIN_PARAM_VALUE,
+                paramsMap.get(pluginParams.get(STRING_PLUGIN_PARAM_FIELD))));
         return pluginParamsList;
     }
 }
