@@ -17,9 +17,12 @@
 
 package org.apache.dolphinscheduler.spi.params.base;
 
+import lombok.Getter;
+
 /**
  * param datetype
  */
+@Getter
 public enum DataType {
 
     STRING("string"),
@@ -32,8 +35,4 @@ public enum DataType {
         this.dataType = dataType;
     }
 
-    public String getDataType() {
-        return this.dataType;
-    }
-
 }
