@@ -35,19 +35,14 @@ public class TaskConstants {
 
     public static final String FLINK_APPLICATION_REGEX = "JobID \\w+";
 
-    public static final String SETVALUE_REGEX = "[\\$#]\\{setValue\\((.*?)\\)}";
-
-    public static final String DSVALUE_REGEX = "[\\$#]\\{\\((.*?)\\)dsVal}$";
-
-    /**
-     * string false
-     */
-    public static final String STRING_FALSE = "false";
+    public static final String DATASOURCE_PASSWORD_REGEX =
+            "(?<=((?i)password((\" : \")|(\":\")|(\\\\\":\\\\\")|(=')))).*?(?=((\")|(\\\\\")|(')))";
 
     /**
      * exit code kill
      */
     public static final int EXIT_CODE_KILL = 137;
+    public static final int EXIT_CODE_HARD_KILL = 143;
     public static final String PID = "pid";
 
     /**
@@ -108,10 +103,7 @@ public class TaskConstants {
      * EQUAL SIGN
      */
     public static final String EQUAL_SIGN = "=";
-    /**
-     * AT SIGN
-     */
-    public static final String AT_SIGN = "@";
+
     /**
      * UNDERLINE
      */
@@ -150,11 +142,6 @@ public class TaskConstants {
 
     public static final String RWXR_XR_X = "rwxr-xr-x";
 
-    /**
-     * date format of yyyyMMdd
-     */
-    public static final String PARAMETER_FORMAT_DATE = "yyyyMMdd";
-
     /**
      * date format of yyyyMMddHHmmss
      */
@@ -295,22 +282,9 @@ public class TaskConstants {
     public static final char P = 'P';
     public static final char N = 'N';
     public static final String SUBTRACT_STRING = "-";
-    public static final String GLOBAL_PARAMS = "globalParams";
-    public static final String LOCAL_PARAMS = "localParams";
     public static final String LOCAL_PARAMS_LIST = "localParamsList";
-    public static final String SUBPROCESS_INSTANCE_ID = "subProcessInstanceId";
-    public static final String PROCESS_INSTANCE_STATE = "processInstanceState";
-    public static final String PARENT_WORKFLOW_INSTANCE = "parentWorkflowInstance";
-    public static final String CONDITION_RESULT = "conditionResult";
-    public static final String SWITCH_RESULT = "switchResult";
-    public static final String DEPENDENCE = "dependence";
     public static final String TASK_TYPE = "taskType";
-    public static final String TASK_LIST = "taskList";
     public static final String QUEUE = "queue";
-    public static final String QUEUE_NAME = "queueName";
-    public static final int LOG_QUERY_SKIP_LINE_NUMBER = 0;
-    public static final int LOG_QUERY_LIMIT = 4096;
-
     /**
      * default display rows
      */
@@ -331,55 +305,6 @@ public class TaskConstants {
      */
     public static final String D = "-D";
 
-    /**
-     * jdbc url
-     */
-    public static final String JDBC_MYSQL = "jdbc:mysql://";
-    public static final String JDBC_POSTGRESQL = "jdbc:postgresql://";
-    public static final String JDBC_HIVE_2 = "jdbc:hive2://";
-    public static final String JDBC_CLICKHOUSE = "jdbc:clickhouse://";
-    public static final String JDBC_DATABEND = "jdbc:databend://";
-    public static final String JDBC_ORACLE_SID = "jdbc:oracle:thin:@";
-    public static final String JDBC_ORACLE_SERVICE_NAME = "jdbc:oracle:thin:@//";
-    public static final String JDBC_SQLSERVER = "jdbc:sqlserver://";
-    public static final String JDBC_DB2 = "jdbc:db2://";
-    public static final String JDBC_PRESTO = "jdbc:presto://";
-
-    /**
-     * driver
-     */
-    public static final String ORG_POSTGRESQL_DRIVER = "org.postgresql.Driver";
-    public static final String COM_MYSQL_CJ_JDBC_DRIVER = "com.mysql.cj.jdbc.Driver";
-    public static final String ORG_APACHE_HIVE_JDBC_HIVE_DRIVER = "org.apache.hive.jdbc.HiveDriver";
-    public static final String COM_CLICKHOUSE_JDBC_DRIVER = "com.clickhouse.jdbc.ClickHouseDriver";
-    public static final String COM_DATABEND_JDBC_DRIVER = "com.databend.jdbc.DatabendDriver";
-    public static final String COM_ORACLE_JDBC_DRIVER = "oracle.jdbc.driver.OracleDriver";
-    public static final String COM_SQLSERVER_JDBC_DRIVER = "com.microsoft.sqlserver.jdbc.SQLServerDriver";
-    public static final String COM_DB2_JDBC_DRIVER = "com.ibm.db2.jcc.DB2Driver";
-    public static final String COM_PRESTO_JDBC_DRIVER = "com.facebook.presto.jdbc.PrestoDriver";
-
-    /**
-     * datasource encryption salt
-     */
-    public static final String DATASOURCE_ENCRYPTION_SALT_DEFAULT = "!@#$%^&*";
-    public static final String DATASOURCE_ENCRYPTION_ENABLE = "datasource.encryption.enable";
-    public static final String DATASOURCE_ENCRYPTION_SALT = "datasource.encryption.salt";
-
-    /**
-     * resource storage type
-     */
-    // public static final String RESOURCE_STORAGE_TYPE = "resource.storage.type";
-
-    /**
-     * kerberos
-     */
-    public static final String KERBEROS = "kerberos";
-
-    /**
-     * kerberos expire time
-     */
-    public static final String KERBEROS_EXPIRE_TIME = "kerberos.expire.time";
-
     /**
      * java.security.krb5.conf
      */
@@ -390,70 +315,16 @@ public class TaskConstants {
      */
     public static final String JAVA_SECURITY_KRB5_CONF_PATH = "java.security.krb5.conf.path";
 
-    /**
-     * loginUserFromKeytab user
-     */
-    public static final String LOGIN_USER_KEY_TAB_USERNAME = "login.user.keytab.username";
-
-    /**
-     * loginUserFromKeytab path
-     */
-    public static final String LOGIN_USER_KEY_TAB_PATH = "login.user.keytab.path";
-
-    /**
-     * hadoop.security.authentication
-     */
-    public static final String HADOOP_SECURITY_AUTHENTICATION = "hadoop.security.authentication";
-
     /**
      * hadoop.security.authentication
      */
     public static final String HADOOP_SECURITY_AUTHENTICATION_STARTUP_STATE =
             "hadoop.security.authentication.startup.state";
 
-    /**
-     * Task Logger Thread's name
-     */
-    public static final String TASK_LOGGER_THREAD_NAME = "TaskLogInfo";
-
-    /**
-     * hdfs/s3 configuration
-     * resource.storage.upload.base.path
-     */
-    public static final String RESOURCE_UPLOAD_PATH = "resource.storage.upload.base.path";
-
-    /**
-     * data.quality.jar.name
-     */
-    public static final String DATA_QUALITY_JAR_NAME = "data-quality.jar.name";
-
-    /**
-     * data.quality.error.output.path
-     */
-    public static final String DATA_QUALITY_ERROR_OUTPUT_PATH = "data-quality.error.output.path";
-
-    public static final String TASK_TYPE_CONDITIONS = "CONDITIONS";
-
-    public static final String TASK_TYPE_SWITCH = "SWITCH";
-
-    public static final String TASK_TYPE_SUB_PROCESS = "SUB_PROCESS";
-
-    public static final String TASK_TYPE_DYNAMIC = "DYNAMIC";
-
-    public static final String TASK_TYPE_DEPENDENT = "DEPENDENT";
-
-    public static final String TASK_TYPE_SQL = "SQL";
-
     public static final String TASK_TYPE_DATA_QUALITY = "DATA_QUALITY";
 
-    public static final String DEPLOY_MODE_KUBERNETES = "Kubernetes";
-
     public static final Set<String> TASK_TYPE_SET_K8S = Sets.newHashSet("K8S", "KUBEFLOW");
 
-    public static final String TASK_TYPE_BLOCKING = "BLOCKING";
-
-    public static final String TASK_TYPE_STREAM = "STREAM";
-
     /**
      * azure config
      */
@@ -463,31 +334,10 @@ public class TaskConstants {
     public static final String AZURE_SECRET_TENANT_ID = "resource.azure.tenant.id";
     public static final String QUERY_INTERVAL = "resource.query.interval";
 
-    /**
-     * aws config
-     */
-    public static final String AWS_ACCESS_KEY_ID = "resource.aws.access.key.id";
-    public static final String AWS_SECRET_ACCESS_KEY = "resource.aws.secret.access.key";
-    public static final String AWS_REGION = "resource.aws.region";
-
-    /**
-     * alibaba cloud config
-     */
-    public static final String ALIBABA_CLOUD_ACCESS_KEY_ID = "resource.alibaba.cloud.access.key.id";
-    public static final String ALIBABA_CLOUD_ACCESS_KEY_SECRET = "resource.alibaba.cloud.access.key.secret";
-    public static final String ALIBABA_CLOUD_REGION = "resource.alibaba.cloud.region";
-
-    /**
-     * huawei cloud config
-     */
-    public static final String HUAWEI_CLOUD_ACCESS_KEY_ID = "resource.huawei.cloud.access.key.id";
-    public static final String HUAWEI_CLOUD_ACCESS_KEY_SECRET = "resource.huawei.cloud.access.key.secret";
-
     /**
      * use for k8s task
      */
     public static final String API_VERSION = "batch/v1";
-    public static final String IMAGE_PULL_POLICY = "Always";
     public static final String RESTART_POLICY = "Never";
     public static final String MEMORY = "memory";
     public static final String CPU = "cpu";
@@ -500,7 +350,6 @@ public class TaskConstants {
     public static final int LOG_LINES = 500;
     public static final String NAMESPACE_NAME = "name";
     public static final String CLUSTER = "cluster";
-    public static final Pattern COMMAND_SPLIT_REGEX = Pattern.compile("[^\\s\"'`]+|\"([^\"]+)\"|'([^']+)'|`([^`]+)`");
 
     /**
      * spark / flink on k8s label name
@@ -515,4 +364,28 @@ public class TaskConstants {
     // Loop task constants
     public static final Duration DEFAULT_LOOP_STATUS_INTERVAL = Duration.ofSeconds(5L);
 
+    /**
+     * sql params regex
+     */
+    public static final String GROUP_NAME1 = "paramName1";
+    public static final String GROUP_NAME2 = "paramName2";
+    public static final String SQL_PARAMS_REGEX =
+            String.format("['\"]\\$\\{(?<%s>.*?)}['\"]|\\$\\{(?<%s>.*?)}", GROUP_NAME1, GROUP_NAME2);
+    public static final Pattern SQL_PARAMS_PATTERN = Pattern.compile(SQL_PARAMS_REGEX);
+
+    public static final String LOGIN_USER_KEY_TAB_USERNAME = "login.user.keytab.username";
+
+    public static final String LOGIN_USER_KEY_TAB_PATH = "login.user.keytab.path";
+
+    /**
+     * fetch applicationId way
+     */
+    public static final String APPID_COLLECT = "appId.collect";
+    public static final String DEFAULT_COLLECT_WAY = "log";
+
+    public static final String WORKFLOW_INSTANCE_ID_MDC_KEY = "workflowInstanceId";
+    public static final String TASK_INSTANCE_ID_MDC_KEY = "taskInstanceId";
+
+    public static final String STAR = "*";
+    public static final String SENSITIVE_DATA_MASK = "******";
 }
