@@ -21,12 +21,10 @@ import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.plugin.task.api.SQLTaskExecutionContext;
 import org.apache.dolphinscheduler.plugin.task.api.enums.DataType;
 import org.apache.dolphinscheduler.plugin.task.api.enums.ResourceType;
-import org.apache.dolphinscheduler.plugin.task.api.enums.UdfType;
 import org.apache.dolphinscheduler.plugin.task.api.model.Property;
 import org.apache.dolphinscheduler.plugin.task.api.model.ResourceInfo;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.resource.DataSourceParameters;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.resource.ResourceParametersHelper;
-import org.apache.dolphinscheduler.plugin.task.api.parameters.resource.UdfFuncParameters;
 import org.apache.dolphinscheduler.plugin.task.api.utils.VarPoolUtils;
 
 import org.apache.commons.collections4.CollectionUtils;
@@ -37,10 +35,7 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import java.util.stream.Collectors;
 
-import com.google.common.base.Enums;
-import com.google.common.base.Strings;
 import com.google.common.collect.Lists;
 
 /**
@@ -80,10 +75,6 @@ public class SqlParameters extends AbstractParameters {
      */
     private int displayRows;
 
-    /**
-     * udf list
-     */
-    private String udfs;
     /**
      * show type
      * 0 TABLE
@@ -148,14 +139,6 @@ public class SqlParameters extends AbstractParameters {
         this.sql = sql;
     }
 
-    public String getUdfs() {
-        return udfs;
-    }
-
-    public void setUdfs(String udfs) {
-        this.udfs = udfs;
-    }
-
     public int getSqlType() {
         return sqlType;
     }
@@ -293,7 +276,6 @@ public class SqlParameters extends AbstractParameters {
                 + ", sendEmail=" + sendEmail
                 + ", displayRows=" + displayRows
                 + ", limit=" + limit
-                + ", udfs='" + udfs + '\''
                 + ", showType='" + showType + '\''
                 + ", connParams='" + connParams + '\''
                 + ", groupId='" + groupId + '\''
@@ -308,16 +290,6 @@ public class SqlParameters extends AbstractParameters {
         ResourceParametersHelper resources = super.getResources();
         resources.put(ResourceType.DATASOURCE, datasource);
 
-        // whether udf type
-        boolean udfTypeFlag = Enums.getIfPresent(UdfType.class, Strings.nullToEmpty(this.getType())).isPresent()
-                && !StringUtils.isEmpty(this.getUdfs());
-
-        if (udfTypeFlag) {
-            String[] udfFunIds = this.getUdfs().split(",");
-            for (int i = 0; i < udfFunIds.length; i++) {
-                resources.put(ResourceType.UDF, Integer.parseInt(udfFunIds[i]));
-            }
-        }
         return resources;
     }
 
@@ -334,16 +306,6 @@ public class SqlParameters extends AbstractParameters {
                 (DataSourceParameters) parametersHelper.getResourceParameters(ResourceType.DATASOURCE, datasource);
         sqlTaskExecutionContext.setConnectionParams(dbSource.getConnectionParams());
 
-        // whether udf type
-        boolean udfTypeFlag = Enums.getIfPresent(UdfType.class, Strings.nullToEmpty(this.getType())).isPresent()
-                && !StringUtils.isEmpty(this.getUdfs());
-
-        if (udfTypeFlag) {
-            List<UdfFuncParameters> collect = parametersHelper.getResourceMap(ResourceType.UDF).entrySet().stream()
-                    .map(entry -> (UdfFuncParameters) entry.getValue()).collect(Collectors.toList());
-            sqlTaskExecutionContext.setUdfFuncParametersList(collect);
-        }
-
         return sqlTaskExecutionContext;
     }
 }
