@@ -23,6 +23,7 @@ import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.PARAMETE
 
 import org.apache.dolphinscheduler.common.utils.DateUtils;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
+import org.apache.dolphinscheduler.plugin.task.api.TaskConstants;
 import org.apache.dolphinscheduler.plugin.task.api.enums.DataType;
 import org.apache.dolphinscheduler.plugin.task.api.enums.Direct;
 import org.apache.dolphinscheduler.plugin.task.api.model.Property;
@@ -48,8 +49,6 @@ public class ParameterUtils {
 
     private static final Pattern DATE_PARSE_PATTERN = Pattern.compile("\\$\\[([^\\$\\]]+)]");
 
-    private static final Pattern DATE_START_PATTERN = Pattern.compile("^[0-9]");
-
     private static final char PARAM_REPLACE_CHAR = '?';
 
     private ParameterUtils() {
@@ -145,7 +144,7 @@ public class ParameterUtils {
         } else if (dataType.equals(DataType.DATE)) {
             stmt.setDate(index, java.sql.Date.valueOf(value));
         } else if (dataType.equals(DataType.TIME)) {
-            stmt.setString(index, value);
+            stmt.setTime(index, java.sql.Time.valueOf(value));
         } else if (dataType.equals(DataType.TIMESTAMP)) {
             stmt.setTimestamp(index, java.sql.Timestamp.valueOf(value));
         } else if (dataType.equals(DataType.BOOLEAN)) {
@@ -192,24 +191,27 @@ public class ParameterUtils {
         if (params == null || params.isEmpty()) {
             return sql;
         }
-        String[] split = sql.split("\\?");
-        if (split.length == 0) {
-            return sql;
-        }
-        StringBuilder ret = new StringBuilder(split[0]);
+        StringBuilder ret = new StringBuilder(sql);
+        Matcher m = TaskConstants.SQL_PARAMS_PATTERN.matcher(sql);
         int index = 1;
-        for (int i = 1; i < split.length; i++) {
-            Property property = params.get(i);
+        int paramsIndex = 1;
+        // When matching with a regex, determine whether the corresponding property is a list.
+        while (m.find()) {
+            Property property = params.get(paramsIndex++);
+            if (property == null) {
+                continue;
+            }
             String value = property.getValue();
+            StringBuilder tempReplace = new StringBuilder();
             if (DataType.LIST.equals(property.getType())) {
                 List<Object> valueList = JSONUtils.toList(value, Object.class);
                 if (valueList.isEmpty() && StringUtils.isNotBlank(value)) {
                     valueList.add(value);
                 }
                 for (int j = 0; j < valueList.size(); j++) {
-                    ret.append(PARAM_REPLACE_CHAR);
+                    tempReplace.append(PARAM_REPLACE_CHAR);
                     if (j != valueList.size() - 1) {
-                        ret.append(",");
+                        tempReplace.append(",");
                     }
                 }
                 for (Object v : valueList) {
@@ -231,14 +233,12 @@ public class ParameterUtils {
                     expandMap.put(index++, newProperty);
                 }
             } else {
-                ret.append(PARAM_REPLACE_CHAR);
+                tempReplace.append(PARAM_REPLACE_CHAR);
                 expandMap.put(index++, property);
             }
-            ret.append(split[i]);
-        }
-        if (PARAM_REPLACE_CHAR == sql.charAt(sql.length() - 1)) {
-            ret.append(PARAM_REPLACE_CHAR);
-            expandMap.put(index, params.get(split.length));
+            ret.replace(m.start(), m.end(), tempReplace.toString());
+            // After replacement, the string length will change, so a reset is required
+            m.reset(ret.toString());
         }
         params.clear();
         params.putAll(expandMap);
@@ -286,21 +286,24 @@ public class ParameterUtils {
         return map;
     }
 
-    private static String dateTemplateParse(String templateStr, Date date) {
-        if (templateStr == null) {
-            return null;
+    // Replace the time placeholder in the template string with the given actual time value
+    // If the templateStr does not contain a time placeholder, will return the original string
+    private static String dateTemplateParse(final String templateStr, final Date date) {
+        if (StringUtils.isEmpty(templateStr)) {
+            return templateStr;
         }
 
-        StringBuffer newValue = new StringBuffer(templateStr.length());
+        final StringBuffer newValue = new StringBuffer(templateStr.length());
 
-        Matcher matcher = DATE_PARSE_PATTERN.matcher(templateStr);
+        final Matcher matcher = DATE_PARSE_PATTERN.matcher(templateStr);
 
         while (matcher.find()) {
-            String key = matcher.group(1);
-            if (DATE_START_PATTERN.matcher(key).matches()) {
+            final String key = matcher.group(1);
+            String value = TimePlaceholderUtils.formatTimeExpression(key, date, true);
+            if (StringUtils.equals(key, value)) {
+                // There is no corresponding time format, so the original string is retained
                 continue;
             }
-            String value = TimePlaceholderUtils.getPlaceHolderTime(key, date);
             matcher.appendReplacement(newValue, value);
         }
 
@@ -341,5 +344,4 @@ public class ParameterUtils {
         }
         return userDefParamsMaps;
     }
-
 }
