@@ -19,10 +19,6 @@ package org.apache.dolphinscheduler.plugin.task.dms;
 
 import org.apache.dolphinscheduler.plugin.task.api.TaskChannel;
 import org.apache.dolphinscheduler.plugin.task.api.TaskChannelFactory;
-import org.apache.dolphinscheduler.spi.params.base.PluginParams;
-
-import java.util.Collections;
-import java.util.List;
 
 import com.google.auto.service.AutoService;
 
@@ -39,8 +35,4 @@ public class DmsTaskChannelFactory implements TaskChannelFactory {
         return "DMS";
     }
 
-    @Override
-    public List<PluginParams> getParams() {
-        return Collections.emptyList();
-    }
 }
