@@ -19,25 +19,17 @@ package org.apache.dolphinscheduler.plugin.task.emr;
 
 import org.apache.dolphinscheduler.plugin.task.api.TaskChannel;
 import org.apache.dolphinscheduler.plugin.task.api.TaskChannelFactory;
-import org.apache.dolphinscheduler.spi.params.base.PluginParams;
-
-import java.util.Collections;
-import java.util.List;
 
 import com.google.auto.service.AutoService;
 
 @AutoService(TaskChannelFactory.class)
 public class EmrTaskChannelFactory implements TaskChannelFactory {
+
     @Override
     public String getName() {
         return "EMR";
     }
 
-    @Override
-    public List<PluginParams> getParams() {
-        return Collections.emptyList();
-    }
-
     @Override
     public TaskChannel create() {
         return new EmrTaskChannel();
