@@ -24,11 +24,13 @@ import org.apache.dolphinscheduler.plugin.task.api.TaskExecutionContext;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.AbstractParameters;
 
 import java.util.List;
-import java.util.Map;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import java.util.stream.Collectors;
 
+import lombok.extern.slf4j.Slf4j;
+
+@Slf4j
 public class FlinkTask extends AbstractYarnTask {
 
     /**
@@ -76,11 +78,6 @@ public class FlinkTask extends AbstractYarnTask {
         return args.stream().collect(Collectors.joining(" "));
     }
 
-    @Override
-    protected Map<String, String> getProperties() {
-        return taskExecutionContext.getDefinedParams();
-    }
-
     @Override
     public AbstractParameters getParameters() {
         return flinkParameters;
