@@ -21,10 +21,5 @@ package org.apache.dolphinscheduler.plugin.task.http;
  * http parameters type
  */
 public enum HttpParametersType {
-    /**
-     * 0 parameter;
-     * 1 body;
-     * 2 headers;
-     */
-    PARAMETER,BODY,HEADERS
+    PARAMETER, HEADERS
 }
