@@ -18,8 +18,8 @@
 package org.apache.dolphinscheduler.plugin.task.java;
 
 import static org.apache.dolphinscheduler.plugin.task.java.JavaConstants.JAVA_HOME_VAR;
-import static org.apache.dolphinscheduler.plugin.task.java.JavaConstants.PUBLIC_CLASS_NAME_REGEX;
 
+import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.plugin.task.api.AbstractTask;
 import org.apache.dolphinscheduler.plugin.task.api.ShellCommandExecutor;
@@ -27,30 +27,17 @@ import org.apache.dolphinscheduler.plugin.task.api.TaskCallBack;
 import org.apache.dolphinscheduler.plugin.task.api.TaskConstants;
 import org.apache.dolphinscheduler.plugin.task.api.TaskException;
 import org.apache.dolphinscheduler.plugin.task.api.TaskExecutionContext;
-import org.apache.dolphinscheduler.plugin.task.api.model.Property;
 import org.apache.dolphinscheduler.plugin.task.api.model.ResourceInfo;
 import org.apache.dolphinscheduler.plugin.task.api.model.TaskResponse;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.AbstractParameters;
 import org.apache.dolphinscheduler.plugin.task.api.resource.ResourceContext;
 import org.apache.dolphinscheduler.plugin.task.api.shell.IShellInterceptorBuilder;
 import org.apache.dolphinscheduler.plugin.task.api.shell.ShellInterceptorBuilderFactory;
-import org.apache.dolphinscheduler.plugin.task.api.utils.MapUtils;
-import org.apache.dolphinscheduler.plugin.task.api.utils.ParameterUtils;
-import org.apache.dolphinscheduler.plugin.task.java.exception.JavaSourceFileExistException;
-import org.apache.dolphinscheduler.plugin.task.java.exception.PublicClassNotFoundException;
 import org.apache.dolphinscheduler.plugin.task.java.exception.RunTypeNotFoundException;
 
-import org.apache.commons.io.FileUtils;
+import org.apache.commons.lang3.StringUtils;
 
 import java.io.File;
-import java.io.IOException;
-import java.nio.charset.StandardCharsets;
-import java.nio.file.Files;
-import java.nio.file.Paths;
-import java.util.HashMap;
-import java.util.Map;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
 
 import lombok.extern.slf4j.Slf4j;
 
@@ -74,11 +61,6 @@ public class JavaTask extends AbstractTask {
      */
     private TaskExecutionContext taskRequest;
 
-    /**
-     * class name regex pattern
-     */
-    private static final Pattern classNamePattern = Pattern.compile(PUBLIC_CLASS_NAME_REGEX);
-
     public JavaTask(TaskExecutionContext taskRequest) {
         super(taskRequest);
         this.taskRequest = taskRequest;
@@ -109,19 +91,22 @@ public class JavaTask extends AbstractTask {
     public void handle(TaskCallBack taskCallBack) throws TaskException {
         try {
             // Step 1: judge if is java or jar run type.
-            // Step 2 case1: the jar run type builds the command directly, adding resource to the java -jar class when
+            // Step 2 case1: the fat jar run type builds the command directly, adding resource to the java -jar class
+            // when
+            // building the command
+            // Step 2 case2: the normal jar run type builds the command directly, adding resource to the java -cp class
+            // when
             // building the command
-            // Step 2 case2: the java run type, first replace the custom parameters, then compile the code, and then
-            // build the command will add resource
             // Step 3: to run the command
             String command = null;
             switch (javaParameters.getRunType()) {
-                case JavaConstants.RUN_TYPE_JAVA:
-                    command = buildJavaCommand();
-                    break;
-                case JavaConstants.RUN_TYPE_JAR:
+
+                case JavaConstants.RUN_TYPE_FAT_JAR:
                     command = buildJarCommand();
                     break;
+                case JavaConstants.RUN_TYPE_NORMAL_JAR:
+                    command = buildNormalJarCommand();
+                    break;
                 default:
                     throw new RunTypeNotFoundException("run type is required, but it is null now.");
             }
@@ -149,28 +134,6 @@ public class JavaTask extends AbstractTask {
         }
     }
 
-    /**
-     * Construct a shell command for the java Run mode
-     *
-     * @return String
-     * @throws Exception
-     **/
-    protected String buildJavaCommand() throws Exception {
-        StringBuilder builder = new StringBuilder();
-        String sourceCode = buildJavaSourceContent();
-        builder.append(buildJavaCompileCommand(sourceCode))
-                .append(";")
-                .append(getJavaCommandPath())
-                .append("java").append(" ")
-                .append(buildResourcePath())
-                .append(" ")
-                .append(getPublicClassName(sourceCode))
-                .append(" ")
-                .append(javaParameters.getMainArgs().trim()).append(" ")
-                .append(javaParameters.getJvmArgs().trim());
-        return builder.toString();
-    }
-
     /**
      * Construct a shell command for the java -jar Run mode
      *
@@ -183,11 +146,39 @@ public class JavaTask extends AbstractTask {
                 .getResourceAbsolutePathInLocal();
         StringBuilder builder = new StringBuilder();
         builder.append(getJavaCommandPath())
-                .append("java").append(" ")
-                .append(buildResourcePath()).append(" ")
-                .append("-jar").append(" ")
-                .append(mainJarAbsolutePathInLocal).append(" ")
-                .append(javaParameters.getMainArgs().trim()).append(" ")
+                .append("java").append(Constants.SPACE)
+                .append(buildResourcePath()).append(Constants.SPACE)
+                .append("-jar").append(Constants.SPACE)
+                .append(mainJarAbsolutePathInLocal).append(Constants.SPACE)
+                .append(javaParameters.getMainArgs().trim()).append(Constants.SPACE)
+                .append(javaParameters.getJvmArgs().trim());
+        return builder.toString();
+    }
+
+    /**
+     * Construct a shell command for the java -cp run mode
+     *
+     * @return String
+     **/
+    protected String buildNormalJarCommand() {
+        ResourceContext resourceContext = taskRequest.getResourceContext();
+        String mainJarAbsolutePathInLocal = resourceContext.getResourceItem(
+                javaParameters.getMainJar()
+                        .getResourceName())
+                .getResourceAbsolutePathInLocal();
+        String mainClassName = javaParameters.getMainClass();
+        String mainJarName;
+        if (mainClassName == null || StringUtils.isEmpty(mainClassName)) {
+            mainJarName = MainClassExtractor.getMainClassName(mainJarAbsolutePathInLocal);
+        } else {
+            mainJarName = mainClassName;
+        }
+        StringBuilder builder = new StringBuilder();
+        builder.append(getJavaCommandPath())
+                .append("java").append(Constants.SPACE)
+                .append(buildResourcePath()).append(Constants.SPACE)
+                .append(mainJarName).append(Constants.SPACE)
+                .append(javaParameters.getMainArgs().trim()).append(Constants.SPACE)
                 .append(javaParameters.getJvmArgs().trim());
         return builder.toString();
     }
@@ -207,36 +198,6 @@ public class JavaTask extends AbstractTask {
         return javaParameters;
     }
 
-    /**
-     * Creates a Java source file when it does not exist
-     *
-     * @param sourceCode
-     * @param fileName
-     * @return String
-     **/
-    protected void createJavaSourceFileIfNotExists(String sourceCode, String fileName) throws IOException {
-        log.info("tenantCode: {}, task dir:{}", taskRequest.getTenantCode(), taskRequest.getExecutePath());
-        if (!Files.exists(Paths.get(fileName))) {
-            log.info("the java source code:{}, will be write to the file: {}", fileName, sourceCode);
-            // write data to file
-            FileUtils.writeStringToFile(new File(fileName),
-                    sourceCode,
-                    StandardCharsets.UTF_8);
-        } else {
-            throw new JavaSourceFileExistException("java source file exists, please report an issue on official.");
-        }
-    }
-
-    /**
-     * Construct the full path name of the Java source file from the temporary execution path of the task
-     *
-     * @return String
-     **/
-    protected String buildJavaSourceCodeFileFullName(String publicClassName) {
-        return String.format(JavaConstants.JAVA_SOURCE_CODE_NAME_TEMPLATE, taskRequest.getExecutePath(),
-                publicClassName);
-    }
-
     /**
      * Construct a Classpath or module path based on isModulePath
      *
@@ -262,47 +223,6 @@ public class JavaTask extends AbstractTask {
         return builder.toString();
     }
 
-    /**
-     * Constructs a shell command compiled from a Java source file
-     *
-     * @param sourceCode
-     * @return String
-     * @throws IOException
-     **/
-    protected String buildJavaCompileCommand(String sourceCode) throws IOException {
-        String publicClassName = getPublicClassName(sourceCode);
-        String fileName = buildJavaSourceCodeFileFullName(publicClassName);
-        createJavaSourceFileIfNotExists(sourceCode, fileName);
-
-        StringBuilder compilerCommand = new StringBuilder()
-                .append(getJavaCommandPath())
-                .append("javac").append(" ")
-                .append(buildResourcePath()).append(" ")
-                .append(fileName);
-        return compilerCommand.toString();
-    }
-
-    /**
-     * Work with Java source file content, such as replacing local variables
-     *
-     * @return String
-     **/
-    protected String buildJavaSourceContent() {
-        String rawJavaScript = javaParameters.getRawScript().replaceAll("\\r\\n", "\n");
-        // replace placeholder
-
-        Map<String, Property> paramsMap = taskRequest.getPrepareParamsMap();
-        if (MapUtils.isEmpty(paramsMap)) {
-            paramsMap = new HashMap<>();
-        }
-        if (MapUtils.isNotEmpty(taskRequest.getParamsMap())) {
-            paramsMap.putAll(taskRequest.getParamsMap());
-        }
-        log.info("The current java source code will begin to replace the placeholder: {}", rawJavaScript);
-        rawJavaScript = ParameterUtils.convertParameterPlaceholders(rawJavaScript, ParameterUtils.convert(paramsMap));
-        return rawJavaScript;
-    }
-
     /**
      * Gets the operating system absolute path to the Java command
      *
@@ -312,17 +232,4 @@ public class JavaTask extends AbstractTask {
         return JAVA_HOME_VAR + File.separator + "bin" + File.separator;
     }
 
-    /**
-     * Gets the public class name from the Java source file
-     *
-     * @param sourceCode
-     * @return String
-     **/
-    public String getPublicClassName(String sourceCode) {
-        Matcher matcher = classNamePattern.matcher(sourceCode);
-        if (!matcher.find()) {
-            throw new PublicClassNotFoundException("public class is not be found in source code : " + sourceCode);
-        }
-        return matcher.group(2).trim();
-    }
 }
