@@ -54,9 +54,9 @@ public class MapReduceParameters extends AbstractParameters {
     private String appName;
 
     /**
-     * queue
+     * The YARN queue to submit to
      */
-    private String queue;
+    private String yarnQueue;
 
     /**
      * resource list
@@ -101,12 +101,12 @@ public class MapReduceParameters extends AbstractParameters {
         this.appName = appName;
     }
 
-    public String getQueue() {
-        return queue;
+    public String getYarnQueue() {
+        return yarnQueue;
     }
 
-    public void setQueue(String queue) {
-        this.queue = queue;
+    public void setYarnQueue(String yarnQueue) {
+        this.yarnQueue = yarnQueue;
     }
 
     public List<ResourceInfo> getResourceList() {
@@ -152,8 +152,7 @@ public class MapReduceParameters extends AbstractParameters {
         return "mainJar= " + mainJar
                 + "mainClass=" + mainClass
                 + "mainArgs=" + mainArgs
-                + "queue=" + queue
-                + "other mainArgs=" + others
-                ;
+                + "yarnQueue=" + yarnQueue
+                + "other mainArgs=" + others;
     }
 }
