@@ -17,17 +17,21 @@
 
 package org.apache.dolphinscheduler.plugin.task.python;
 
-import org.apache.dolphinscheduler.spi.task.TaskChannel;
-import org.apache.dolphinscheduler.spi.task.request.TaskRequest;
+import org.apache.dolphinscheduler.common.utils.JSONUtils;
+import org.apache.dolphinscheduler.plugin.task.api.TaskChannel;
+import org.apache.dolphinscheduler.plugin.task.api.TaskExecutionContext;
+import org.apache.dolphinscheduler.plugin.task.api.parameters.AbstractParameters;
 
 public class PythonTaskChannel implements TaskChannel {
-    @Override
-    public void cancelApplication(boolean status) {
-
-    }
 
     @Override
-    public PythonTask createTask(TaskRequest taskRequest) {
+    public PythonTask createTask(TaskExecutionContext taskRequest) {
         return new PythonTask(taskRequest);
     }
+
+    @Override
+    public AbstractParameters parseParameters(String taskParams) {
+        return JSONUtils.parseObject(taskParams, PythonParameters.class);
+    }
+
 }
