@@ -1,4 +1,4 @@
-package org.apache.dolphinscheduler.plugin.task.python;/*
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -15,16 +15,16 @@ package org.apache.dolphinscheduler.plugin.task.python;/*
  * limitations under the License.
  */
 
+package org.apache.dolphinscheduler.plugin.task.python;
+
 import org.apache.dolphinscheduler.plugin.task.api.TaskChannel;
 import org.apache.dolphinscheduler.plugin.task.api.TaskChannelFactory;
-import org.apache.dolphinscheduler.spi.params.base.PluginParams;
-
-import java.util.List;
 
 import com.google.auto.service.AutoService;
 
 @AutoService(TaskChannelFactory.class)
 public class PythonTaskChannelFactory implements TaskChannelFactory {
+
     @Override
     public TaskChannel create() {
         return new PythonTaskChannel();
@@ -35,8 +35,4 @@ public class PythonTaskChannelFactory implements TaskChannelFactory {
         return "PYTHON";
     }
 
-    @Override
-    public List<PluginParams> getParams() {
-        return null;
-    }
 }
