@@ -35,7 +35,8 @@ public class SeatunnelFlinkTask extends SeatunnelTask {
 
     @Override
     public void init() {
-        seatunnelParameters = JSONUtils.parseObject(taskExecutionContext.getTaskParams(), SeatunnelFlinkParameters.class);
+        seatunnelParameters =
+                JSONUtils.parseObject(taskExecutionContext.getTaskParams(), SeatunnelFlinkParameters.class);
         setSeatunnelParameters(seatunnelParameters);
         super.init();
     }
