@@ -42,7 +42,8 @@ public class SeatunnelSparkTask extends SeatunnelTask {
 
     @Override
     public void init() {
-        seatunnelParameters = JSONUtils.parseObject(taskExecutionContext.getTaskParams(), SeatunnelSparkParameters.class);
+        seatunnelParameters =
+                JSONUtils.parseObject(taskExecutionContext.getTaskParams(), SeatunnelSparkParameters.class);
         setSeatunnelParameters(seatunnelParameters);
         super.init();
     }
@@ -53,7 +54,8 @@ public class SeatunnelSparkTask extends SeatunnelTask {
         args.add(DEPLOY_MODE_OPTIONS);
         args.add(seatunnelParameters.getDeployMode().getCommand());
 
-        MasterTypeEnum master = DeployModeEnum.local == seatunnelParameters.getDeployMode() ? MasterTypeEnum.LOCAL : seatunnelParameters.getMaster();
+        MasterTypeEnum master = DeployModeEnum.local == seatunnelParameters.getDeployMode() ? MasterTypeEnum.LOCAL
+                : seatunnelParameters.getMaster();
 
         args.add(MASTER_OPTIONS);
         if (MasterTypeEnum.SPARK.equals(master) || MasterTypeEnum.MESOS.equals(master)) {
