@@ -17,19 +17,21 @@
 
 package org.apache.dolphinscheduler.plugin.task.shell;
 
-import org.apache.dolphinscheduler.spi.task.TaskChannel;
-import org.apache.dolphinscheduler.spi.task.request.TaskRequest;
+import org.apache.dolphinscheduler.common.utils.JSONUtils;
+import org.apache.dolphinscheduler.plugin.task.api.TaskChannel;
+import org.apache.dolphinscheduler.plugin.task.api.TaskExecutionContext;
+import org.apache.dolphinscheduler.plugin.task.api.parameters.AbstractParameters;
 
 public class ShellTaskChannel implements TaskChannel {
 
     @Override
-    public void cancelApplication(boolean status) {
-
-    }
-
-    @Override
-    public ShellTask createTask(TaskRequest taskRequest) {
+    public ShellTask createTask(TaskExecutionContext taskRequest) {
         return new ShellTask(taskRequest);
     }
 
+    @Override
+    public AbstractParameters parseParameters(String taskParams) {
+        return JSONUtils.parseObject(taskParams, ShellParameters.class);
+    }
+
 }
