@@ -17,18 +17,15 @@
 
 package org.apache.dolphinscheduler.plugin.task.sqoop;
 
-import org.apache.dolphinscheduler.common.log.SensitiveDataConverter;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.plugin.task.api.AbstractYarnTask;
 import org.apache.dolphinscheduler.plugin.task.api.TaskException;
 import org.apache.dolphinscheduler.plugin.task.api.TaskExecutionContext;
+import org.apache.dolphinscheduler.plugin.task.api.log.SensitiveDataConverter;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.AbstractParameters;
-import org.apache.dolphinscheduler.plugin.task.api.utils.ParameterUtils;
 import org.apache.dolphinscheduler.plugin.task.sqoop.generator.SqoopJobGenerator;
 import org.apache.dolphinscheduler.plugin.task.sqoop.parameter.SqoopParameters;
 
-import java.util.Map;
-
 import lombok.extern.slf4j.Slf4j;
 
 /**
@@ -75,11 +72,6 @@ public class SqoopTask extends AbstractYarnTask {
 
     }
 
-    @Override
-    protected Map<String, String> getProperties() {
-        return ParameterUtils.convert(taskExecutionContext.getPrepareParamsMap());
-    }
-
     @Override
     public AbstractParameters getParameters() {
         return sqoopParameters;
