@@ -20,17 +20,16 @@ package org.apache.dolphinscheduler.plugin.task.sqoop.generator;
 import org.apache.dolphinscheduler.plugin.task.sqoop.SqoopTaskExecutionContext;
 import org.apache.dolphinscheduler.plugin.task.sqoop.parameter.SqoopParameters;
 
-/**
- * Source Generator Interface
- */
+/** Source Generator Interface */
 public interface ISourceGenerator {
 
     /**
      * generate the source script
      *
-     * @param sqoopParameters      sqoopParameters
+     * @param sqoopParameters sqoopParameters
      * @param sqoopTaskExecutionContext sqoopTaskExecutionContext
      * @return source script
      */
-    String generate(SqoopParameters sqoopParameters, SqoopTaskExecutionContext sqoopTaskExecutionContext);
+    String generate(
+                    SqoopParameters sqoopParameters, SqoopTaskExecutionContext sqoopTaskExecutionContext);
 }
