@@ -23,12 +23,12 @@ import lombok.extern.slf4j.Slf4j;
 
 import org.springframework.boot.CommandLineRunner;
 import org.springframework.boot.SpringApplication;
-import org.springframework.boot.autoconfigure.ImportAutoConfiguration;
 import org.springframework.boot.autoconfigure.SpringBootApplication;
+import org.springframework.context.annotation.Import;
 import org.springframework.context.annotation.Profile;
 import org.springframework.stereotype.Component;
 
-@ImportAutoConfiguration(DaoConfiguration.class)
+@Import(DaoConfiguration.class)
 @SpringBootApplication
 public class UpgradeDolphinScheduler {
 
