@@ -31,6 +31,8 @@ export function useDropDown() {
       useLogout()
     } else if (key === 'password') {
       router.push({ path: '/password' })
+    } else if (key === 'about') {
+      router.push({ path: '/about' })
     } else if (key === 'profile') {
       router.push({ path: '/profile' })
     }
@@ -41,6 +43,7 @@ export function useDropDown() {
       userStore.setSessionId('')
       userStore.setSecurityConfigType('')
       userStore.setUserInfo({})
+      userStore.setBaseResDir('')
       cookies.remove('sessionId')
 
       router.push({ path: '/login' })
