@@ -17,8 +17,8 @@
 
 export default {
   task_state_statistics: 'Task State Statistics',
-  process_state_statistics: 'Process State Statistics',
-  process_definition_statistics: 'Process Definition Statistics',
+  workflow_state_statistics: 'Workflow State Statistics',
+  workflow_definition_statistics: 'Workflow Definition Statistics',
   number: 'Number',
   state: 'State',
   submitted_success: 'SUBMITTED_SUCCESS',
@@ -39,5 +39,6 @@ export default {
   dispatch: 'DISPATCH',
   ready_block: 'READY_BLOCK',
   block: 'BLOCK',
-  wait_to_run: 'WAIT_TO_RUN'
+  wait_to_run: 'WAIT_TO_RUN',
+  failover: 'FAILOVER'
 }
