@@ -27,7 +27,6 @@ export default {
     project_description: 'Project Description',
     owned_users: 'Owned Users',
     workflow_define_count: 'Workflow Define Count',
-    process_instance_running_count: 'Process Instance Running Count',
     description: 'Description',
     create_time: 'Create Time',
     update_time: 'Update Time',
@@ -40,7 +39,9 @@ export default {
     authorize_level: 'Authorize Level',
     no_permission: 'No Permission',
     read_permission: 'Read Permission',
-    all_permission: 'All Permission'
+    all_permission: 'All Permission',
+    assign_worker_group: 'Worker Group',
+    total_items: 'Total Item is'
   },
   workflow: {
     on_line: 'Online',
@@ -82,6 +83,8 @@ export default {
     timezone: 'Timezone',
     up_line: 'Online',
     down_line: 'Offline',
+    time_up_line: 'Scheduler Online',
+    time_down_line: 'Scheduler Offline',
     copy_workflow: 'Copy Workflow',
     copy_workflow_name: 'Copy workflow name',
     visit_workflow_instances: 'Visit workflow instances',
@@ -122,14 +125,14 @@ export default {
     complement_data: 'Complement Data',
     startup_parameter: 'Startup Parameter',
     whether_dry_run: 'Whether Dry-Run',
-    whether_test: 'Whether Test',
     continue: 'Continue',
     end: 'End',
     none_send: 'None',
     success_send: 'Success',
     failure_send: 'Failure',
     all_send: 'All',
-    whether_complement_data: 'Whether it is a complement process?',
+    warning_group_tip: 'Please select alarm group',
+    whether_complement_data: 'Whether it is a complement workflow?',
     schedule_date: 'Schedule date',
     select_date: 'Select Date',
     enter_date: 'Enter Date',
@@ -162,7 +165,7 @@ export default {
     dry_run_flag: 'Dry-run Flag',
     executor: 'Executor',
     host: 'Host',
-    start_process: 'Start Process',
+    start_process: 'Start Workflow',
     execute_from_the_current_node: 'Execute from the current node',
     recover_tolerance_fault_process: 'Recover tolerance fault process',
     resume_the_suspension_process: 'Resume the suspension process',
@@ -227,11 +230,25 @@ export default {
       'Can not find any relations of workflows.',
     workflow_relation_no_data_result_desc:
       'There is not any workflows. Please create a workflow, and then visit this page again.',
-    ready_to_block: 'Ready to block',
-    block: 'Block',
-    want_to_set_timing: 'Would you like to set the workflow timing?',
+    wait_to_run: 'Wait to run',
     confirm_to_online: 'Confirm to make the workflow online?',
     confirm_to_offline: 'Confirm to make the workflow offline?',
+    time_to_online: 'Confirm to make the Scheduler online?',
+    time_to_offline: 'Confirm to make the Scheduler offline?',
+    warning_dependent_tasks_title: 'Warning',
+    warning_dependent_tasks_desc:
+      'The downstream dependent tasks exists. Are you sure to make the workflow offline?',
+    warning_dependencies: 'Dependencies:',
+    delete_validate_dependent_tasks_desc:
+      'The downstream dependent tasks exists. You can not delete the workflow.',
+    warning_offline_scheduler_dependent_tasks_desc:
+      'The downstream dependent tasks exists. Are you sure to make the scheduler offline?',
+    delete_task_validate_dependent_tasks_desc:
+      'The downstream dependent tasks exists. You can not delete the task.',
+    warning_delete_scheduler_dependent_tasks_desc:
+      'The downstream dependent tasks exists. Are you sure to delete the scheduler?',
+    warning_too_large_parallelism_number:
+      'The parallelism number is too large. It is better not to be over 10.'
   },
   task: {
     on_line: 'Online',
@@ -247,7 +264,6 @@ export default {
     task_type: 'Task Type',
     create_task: 'Create Task',
     workflow_instance: 'Workflow Instance',
-    workflow_name: 'Workflow Name',
     workflow_name_tips: 'Please select workflow name',
     workflow_state: 'Workflow State',
     version: 'Version',
@@ -300,7 +316,8 @@ export default {
     startup_parameter: 'Startup Parameter',
     whether_dry_run: 'Whether Dry-Run',
     please_choose: 'Please Choose',
-    remove_task_cache: 'Clear cache'
+    delete_validate_dependent_tasks_desc:
+      'The downstream dependent tasks exists. You can not delete the task.'
   },
   dag: {
     create: 'Create Workflow',
@@ -318,10 +335,9 @@ export default {
     rows: 'Rows',
     cols: 'Cols',
     copy_success: 'Copy Success',
-    workflow_name: 'Workflow Name',
     description: 'Description',
     timeout_alert: 'Timeout Alert',
-    process_execute_type: 'Process execute type',
+    workflow_execute_type: 'Workflow execute type',
     parallel: 'parallel',
     serial_wait: 'Serial wait',
     serial_discard: 'Serial discard',
@@ -347,7 +363,6 @@ export default {
     online: 'Online'
   },
   node: {
-    is_cache: 'Cache Execution',
     jvm_args: 'Java VM Parameters',
     jvm_args_tips: 'Please enter virtual machine parameters',
     run_type: 'Run Type',
@@ -365,7 +380,6 @@ export default {
     task_type: 'Task Type',
     task_type_tips: 'Please select a task type (required)',
     workflow_name: 'Workflow Name',
-    workflow_name_tips: 'Please select a workflow (required)',
     child_node: 'Child Node',
     child_node_tips: 'Please select a child node (required)',
     run_flag: 'Run flag',
@@ -427,12 +441,14 @@ export default {
     timeout_period_tips: 'Timeout must be a positive integer',
     script: 'Script',
     script_tips: 'Please enter script(required)',
+    master: 'Master',
+    master_tips: 'Please enter master url(required)',
     init_script: 'Initialization script',
     init_script_tips: 'Please enter initialization script',
     resources: 'Resources',
     resources_tips: 'Please select resources',
     resources_limit_tips: 'Please select again, resource limit:',
-    non_resources_tips: 'Please delete all non-existent resources',
+    no_resources_tips: 'Please delete all non-existent resources',
     useless_resources_tips: 'Unauthorized or deleted resources',
     custom_parameters: 'Custom Parameters',
     copy_success: 'Copy success',
@@ -450,8 +466,9 @@ export default {
     expression_value_tips: 'expression values(optional)',
     pre_tasks: 'Pre tasks',
     program_type: 'Program Type',
-    main_class: 'Main Class',
-    main_class_tips: 'Please enter main class',
+    main_class: 'Main Class Name',
+    main_class_tips: 'Please enter the full main class name (optional)',
+    main_class_invalid: 'Invalid main class name',
     main_package: 'Main Package',
     main_package_tips: 'Please enter main package',
     deploy_mode: 'Deploy Mode',
@@ -493,20 +510,20 @@ export default {
     http_url_validator: 'The request address must contain HTTP or HTTPS',
     http_method: 'Http Method',
     http_parameters: 'Http Parameters',
+    http_body: 'Http Body',
+    http_body_tips: 'http body(required)',
     http_check_condition: 'Http Check Condition',
     http_condition: 'Http Condition',
     http_condition_tips: 'Please Enter Http Condition',
     timeout_settings: 'Timeout Settings',
     connect_timeout: 'Connect Timeout',
     ms: 'ms',
-    socket_timeout: 'Socket Timeout',
     status_code_default: 'Default response code 200',
     status_code_custom: 'Custom response code',
     body_contains: 'Content includes',
     body_not_contains: 'Content does not contain',
     http_parameters_position: 'Http Parameters Position',
     target_task_name: 'Target Task Name',
-    target_task_name_tips: 'Please enter the Pigeon task name(required)',
     datasource_type: 'Datasource types',
     datasource_instances: 'Datasource instances',
     sql_type: 'SQL Type',
@@ -539,7 +556,7 @@ export default {
     model_type: 'ModelType',
     form: 'Form',
     table: 'Table',
-    table_tips: 'Please enter Mysql Table(required)',
+    table_tips: 'Please enter Table(required)',
     column_type: 'ColumnType',
     all_columns: 'All Columns',
     some_columns: 'Some Columns',
@@ -644,13 +661,13 @@ export default {
     hour: 'hour',
     add_dependency: 'Add dependency',
     waiting_dependent_start: 'Waiting Dependent start',
+    dependent_task_parameter_passing: 'Parameter Passing',
     check_interval: 'Check interval',
     check_interval_tips: 'Check interval must be a positive integer',
     waiting_dependent_complete: 'Waiting Dependent complete',
     project_name: 'Project Name',
     project_name_tips: 'Please select a project(required)',
-    process_name: 'Workflow Name',
-    process_name_tips: 'Please select a workflow(required)',
+    workflow_name_tips: 'Please select a workflow(required)',
     cycle_time: 'Cycle Time',
     cycle_time_tips: 'Please select a cycle time(required)',
     date_tips: 'Please select a date(required)',
@@ -802,17 +819,16 @@ export default {
     dvc_load_save_data_path: 'Data Path In Worker',
     dvc_store_url: 'Store Url',
     dvc_empty_tips: 'This parameter cannot be empty',
-    send_email: 'Send Email',
+    send_alarm: 'Send Alarm',
     log_display: 'Log display',
     rows_of_result: 'rows of result',
     title: 'Title',
-    title_tips: 'Please enter the title of email',
+    title_tips: 'Please enter the title of alarm',
     alarm_group: 'Alarm group',
     alarm_group_tips: 'Alarm group required',
     integer_tips: 'Please enter a positive integer',
     sql_parameter: 'SQL Parameter',
     format_tips: 'Please enter format',
-    udf_function: 'UDF Function',
     unlimited: 'unlimited',
     please_select_source_connector_type: 'Please select source connector type',
     please_select_source_datasource_id: 'Please select source datasource id',
@@ -825,9 +841,12 @@ export default {
     please_select_target_datasource: 'Please select target datasource id',
     please_select_target_database: 'Please select target database',
     please_enter_target_table: 'Please select target table name',
-    please_enter_target_filter_expression: 'Please enter target filter expression',
-    please_enter_comparison_name_the_alias_in_comparison_execute_sql: 'Please enter comparison name the alias in comparison execute sql',
-    please_enter_statistics_name_the_alias_in_statistics_execute_sql: 'Please enter statistics name the alias in statistics execute sql',
+    please_enter_target_filter_expression:
+      'Please enter target filter expression',
+    please_enter_comparison_name_the_alias_in_comparison_execute_sql:
+      'Please enter comparison name the alias in comparison execute sql',
+    please_enter_statistics_name_the_alias_in_statistics_execute_sql:
+      'Please enter statistics name the alias in statistics execute sql',
     please_enter_comparison_execute_sql: 'Please enter comparison execute sql',
     please_enter_statistics_execute_sql: 'Please enter statistics execute sql',
     please_enter_threshold_number_is_needed:
@@ -849,8 +868,8 @@ export default {
     pytorch_other_params: 'Show More Configurations',
     pytorch_python_path: 'Project Path',
     pytorch_is_create_environment: 'Create An Environment Or Not',
-    pytorch_python_command: 'Python Command Path',
-    pytorch_python_command_tips: 'If empty，will be set $PYTHON_LAUNCHER',
+    pytorch_python_launcher: 'Python Executable Path',
+    pytorch_python_launcher_tips: 'If empty，will be set $PYTHON_LAUNCHER',
     pytorch_python_env_tool: 'Python Environment Manager Tool',
     pytorch_requirements: 'Requirement File',
     pytorch_conda_python_version: 'Python Version',
@@ -872,13 +891,42 @@ export default {
     filter_condition: 'Filter Condition',
     params_value: 'Params Value',
     separator: 'Separator',
-    dynamic_name_tips: 'name(required)',
-    dynamic_value_tips: 'params or value(required)',
-    dynamic_separator_tips: 'separator(required)',
     child_node_definition: 'child node definition',
     child_node_instance: 'child node instance',
     yarn_queue: 'Yarn Queue',
     yarn_queue_tips: 'Please input yarn queue(optional)',
+    dependent_type: 'Dependency Type',
+    dependent_on_workflow: 'Dependent on workflow',
+    dependent_on_task: 'Dependent on task',
+    region_id: 'region id',
+    region_id_tips: 'region id',
+    endpoint: 'endpoint',
+    endpoint_tips: 'restful endpoint',
+    access_key_id: 'access key id',
+    access_key_id_tips: 'access key id',
+    access_key_secret: 'access key secret',
+    access_key_secret_tips: 'access key secret',
+    workspace_id: 'workspace id',
+    workspace_id_tips: 'workspace id',
+    resource_queue_id: 'resource queue id',
+    resource_queue_id_tips: 'resource queue id',
+    code_type: 'code type',
+    code_type_tips: 'code type',
+    job_name: 'job name',
+    job_name_tips: 'job name',
+    engine_release_version: 'engine release version',
+    engine_release_version_tips: 'engine release version',
+    entry_point: 'entry point',
+    entry_point_tips: 'entry point',
+    entry_point_arguments: 'entry point arguments',
+    entry_point_arguments_tips: 'entry point arguments',
+    spark_submit_parameters: 'spark submit parameters',
+    spark_submit_parameters_tips: 'spark submit parameters',
+    template_id: 'spark template id',
+    template_id_tips: 'spark template id',
+    is_production: 'is production',
+    is_production_tips: 'is production',
+    json_format_tips: 'Json parameters format is abnormal'
   },
   menu: {
     fav: 'Favorites',
@@ -886,7 +934,6 @@ export default {
     cloud: 'Cloud',
     logic: 'Logic',
     di: 'Data Integration',
-    dq: 'Data Quality',
     ml: 'Machine Learning',
     other: 'Other'
   },
@@ -897,23 +944,28 @@ export default {
     code: 'Parameter Code',
     name: 'Parameter Name',
     value: 'Parameter Value',
+    data_type: 'Parameter Data Type',
+    create_user: 'Create User',
+    modify_user: 'Modify User',
     create_time: 'Create Time',
     update_time: 'Update Time',
     name_tips: 'Please enter your parameter name',
     value_tips: 'Please enter your parameter value',
+    data_type_tips: 'Please choose your parameter data type',
     operation: 'Operation',
     edit: 'Edit',
     delete: 'Delete',
     delete_confirm: 'Delete?',
-    success: 'Success',
+    success: 'Success'
   },
   preference: {
     edit_preference: 'Edit Preference',
     preference_manage: 'Project Preference Management',
-    instruction_tips: 'The settings below will affect all workflows and tasks under this project.When creating the workflow or task, these preferences will be the default value of their components.',
+    instruction_tips:
+      'The settings below will affect all workflows and tasks under this project.When creating the workflow or task, these preferences will be the default value of their components.',
     success: 'Success',
     submit: 'Submit',
     enabled: 'Enabled',
     disabled: 'Disabled'
-  },
+  }
 }
