@@ -21,5 +21,7 @@ export default {
   userName_tips: '请输入用户名',
   userPassword: '密码',
   userPassword_tips: '请输入密码',
-  login: '登录'
+  login: '登录',
+  loginWithOAuth2: '通过OAuth2登录',
+  ssoLogin: '单点登录'
 }
