@@ -27,7 +27,6 @@ export default {
     project_description: '项目描述',
     owned_users: '所属用户',
     workflow_define_count: '工作流定义数',
-    process_instance_running_count: '正在运行的流程数',
     description: '描述',
     create_time: '创建时间',
     update_time: '更新时间',
@@ -41,7 +40,8 @@ export default {
     no_permission: '无权限',
     read_permission: '读权限',
     all_permission: '所有权限',
-    assign_worker_group: '分配WorkerGroup'
+    assign_worker_group: '分配WorkerGroup',
+    total_items: '总条目为'
   },
   workflow: {
     on_line: '线上',
@@ -125,7 +125,6 @@ export default {
     complement_data: '补数',
     startup_parameter: '启动参数',
     whether_dry_run: '是否空跑',
-    whether_test: '是否测试',
     continue: '继续',
     end: '结束',
     none_send: '都不发',
@@ -229,9 +228,7 @@ export default {
     workflow_relation_no_data_result_title: '工作流关系不存在',
     workflow_relation_no_data_result_desc:
       '目前没有任何工作流，请先创建工作流，再访问该页面',
-    ready_to_block: '准备锁定',
-    block: '锁定',
-    want_to_set_timing: '现在想去配置该工作流定时?',
+    wait_to_run: '等待执行',
     confirm_to_online: '是否确定上线该工作流?',
     confirm_to_offline: '是否确定下线该工作流?',
     time_to_online: '是否确定上线该定时?',
@@ -247,7 +244,7 @@ export default {
       '下游存在依赖，你不能删除该任务.',
     warning_delete_scheduler_dependent_tasks_desc:
       '下游存在依赖, 删除定时可能会对下游任务产生影响. 你确定要删除该定时嘛?',
-    warning_too_large_parallelism_number: '并行度设置太大了, 最好不要超过10.',
+    warning_too_large_parallelism_number: '并行度设置太大了, 最好不要超过10.'
   },
   task: {
     on_line: '线上',
@@ -265,7 +262,6 @@ export default {
     create_task: '创建任务',
     workflow_instance: '工作流实例',
     workflow_name: '工作流名称',
-    workflow_name_tips: '请选择工作流名称',
     workflow_state: '工作流状态',
     version: '版本',
     current_version: '当前版本',
@@ -316,7 +312,6 @@ export default {
     startup_parameter: '启动参数',
     whether_dry_run: '是否空跑',
     please_choose: '请选择',
-    remove_task_cache: '清除缓存',
     delete_validate_dependent_tasks_desc: '下游存在依赖，你不能删除该任务定义'
   },
   dag: {
@@ -335,10 +330,9 @@ export default {
     rows: '行数',
     cols: '列数',
     copy_success: '复制成功',
-    workflow_name: '工作流名称',
     description: '描述',
     timeout_alert: '超时告警',
-    process_execute_type: '执行策略',
+    workflow_execute_type: '执行策略',
     parallel: '并行',
     serial_wait: '串行等待',
     serial_discard: '串行抛弃',
@@ -364,7 +358,6 @@ export default {
     online: '已上线'
   },
   node: {
-    is_cache: '缓存执行',
     is_module_path: '使用模块路径',
     run_type: '运行类型',
     jvm_args: '虚拟机参数',
@@ -381,8 +374,6 @@ export default {
     name_tips: '请输入名称(必填)',
     task_type: '任务类型',
     task_type_tips: '请选择任务类型(必选)',
-    workflow_name: '工作流名称',
-    workflow_name_tips: '请选择工作流(必选)',
     child_node: '子节点',
     child_node_tips: '请选择子节点(必选)',
     run_flag: '运行标志',
@@ -462,8 +453,9 @@ export default {
     expression_value_tips: '表达式值集(选填)',
     pre_tasks: '前置任务',
     program_type: '程序类型',
-    main_class: '主函数的Class',
-    main_class_tips: '请填写主函数的Class',
+    main_class: '主类名',
+    main_class_tips: '请填写完整主类名(可选)',
+    main_class_invalid: '主类名不合法',
     main_package: '主程序包',
     main_package_tips: '请选择主程序包',
     deploy_mode: '部署方式',
@@ -505,21 +497,19 @@ export default {
     http_method: '请求类型',
     http_parameters: '请求参数',
     http_body: '请求Body',
-    http_body_tips: '请填写http body,如若填写将忽略请求参数中的body类型参数',
+    http_body_tips: '请填写http body',
     http_check_condition: '校验条件',
     http_condition: '校验内容',
     http_condition_tips: '请填写校验内容',
     timeout_settings: '超时设置',
     connect_timeout: '连接超时',
     ms: '毫秒',
-    socket_timeout: 'Socket超时',
     status_code_default: '默认响应码200',
     status_code_custom: '自定义响应码',
     body_contains: '内容包含',
     body_not_contains: '内容不包含',
     http_parameters_position: '参数位置',
     target_task_name: '目标任务名',
-    target_task_name_tips: '请输入Pigeon任务名(必填)',
     datasource_type: '数据源类型',
     datasource_instances: '数据源实例',
     sql_type: 'SQL类型',
@@ -662,8 +652,8 @@ export default {
     waiting_dependent_complete: '等待依赖完成',
     project_name: '项目名称',
     project_name_tips: '项目名称（必填）',
-    process_name: '工作流名称',
-    process_name_tips: '工作流名称（必填）',
+    workflow_name: '工作流名称',
+    workflow_name_tips: '工作流名称（必填）',
     cycle_time: '时间周期',
     cycle_time_tips: '时间周期（必填）',
     date_tips: '日期（必填）',
@@ -804,17 +794,16 @@ export default {
     dvc_load_save_data_path: 'Worker中数据路径',
     dvc_store_url: '数据存储地址',
     dvc_empty_tips: '该参数不能为空',
-    send_email: '发送邮件',
+    send_alarm: '发送告警',
     log_display: '日志显示',
     rows_of_result: '行查询结果',
     title: '主题',
-    title_tips: '请输入邮件主题',
+    title_tips: '请输入告警主题',
     alarm_group: '告警组',
     alarm_group_tips: '告警组必填',
     integer_tips: '请输入一个正整数',
     sql_parameter: 'sql参数',
     format_tips: '请输入格式为',
-    udf_function: 'UDF函数',
     unlimited: '不限制',
     please_select_source_connector_type: '请选择源数据类型',
     please_select_source_datasource_id: '请选择源数据源',
@@ -851,8 +840,8 @@ export default {
     pytorch_other_params: '展开更多配置',
     pytorch_python_path: 'python项目地址',
     pytorch_is_create_environment: '是否创建新环境',
-    pytorch_python_command: 'python命令路径',
-    pytorch_python_command_tips: '若为空，则使用$PYTHON_LAUNCHER',
+    pytorch_python_launcher: 'python解释器路径',
+    pytorch_python_launcher_tips: '若为空，则使用$PYTHON_LAUNCHER',
     pytorch_python_env_tool: 'python环境管理工具',
     pytorch_requirements: '依赖文件',
     pytorch_conda_python_version: 'python版本',
@@ -872,16 +861,42 @@ export default {
     filter_condition: '过滤条件',
     params_value: '取值参数',
     separator: '分隔符',
-    dynamic_name_tips: 'name(必填)',
-    dynamic_value_tips: 'params or value(必填)',
-    dynamic_separator_tips: '分隔符(必填)',
     child_node_definition: '子节点定义',
     child_node_instance: '子节点实例',
     yarn_queue: 'Yarn队列',
     yarn_queue_tips: '请输入Yarn队列(选填)',
     dependent_type: '依赖类型',
     dependent_on_workflow: '依赖于工作流',
-    dependent_on_task: '依赖于任务'
+    dependent_on_task: '依赖于任务',
+    region_id: 'region id',
+    region_id_tips: 'region id',
+    endpoint: 'endpoint',
+    endpoint_tips: '请输入endpoint',
+    access_key_id: 'access key id',
+    access_key_id_tips: 'access key id',
+    access_key_secret: 'access key secret',
+    access_key_secret_tips: 'access key secret',
+    workspace_id: 'workspace id',
+    workspace_id_tips: 'workspace id',
+    resource_queue_id: 'resource queue id',
+    resource_queue_id_tips: 'resource queue id',
+    code_type: 'code type',
+    code_type_tips: 'code type',
+    job_name: 'job name',
+    job_name_tips: 'job name',
+    engine_release_version: 'engine release version',
+    engine_release_version_tips: 'engine release version',
+    entry_point: 'entry point',
+    entry_point_tips: 'entry point',
+    entry_point_arguments: 'entry point arguments',
+    entry_point_arguments_tips: 'entry point arguments',
+    spark_submit_parameters: 'spark submit parameters',
+    spark_submit_parameters_tips: 'spark submit parameters',
+    template_id: 'spark template id',
+    template_id_tips: 'spark template id',
+    is_production: 'is production',
+    is_production_tips: 'is production',
+    json_format_tips: 'JSON参数格式异常'
   },
   menu: {
     fav: '收藏组件',
@@ -889,7 +904,6 @@ export default {
     cloud: '云',
     logic: '逻辑节点',
     di: '数据集成',
-    dq: '数据质量',
     ml: '机器学习',
     other: '其他'
   },
@@ -900,12 +914,14 @@ export default {
     code: '参数编码',
     name: '参数名称',
     value: '参数值',
+    data_type: '参数类型',
     create_user: '创建用户',
     modify_user: '修改用户',
     create_time: '创建时间',
     update_time: '更新时间',
     name_tips: '请输入参数名称',
     value_tips: '请输入参数值',
+    data_type_tips: '请选择参数类型',
     operation: '操作',
     edit: '编辑',
     delete: '删除',
