@@ -64,6 +64,7 @@ export default {
     group_name_tips: '请输入分组名称',
     worker_addresses: 'Worker地址',
     worker_addresses_tips: '请选择Worker地址',
+    source: '来源',
     create_time: '创建时间',
     update_time: '更新时间'
   },
@@ -148,18 +149,14 @@ export default {
     project: '项目',
     resource: '资源',
     file_resource: '文件资源',
-    udf_resource: 'UDF资源',
     datasource: '数据源',
-    udf: 'UDF函数',
     namespace: '命名空间',
     revoke_auth: '撤销权限',
     grant_read: '授予读权限',
     grant_all: '授予所有权限',
     authorize_project: '项目授权',
-    authorize_resource: '资源授权',
     authorize_namespace: '命名空间授权',
     authorize_datasource: '数据源授权',
-    authorize_udf: 'UDF函数授权',
     username: '用户名',
     username_exists: '用户名已存在',
     username_tips: '请输入用户名',
@@ -201,8 +198,6 @@ export default {
     alarm_instance_name: '告警实例名称',
     alarm_instance_name_tips: '请输入告警实例名称',
     alarm_plugin_name: '告警插件名称',
-    alarm_instance_type: '告警实例类型',
-    is_global_instance: '是否全局告警实例',
     create_time: '创建时间',
     update_time: '更新时间',
     operation: '操作',
@@ -246,7 +241,7 @@ export default {
     requestType: '请求方式',
     headerParams: '请求头',
     bodyParams: '请求体',
-    contentField: '内容字段',
+    contentType: 'Content Type',
     timeout: '超时时间（秒）',
     Keyword: '关键词',
     userParams: '自定义参数',
@@ -268,7 +263,7 @@ export default {
     // eslint-disable-next-line quotes
     AtMobiles: "被{'@'}人的手机号",
     // eslint-disable-next-line quotes
-    AtUserIds: "被{'@'}人的用户ID",
+    AtDingtalkIds: "被{'@'}人的用户ID",
     MsgType: '消息类型',
     // eslint-disable-next-line quotes
     IsAtAll: "{'@'}所有人",
