@@ -179,17 +179,6 @@ export default {
         auth: []
       }
     },
-    {
-      path: '/projects/:projectCode/task/definitions',
-      name: 'task-definition',
-      component: components['projects-task-definition'],
-      meta: {
-        title: '任务定义',
-        activeMenu: 'projects',
-        showSide: true,
-        auth: []
-      }
-    },
     {
       path: '/projects/:projectCode/task/instances',
       name: 'task-instance',
