@@ -16,13 +16,7 @@
  */
 
 import { axios } from '@/service/service'
-import {
-  ExecuteReq,
-  ExecuteTaskReq,
-  ProjectCodeReq,
-  ProcessDefinitionCodeReq,
-  ProcessInstanceReq
-} from './types'
+import { ExecuteReq, ExecuteTaskReq, WorkflowInstanceReq } from './types'
 
 export function execute(data: ExecuteReq, code: number): any {
   return axios({
@@ -40,23 +34,12 @@ export function executeTask(data: ExecuteTaskReq, code: number): any {
   })
 }
 
-export function startCheckProcessDefinition(
-  data: ProcessDefinitionCodeReq,
-  code: ProjectCodeReq
-): any {
-  return axios({
-    url: `/projects/${code}/executors/start-check`,
-    method: 'post',
-    data
-  })
-}
-
-export function startProcessInstance(
-  data: ProcessInstanceReq,
+export function startWorkflowInstance(
+  data: WorkflowInstanceReq,
   code: number
 ): any {
   return axios({
-    url: `/projects/${code}/executors/start-process-instance`,
+    url: `/projects/${code}/executors/start-workflow-instance`,
     method: 'post',
     data
   })
