@@ -27,7 +27,6 @@ import {
   GrantResourceReq,
   GrantProject,
   ProjectCodeReq,
-  GrantUDFReq,
   GrantNamespaceReq,
   ListAllReq,
   ListReq,
@@ -129,14 +128,6 @@ export function grantProjectByCode(data: ProjectCodeReq & UserIdReq): any {
   })
 }
 
-export function grantUDFFunc(data: GrantUDFReq & UserIdReq) {
-  return axios({
-    url: '/users/grant-udf-func',
-    method: 'post',
-    data
-  })
-}
-
 export function grantNamespaceFunc(data: GrantNamespaceReq & UserIdReq) {
   return axios({
     url: '/users/grant-namespace',
