@@ -17,6 +17,7 @@
 
 import axios, { AxiosRequestConfig, AxiosResponse, AxiosError } from 'axios'
 import { useUserStore } from '@/store/user/user'
+import { useUISettingStore } from '@/store/ui-setting/ui-setting'
 import qs from 'qs'
 import _ from 'lodash'
 import cookies from 'js-cookie'
@@ -24,6 +25,7 @@ import router from '@/router'
 import utils from '@/utils'
 
 const userStore = useUserStore()
+const uiSettingStore = useUISettingStore()
 
 /**
  * @description Log and display errors
@@ -43,7 +45,7 @@ const baseRequestConfig: AxiosRequestConfig = {
     import.meta.env.MODE === 'development'
       ? '/dolphinscheduler'
       : import.meta.env.VITE_APP_PROD_WEB_URL + '/dolphinscheduler',
-  timeout: 15000,
+  timeout: uiSettingStore.getApiTimer ? uiSettingStore.getApiTimer : 20000,
   transformRequest: (params) => {
     if (_.isPlainObject(params)) {
       return qs.stringify(params, { arrayFormat: 'repeat' })
@@ -63,6 +65,7 @@ const err = (err: AxiosError): Promise<AxiosError> => {
     userStore.setSessionId('')
     userStore.setSecurityConfigType('')
     userStore.setUserInfo({})
+    userStore.setBaseResDir('')
     router.push({ path: '/login' })
   }
 
@@ -70,9 +73,9 @@ const err = (err: AxiosError): Promise<AxiosError> => {
 }
 
 service.interceptors.request.use((config: AxiosRequestConfig<any>) => {
-  config.headers && (config.headers.sessionId = userStore.getSessionId)
-  const language = cookies.get('language')
   config.headers = config.headers || {}
+  config.headers.sessionId = userStore.getSessionId
+  const language = cookies.get('language')
   if (language) config.headers.language = language
 
   return config
