@@ -17,7 +17,7 @@
 
 import { timezoneList } from '@/common/timezone'
 
-type Timezone = typeof timezoneList[number]
+type Timezone = (typeof timezoneList)[number]
 
 interface timezoneStore {
   timezone: Timezone
