@@ -15,6 +15,12 @@
  * limitations under the License.
  */
 
+const trim = (value: string) => {
+  return !value.startsWith(' ') && !value.endsWith(' ')
+}
+
 export const noSpace = (value: string) => {
   return value.indexOf(' ') === -1
 }
+
+export default trim
