@@ -155,6 +155,10 @@ const DetailModal = defineComponent({
       showHost,
       showPort,
       showRestEndpoint,
+      showAccessKeyId,
+      showAccessKeySecret,
+      showRegionId,
+      showEndpoint,
       showAwsRegion,
       showCompatibleMode,
       showConnectType,
@@ -163,6 +167,8 @@ const DetailModal = defineComponent({
       showDataBaseName,
       showJDBCConnectParameters,
       showPublicKey,
+      showNamespace,
+      showKubeConfig,
       modeOptions,
       redShiftModeOptions,
       sagemakerModeOption,
@@ -268,6 +274,65 @@ const DetailModal = defineComponent({
                     placeholder={t('datasource.zeppelin_rest_endpoint_tips')}
                   />
                 </NFormItem>
+                <NFormItem
+                  v-show={showAccessKeyId}
+                  label={t('datasource.access_key_id')}
+                  path='accessKeyId'
+                  show-require-mark
+                >
+                  <NInput
+                    allowInput={this.trim}
+                    class='input-access_key_id'
+                    v-model={[detailForm.accessKeyId, 'value']}
+                    type='text'
+                    maxlength={255}
+                    placeholder={t('datasource.access_key_id_tips')}
+                  />
+                </NFormItem>
+                <NFormItem
+                  v-show={showAccessKeySecret}
+                  label={t('datasource.access_key_secret')}
+                  path='accessKeySecret'
+                  show-require-mark
+                >
+                  <NInput
+                    allowInput={this.trim}
+                    class='input-access_key_secret'
+                    v-model={[detailForm.accessKeySecret, 'value']}
+                    type='text'
+                    maxlength={255}
+                    placeholder={t('datasource.access_key_secret_tips')}
+                  />
+                </NFormItem>
+                <NFormItem
+                  v-show={showRegionId}
+                  label={t('datasource.region_id')}
+                  path='regionId'
+                  show-require-mark
+                >
+                  <NInput
+                    allowInput={this.trim}
+                    class='input-region_id'
+                    v-model={[detailForm.regionId, 'value']}
+                    type='text'
+                    maxlength={255}
+                    placeholder={t('datasource.region_id_tips')}
+                  />
+                </NFormItem>
+                <NFormItem
+                  v-show={showEndpoint}
+                  label={t('datasource.endpoint')}
+                  path='endpoint'
+                >
+                  <NInput
+                    allowInput={this.trim}
+                    class='input-endpoint'
+                    v-model={[detailForm.endpoint, 'value']}
+                    type='text'
+                    maxlength={255}
+                    placeholder={t('datasource.endpoint_tips')}
+                  />
+                </NFormItem>
                 <NFormItem
                   v-show={showPort}
                   label={t('datasource.port')}
@@ -542,6 +607,11 @@ const DetailModal = defineComponent({
                   />
                 </NFormItem>
                 <NFormItem
+                  v-show={
+                    (!showMode || detailForm.mode === 'password') &&
+                    detailForm.type != 'K8S' &&
+                    detailForm.type != 'ALIYUN_SERVERLESS_SPARK'
+                  }
                   label={t('datasource.user_name')}
                   path='userName'
                   show-require-mark
@@ -556,6 +626,11 @@ const DetailModal = defineComponent({
                   />
                 </NFormItem>
                 <NFormItem
+                  v-show={
+                    (!showMode || detailForm.mode === 'password') &&
+                    detailForm.type != 'K8S' &&
+                    detailForm.type != 'ALIYUN_SERVERLESS_SPARK'
+                  }
                   label={t('datasource.user_password')}
                   path='password'
                 >
@@ -676,6 +751,35 @@ const DetailModal = defineComponent({
                     }}
                   />
                 </NFormItem>
+                <NFormItem
+                  v-show={showKubeConfig}
+                  label={t('datasource.kubeConfig')}
+                  path='kubeConfig'
+                  show-require-mark
+                >
+                  <NInput
+                    allowInput={this.trim}
+                    class='input-kubeConfig'
+                    v-model={[detailForm.kubeConfig, 'value']}
+                    type='textarea'
+                    autosize={{
+                      minRows: 14
+                    }}
+                    placeholder={t('datasource.kubeConfig_tips')}
+                  />
+                </NFormItem>
+                <NFormItem
+                  v-show={showNamespace}
+                  label={t('datasource.namespace')}
+                  path='namespace'
+                  show-require-mark
+                >
+                  <NInput
+                    allowInput={this.trim}
+                    v-model={[detailForm.namespace, 'value']}
+                    placeholder={t('datasource.namespace_tips')}
+                  />
+                </NFormItem>
               </NForm>
             </NSpin>
           ),
