@@ -69,6 +69,12 @@ export function useForm(id?: number) {
     showDataBaseName: true,
     showJDBCConnectParameters: true,
     showPublicKey: false,
+    showNamespace: false,
+    showKubeConfig: false,
+    showAccessKeyId: false,
+    showAccessKeySecret: false,
+    showRegionId: false,
+    showEndpoint: false,
     rules: {
       name: {
         trigger: ['input'],
@@ -118,7 +124,9 @@ export function useForm(id?: number) {
         validator() {
           if (
             !state.detailForm.userName &&
-            state.detailForm.type !== 'AZURESQL'
+            state.detailForm.type !== 'AZURESQL' &&
+            state.detailForm.type !== 'K8S' &&
+            state.detailForm.type !== 'ALIYUN_SERVERLESS_SPARK'
           ) {
             return new Error(t('datasource.user_name_tips'))
           }
@@ -242,7 +250,8 @@ export function useForm(id?: number) {
     state.detailForm.port = options.previousPort || options.defaultPort
     state.detailForm.type = type
 
-    state.requiredDataBase = type !== 'POSTGRESQL' && type !== 'ATHENA'
+    state.requiredDataBase =
+      type !== 'POSTGRESQL' && type !== 'ATHENA' && type !== 'DOLPHINDB'
 
     state.showHost = type !== 'ATHENA'
     state.showPort = type !== 'ATHENA'
@@ -261,11 +270,23 @@ export function useForm(id?: number) {
     } else {
       state.showPrincipal = false
     }
-    if (type === 'SSH' || type === 'ZEPPELIN' || type === 'SAGEMAKER') {
+
+    if (
+      type === 'SSH' ||
+      type === 'ZEPPELIN' ||
+      type === 'SAGEMAKER' ||
+      type === 'K8S' ||
+      type === 'ALIYUN_SERVERLESS_SPARK' ||
+      type === 'DOLPHINDB'
+    ) {
       state.showDataBaseName = false
       state.requiredDataBase = false
       state.showJDBCConnectParameters = false
       state.showPublicKey = false
+      if (type === 'DOLPHINDB') {
+        state.showJDBCConnectParameters = true
+        state.showPublicKey = false
+      }
       if (type === 'SSH') {
         state.showPublicKey = true
       }
@@ -273,16 +294,47 @@ export function useForm(id?: number) {
         state.showHost = false
         state.showPort = false
         state.showRestEndpoint = true
+      } else {
+        state.showRestEndpoint = false
       }
-      if (type === 'SAGEMAKER') {
+      if (
+        type === 'SAGEMAKER' ||
+        type === 'K8S' ||
+        type == 'ALIYUN_SERVERLESS_SPARK'
+      ) {
         state.showHost = false
         state.showPort = false
       }
+      if (type === 'K8S') {
+        state.showNamespace = true
+        state.showKubeConfig = true
+      } else {
+        state.showNamespace = false
+        state.showKubeConfig = false
+      }
+      if (type === 'ALIYUN_SERVERLESS_SPARK') {
+        state.showAccessKeyId = true
+        state.showAccessKeySecret = true
+        state.showRegionId = true
+        state.showEndpoint = true
+      } else {
+        state.showAccessKeyId = false
+        state.showAccessKeySecret = false
+        state.showRegionId = false
+        state.showEndpoint = false
+      }
     } else {
       state.showDataBaseName = true
       state.requiredDataBase = true
       state.showJDBCConnectParameters = true
       state.showPublicKey = false
+      state.showRestEndpoint = false
+      state.showNamespace = false
+      state.showKubeConfig = false
+      state.showAccessKeyId = false
+      state.showAccessKeySecret = false
+      state.showRegionId = false
+      state.showEndpoint = false
     }
   }
 
@@ -441,6 +493,21 @@ export const datasourceType: IDataBaseOptionKeys = {
     value: 'SAGEMAKER',
     label: 'SAGEMAKER',
     defaultPort: 0
+  },
+  K8S: {
+    value: 'K8S',
+    label: 'K8S',
+    defaultPort: 6443
+  },
+  ALIYUN_SERVERLESS_SPARK: {
+    value: 'ALIYUN_SERVERLESS_SPARK',
+    label: 'ALIYUN_SERVERLESS_SPARK',
+    defaultPort: 0
+  },
+  DOLPHINDB: {
+    value: 'DOLPHINDB',
+    label: 'DOLPHINDB',
+    defaultPort: 8848
   }
 }
 
