@@ -30,6 +30,7 @@ import Card from '@/components/card'
 import Search from '@/components/input-search'
 import ProjectModal from './components/project-modal'
 import WorkerGroupModal from '@/views/projects/list/components/worker-group-modal'
+import totalCount from '@/utils/tableTotalCount'
 
 const list = defineComponent({
   name: 'list',
@@ -155,12 +156,13 @@ const list = defineComponent({
               <NPagination
                 v-model:page={this.page}
                 v-model:page-size={this.pageSize}
-                page-count={this.totalPage}
                 show-size-picker
                 page-sizes={[10, 30, 50]}
                 show-quick-jumper
                 onUpdatePage={this.requestData}
                 onUpdatePageSize={this.handleChangePageSize}
+                itemCount={this.totalCount}
+                prefix={totalCount}
               />
             </NSpace>
           </NSpace>
