@@ -39,18 +39,29 @@ import {
 } from '@/common/column-width-config'
 import type { Router } from 'vue-router'
 import type { ProjectRes } from '@/service/modules/projects/types'
-import { DeleteOutlined, EditOutlined } from '@vicons/antd'
+import { ControlOutlined, DeleteOutlined, EditOutlined } from '@vicons/antd'
+import { useUserStore } from '@/store/user/user'
+import { UserInfoRes } from '@/service/modules/users/types'
 
 export function useTable() {
   const { t } = useI18n()
   const router: Router = useRouter()
 
+  const userStore = useUserStore()
+  const userInfo = userStore.getUserInfo as UserInfoRes
+  const IS_ADMIN = userInfo.userType === 'ADMIN_USER'
+
   const handleEdit = (row: any) => {
     variables.showModalRef = true
     variables.statusRef = 1
     variables.row = row
   }
 
+  const handleAssign = (row: any) => {
+    variables.showWorkerGroupModalRef = true
+    variables.row = row
+  }
+
   const handleDelete = (row: any) => {
     deleteProject(row.code).then(() => {
       getTableData({
@@ -111,14 +122,6 @@ export function useTable() {
           tooltip: true
         }
       },
-      {
-        title: t('project.list.process_instance_running_count'),
-        key: 'instRunningCount',
-        width: 120,
-        ellipsis: {
-          tooltip: true
-        }
-      },
       {
         title: t('project.list.description'),
         key: 'description',
@@ -137,7 +140,7 @@ export function useTable() {
       {
         title: t('project.list.operation'),
         key: 'actions',
-        ...COLUMN_WIDTH_CONFIG['operation'](2),
+        ...COLUMN_WIDTH_CONFIG['operation'](3),
         render(row: any) {
           return h(NSpace, null, {
             default: () => [
@@ -165,6 +168,32 @@ export function useTable() {
                   default: () => t('project.list.edit')
                 }
               ),
+              IS_ADMIN &&
+                h(
+                  NTooltip,
+                  {
+                    trigger: 'hover'
+                  },
+                  {
+                    trigger: () =>
+                      h(
+                        NButton,
+                        {
+                          circle: true,
+                          type: 'info',
+                          size: 'small',
+                          class: 'assign-worker-group-btn',
+                          onClick: () => {
+                            handleAssign(row)
+                          }
+                        },
+                        {
+                          icon: () => h(NIcon, null, () => h(ControlOutlined))
+                        }
+                      ),
+                    default: () => t('project.list.assign_worker_group')
+                  }
+                ),
               h(
                 NPopconfirm,
                 {
@@ -218,7 +247,9 @@ export function useTable() {
     pageSize: ref(10),
     searchVal: ref(''),
     totalPage: ref(1),
+    totalCount: ref(0),
     showModalRef: ref(false),
+    showWorkerGroupModalRef: ref(false),
     statusRef: ref(0),
     row: {},
     loadingRef: ref(false)
@@ -229,6 +260,7 @@ export function useTable() {
     variables.loadingRef = true
     const { state } = useAsyncState(
       queryProjectListPaging(params).then((res: ProjectRes) => {
+        variables.totalCount = res.total
         variables.totalPage = res.totalPage
         variables.tableData = res.totalList.map((item, unused) => {
           item.createTime = format(
