@@ -29,7 +29,6 @@ export function useDatasource(
     typeField?: string
     sourceField?: string
     span?: Ref | number
-    testFlag?: Ref | number
   } = {}
 ): IJsonItem[] {
   const { t } = useI18n()
@@ -157,6 +156,16 @@ export function useDatasource(
       id: 25,
       code: 'SAGEMAKER',
       disabled: false
+    },
+    {
+      id: 27,
+      code: 'ALIYUN_SERVERLESS_SPARK',
+      disabled: false
+    },
+    {
+      id: 28,
+      code: 'DOLPHINDB',
+      disabled: false
     }
   ]
 
@@ -176,8 +185,7 @@ export function useDatasource(
 
   const refreshOptions = async () => {
     const parameters = {
-      type: model[params.typeField || 'type'],
-      testFlag: 0
+      type: model[params.typeField || 'type']
     } as TypeReq
     const res = await queryDataSourceList(parameters)
     datasourceOptions.value = res.map((item: any) => ({
