@@ -129,7 +129,10 @@ export function useDataX(model: { [field: string]: any }): IJsonItem[] {
     'ORACLE',
     'SQLSERVER',
     'CLICKHOUSE',
-    'HIVE'
+    'DATABEND',
+    'HIVE',
+    'PRESTO',
+    'OCEANBASE'
   ]
   onMounted(() => {
     initConstants()
