@@ -28,14 +28,14 @@ import type {
 import { ref } from 'vue'
 
 export function formatParams(data: INodeData): {
-  processDefinitionCode: string
+  workflowDefinitionCode: string
   upstreamCodes: string
   taskDefinitionJsonObj: object
 } {
   const rdbmsSourceTypes = ref(['MYSQL', 'ORACLE', 'SQLSERVER', 'HANA'])
   const taskParams: ITaskParams = {}
-  if (data.taskType === 'SUB_PROCESS' || data.taskType === 'DYNAMIC') {
-    taskParams.processDefinitionCode = data.processDefinitionCode
+  if (data.taskType === 'SUB_WORKFLOW') {
+    taskParams.workflowDefinitionCode = data.workflowDefinitionCode
   }
 
   if (data.taskType === 'JAVA') {
@@ -43,7 +43,11 @@ export function formatParams(data: INodeData): {
     taskParams.mainArgs = data.mainArgs
     taskParams.jvmArgs = data.jvmArgs
     taskParams.isModulePath = data.isModulePath
-    if (data.runType === 'JAR' && data.mainJar) {
+    taskParams.mainClass = data.mainClass
+    if (
+      (data.runType === 'FAT_JAR' || data.runType === 'NORMAL_JAR') &&
+      data.mainJar
+    ) {
       taskParams.mainJar = { resourceName: data.mainJar }
     }
   }
@@ -194,14 +198,6 @@ export function formatParams(data: INodeData): {
       taskParams.title = data.title
       taskParams.groupId = data.groupId
     }
-    if (data.type === 'HIVE') {
-      if (data.udfs) taskParams.udfs = data.udfs.join(',')
-      taskParams.connParams = data.connParams
-    }
-
-    if (data.type === 'KYUUBI') {
-      if (data.udfs) taskParams.udfs = data.udfs.join(',')
-    }
   }
 
   if (data.taskType === 'PROCEDURE') {
@@ -213,7 +209,9 @@ export function formatParams(data: INodeData): {
   if (data.taskType === 'SEATUNNEL') {
     taskParams.startupScript = data.startupScript
     taskParams.useCustom = data.useCustom
-    taskParams.rawScript = data.rawScript
+    if (!data.useCustom) {
+      taskParams.rawScript = ''
+    }
     if (data.startupScript?.includes('flink')) {
       taskParams.runMode = data.runMode
       taskParams.others = data.others
@@ -281,49 +279,6 @@ export function formatParams(data: INodeData): {
       dependTaskList: data.dependTaskList
     }
   }
-  if (data.taskType === 'DATA_QUALITY') {
-    taskParams.ruleId = data.ruleId
-    taskParams.ruleInputParameter = {
-      check_type: data.check_type,
-      comparison_execute_sql: data.comparison_execute_sql,
-      comparison_type: data.comparison_type,
-      comparison_name: data.comparison_name,
-      failure_strategy: data.failure_strategy,
-      operator: data.operator,
-      src_connector_type: data.src_connector_type,
-      src_datasource_id: data.src_datasource_id,
-      src_database: data.src_database,
-      field_length: data.field_length,
-      begin_time: data.begin_time,
-      deadline: data.deadline,
-      datetime_format: data.datetime_format,
-      enum_list: data.enum_list,
-      regexp_pattern: data.regexp_pattern,
-      target_filter: data.target_filter,
-      src_filter: data.src_filter,
-      src_field: data.src_field,
-      src_table: data.src_table,
-      statistics_execute_sql: data.statistics_execute_sql,
-      statistics_name: data.statistics_name,
-      target_connector_type: data.target_connector_type,
-      target_datasource_id: data.target_datasource_id,
-      target_database: data.target_database,
-      target_table: data.target_table,
-      threshold: data.threshold,
-      mapping_columns: JSON.stringify(data.mapping_columns)
-    }
-    taskParams.sparkParameters = {
-      deployMode: data.deployMode,
-      driverCores: data.driverCores,
-      driverMemory: data.driverMemory,
-      executorCores: data.executorCores,
-      executorMemory: data.executorMemory,
-      numExecutors: data.numExecutors,
-      others: data.others,
-      yarnQueue: data.yarnQueue,
-      sqlExecutionType: data.sqlExecutionType
-    }
-  }
 
   if (data.taskType === 'EMR') {
     taskParams.type = data.type
@@ -344,6 +299,21 @@ export function formatParams(data: INodeData): {
     taskParams.type = data.type
   }
 
+  if (data.taskType === 'ALIYUN_SERVERLESS_SPARK') {
+    taskParams.workspaceId = data.workspaceId
+    taskParams.resourceQueueId = data.resourceQueueId
+    taskParams.codeType = data.codeType
+    taskParams.jobName = data.jobName
+    taskParams.engineReleaseVersion = data.engineReleaseVersion
+    taskParams.templateId = data.templateId
+    taskParams.entryPoint = data.entryPoint
+    taskParams.entryPointArguments = data.entryPointArguments
+    taskParams.sparkSubmitParameters = data.sparkSubmitParameters
+    taskParams.isProduction = data.isProduction
+    taskParams.type = data.type
+    taskParams.datasource = data.datasource
+  }
+
   if (data.taskType === 'K8S') {
     taskParams.namespace = data.namespace
     taskParams.minCpuCores = data.minCpuCores
@@ -354,6 +324,9 @@ export function formatParams(data: INodeData): {
     taskParams.args = data.args
     taskParams.customizedLabels = data.customizedLabels
     taskParams.nodeSelectors = data.nodeSelectors
+    taskParams.datasource = data.datasource
+    taskParams.type = data.type
+    taskParams.kubeConfig = data.kubeConfig
     taskParams.pullSecret = data.pullSecret
   }
 
@@ -411,7 +384,7 @@ export function formatParams(data: INodeData): {
     taskParams.scriptParams = data.scriptParams
     taskParams.pythonPath = data.pythonPath
     taskParams.isCreateEnvironment = data.isCreateEnvironment
-    taskParams.pythonCommand = data.pythonCommand
+    taskParams.pythonLauncher = data.pythonLauncher
     taskParams.pythonEnvTool = data.pythonEnvTool
     taskParams.requirements = data.requirements
     taskParams.condaPythonVersion = data.condaPythonVersion
@@ -437,10 +410,6 @@ export function formatParams(data: INodeData): {
     taskParams.others = data.others
   }
 
-  if (data.taskType === 'PIGEON') {
-    taskParams.targetJobName = data.targetJobName
-  }
-
   if (data.taskType === 'HIVECLI') {
     taskParams.hiveCliTaskExecutionType = data.hiveCliTaskExecutionType
     taskParams.hiveSqlScript = data.hiveSqlScript
@@ -490,14 +459,6 @@ export function formatParams(data: INodeData): {
     taskParams.datasource = data.datasource
   }
 
-  if (data.taskType === 'DYNAMIC') {
-    taskParams.processDefinitionCode = data.processDefinitionCode
-    taskParams.maxNumOfSubWorkflowInstances = data.maxNumOfSubWorkflowInstances
-    taskParams.degreeOfParallelism = data.degreeOfParallelism
-    taskParams.filterCondition = data.filterCondition
-    taskParams.listParameters = data.listParameters
-  }
-
   let timeoutNotifyStrategy = ''
   if (data.timeoutNotifyStrategy) {
     if (data.timeoutNotifyStrategy.length === 1) {
@@ -508,7 +469,9 @@ export function formatParams(data: INodeData): {
     }
   }
   const params = {
-    processDefinitionCode: data.processName ? String(data.processName) : '',
+    workflowDefinitionCode: data.workflowDefinitionName
+      ? String(data.workflowDefinitionName)
+      : '',
     upstreamCodes: data?.preTasks?.join(','),
     taskDefinitionJsonObj: {
       code: data.code,
@@ -520,7 +483,6 @@ export function formatParams(data: INodeData): {
         : '0',
       failRetryTimes: data.failRetryTimes ? String(data.failRetryTimes) : '0',
       flag: data.flag,
-      isCache: data.isCache ? 'YES' : 'NO',
       name: data.name,
       taskGroupId: data.taskGroupId,
       taskGroupPriority: data.taskGroupPriority,
@@ -549,7 +511,7 @@ export function formatParams(data: INodeData): {
       taskExecuteType: data.taskExecuteType
     }
   } as {
-    processDefinitionCode: string
+    workflowDefinitionCode: string
     upstreamCodes: string
     taskDefinitionJsonObj: { timeout: number; timeoutNotifyStrategy: string }
   }
@@ -571,7 +533,6 @@ export function formatModel(data: ITaskData) {
     ...omit(data.taskParams, ['resourceList', 'mainJar', 'localParams']),
     environmentCode: data.environmentCode === -1 ? null : data.environmentCode,
     timeoutFlag: data.timeoutFlag === 'OPEN',
-    isCache: data.isCache === 'YES',
     timeoutNotifyStrategy: data.timeoutNotifyStrategy
       ? [data.timeoutNotifyStrategy]
       : [],
@@ -740,9 +701,6 @@ export function formatModel(data: ITaskData) {
   if (data.taskParams?.conditionResult?.failedNode?.length) {
     params.failedBranch = data.taskParams.conditionResult.failedNode[0]
   }
-  if (data.taskParams?.udfs) {
-    params.udfs = data.taskParams.udfs?.split(',')
-  }
   if (data.taskParams?.customConfig !== void 0) {
     params.customConfig = data.taskParams.customConfig === 1 ? true : false
   }
