@@ -44,6 +44,7 @@ export function useHttp({
     delayTime: 0,
     timeout: 30,
     httpMethod: 'GET',
+    httpBody: '',
     httpCheckCondition: 'STATUS_CODE_DEFAULT',
     httpParams: [],
     url: '',
@@ -58,10 +59,9 @@ export function useHttp({
       Fields.useName(from),
       ...Fields.useTaskDefinition({ projectCode, from, readonly, data, model }),
       Fields.useRunFlag(),
-      Fields.useCache(),
       Fields.useDescription(),
       Fields.useTaskPriority(),
-      Fields.useWorkerGroup(),
+      Fields.useWorkerGroup(projectCode),
       Fields.useEnvironmentName(model, !data?.id),
       ...Fields.useTaskGroup(model, projectCode),
       ...Fields.useFailed(),
