@@ -46,7 +46,11 @@ export function useK8s({
     workerGroup: 'default',
     delayTime: 0,
     timeout: 30,
-    timeoutNotifyStrategy: ['WARN']
+    type: 'K8S',
+    displayRows: 10,
+    timeoutNotifyStrategy: ['WARN'],
+    kubeConfig: '',
+    namespace: ''
   } as INodeData)
 
   return {
@@ -54,7 +58,6 @@ export function useK8s({
       Fields.useName(),
       ...Fields.useTaskDefinition({ projectCode, from, readonly, data, model }),
       Fields.useRunFlag(),
-      Fields.useCache(),
       Fields.useDescription(),
       Fields.useTaskPriority(),
       Fields.useWorkerGroup(projectCode),
@@ -63,6 +66,7 @@ export function useK8s({
       ...Fields.useFailed(),
       Fields.useDelayTime(model),
       ...Fields.useTimeoutAlarm(model),
+      ...Fields.useDatasource(model),
       ...Fields.useK8s(model),
       Fields.usePreTasks()
     ] as IJsonItem[],
