@@ -49,7 +49,7 @@ export const useForm = () => {
   const startState = reactive({
     startFormRef: ref(),
     startForm: {
-      processDefinitionCode: -1,
+      workflowDefinitionCode: -1,
       startEndTime: [new Date(year, month, day), new Date(year, month, day)],
       scheduleTime: '',
       dataDateType: 1,
@@ -61,14 +61,13 @@ export const useForm = () => {
       taskDependType: 'TASK_POST',
       complementDependentMode: 'OFF_MODE',
       runMode: 'RUN_MODE_SERIAL',
-      processInstancePriority: 'MEDIUM',
+      workflowInstancePriority: 'MEDIUM',
       workerGroup: 'default',
       tenantCode: 'default',
       environmentCode: null,
       startParams: null,
       expectedParallelismNumber: '2',
       dryRun: 0,
-      testFlag: 0,
       version: null,
       allLevelDependent: 'false',
       executionOrder: 'DESC_ORDER'
@@ -117,7 +116,7 @@ export const useForm = () => {
       timezoneId: Intl.DateTimeFormat().resolvedOptions().timeZone,
       failureStrategy: 'CONTINUE',
       warningType: 'NONE',
-      processInstancePriority: 'MEDIUM',
+      workflowInstancePriority: 'MEDIUM',
       warningGroupId: null as null | number,
       workerGroup: 'default',
       tenantCode: 'default',
