@@ -32,7 +32,7 @@ export function useEdit(state: any) {
   const getResourceView = (fullName: string, tenantCode: string) => {
     const params = {
       skipLineNum: 0,
-      limit: 3000,
+      limit: -1,
       fullName: fullName,
       tenantCode: tenantCode
     }
