@@ -154,21 +154,15 @@ export default defineComponent({
     }
 
     const goBread = (fullName: string) => {
-      const { resourceType, tenantCode } = variables
-      const baseDir =
-        resourceType === 'UDF'
-          ? userStore.getBaseUdfDir
-          : userStore.getBaseResDir
+      const { tenantCode } = variables
+      const baseDir = userStore.getBaseResDir
       if (fullName === '' || !fullName.startsWith(baseDir)) {
         router.push({
-          name: resourceType === 'UDF' ? 'resource-manage' : 'file-manage'
+          name: 'file-manage'
         })
       } else {
         router.push({
-          name:
-            resourceType === 'UDF'
-              ? 'resource-sub-manage'
-              : 'resource-file-subdirectory',
+          name: 'resource-file-subdirectory',
           query: { prefix: fullName, tenantCode: tenantCode }
         })
       }
@@ -204,10 +198,7 @@ export default defineComponent({
       handleUploadFile,
       tableWidth
     } = this
-    const manageTitle =
-      this.resourceType === 'UDF'
-        ? t('resource.udf.udf_resources')
-        : t('resource.file.file_manage')
+    const manageTitle = t('resource.file.file_manage')
 
     return (
       <NSpace vertical>
@@ -221,15 +212,13 @@ export default defineComponent({
               >
                 {t('resource.file.create_folder')}
               </NButton>
-              {this.resourceType !== 'UDF' && (
+              {
                 <NButton onClick={handleCreateFile} class='btn-create-file'>
                   {t('resource.file.create_file')}
                 </NButton>
-              )}
+              }
               <NButton onClick={handleUploadFile} class='btn-upload-resource'>
-                {this.resourceType === 'UDF'
-                  ? t('resource.udf.upload_udf_resources')
-                  : t('resource.file.upload_files')}
+                {t('resource.file.upload_files')}
               </NButton>
             </NButtonGroup>
             <NSpace>
