@@ -23,19 +23,13 @@ import {
   onMounted,
   getCurrentInstance
 } from 'vue'
-import {
-  NButton,
-  NIcon,
-  NInput,
-  NDataTable,
-  NPagination,
-  NSpace
-} from 'naive-ui'
+import { NButton, NIcon, NDataTable, NPagination, NSpace } from 'naive-ui'
 import Card from '@/components/card'
 import { SearchOutlined } from '@vicons/antd'
 import { useI18n } from 'vue-i18n'
 import { useTable } from './use-table'
 import FormModal from './components/form-modal'
+import Search from '@/components/input-search'
 
 const taskGroupOption = defineComponent({
   name: 'taskGroupOption',
@@ -163,14 +157,13 @@ const taskGroupOption = defineComponent({
               {t('resource.task_group_option.create')}
             </NButton>
             <NSpace>
-              <NInput
-                allowInput={this.trim}
-                size='small'
-                v-model={[this.name, 'value']}
+              <Search
                 placeholder={t(
                   'resource.task_group_option.please_enter_keywords'
                 )}
-              ></NInput>
+                v-model:value={this.name}
+                onSearch={this.onSearch}
+              ></Search>
               <NButton size='small' type='primary' onClick={onSearch}>
                 <NIcon>
                   <SearchOutlined />
