@@ -16,21 +16,16 @@
  */
 
 import { defineComponent, getCurrentInstance, toRefs } from 'vue'
-import {
-  NButton,
-  NInput,
-  NIcon,
-  NSpace,
-  NDataTable,
-  NPagination
-} from 'naive-ui'
+import { NButton, NIcon, NSpace, NDataTable, NPagination } from 'naive-ui'
 import { useI18n } from 'vue-i18n'
 import { SearchOutlined } from '@vicons/antd'
 import { useColumns } from './use-columns'
 import { useTable } from './use-table'
 import UserDetailModal from './components/user-detail-modal'
 import AuthorizeModal from './components/authorize-modal'
+import PasswordModal from './components/password-modal'
 import Card from '@/components/card'
+import Search from '@/components/input-search'
 
 const UsersManage = defineComponent({
   name: 'user-manage',
@@ -50,6 +45,10 @@ const UsersManage = defineComponent({
     const onAuthorizeModalCancel = () => {
       state.authorizeModalShow = false
     }
+    const onPasswordModalCancel = () => {
+      state.passwordModalShow = false
+    }
+
     const trim = getCurrentInstance()?.appContext.config.globalProperties.trim
 
     return {
@@ -62,6 +61,7 @@ const UsersManage = defineComponent({
       onUpdatedList: updateList,
       onDetailModalCancel,
       onAuthorizeModalCancel,
+      onPasswordModalCancel,
       trim
     }
   },
@@ -79,11 +79,9 @@ const UsersManage = defineComponent({
               {this.t('security.user.create_user')}
             </NButton>
             <NSpace>
-              <NInput
-                allowInput={this.trim}
+              <Search
                 v-model:value={this.searchVal}
-                size='small'
-                clearable
+                onSearch={this.onUpdatedList}
               />
               <NButton type='primary' size='small' onClick={this.onUpdatedList}>
                 <NIcon>
@@ -128,6 +126,11 @@ const UsersManage = defineComponent({
           userId={this.currentRecord?.id}
           onCancel={this.onAuthorizeModalCancel}
         />
+        <PasswordModal
+          show={this.passwordModalShow}
+          currentRecord={this.currentRecord}
+          onCancel={this.onPasswordModalCancel}
+        />
       </NSpace>
     )
   }
