@@ -22,19 +22,13 @@ import {
   toRefs,
   watch
 } from 'vue'
-import {
-  NButton,
-  NDataTable,
-  NIcon,
-  NInput,
-  NPagination,
-  NSpace
-} from 'naive-ui'
+import { NButton, NDataTable, NIcon, NPagination, NSpace } from 'naive-ui'
 import { SearchOutlined } from '@vicons/antd'
 import { useI18n } from 'vue-i18n'
 import { useTable } from './use-table'
 import YarnQueueModal from './components/yarn-queue-modal'
 import Card from '@/components/card'
+import Search from '@/components/input-search'
 
 const yarnQueueManage = defineComponent({
   name: 'yarn-queue-manage',
@@ -122,12 +116,10 @@ const yarnQueueManage = defineComponent({
               {t('security.yarn_queue.create_queue')}
             </NButton>
             <NSpace>
-              <NInput
-                allowInput={this.trim}
-                size='small'
-                clearable
-                v-model={[this.searchVal, 'value']}
+              <Search
+                v-model:value={this.searchVal}
                 placeholder={t('security.yarn_queue.search_tips')}
+                onSearch={onSearch}
               />
               <NButton size='small' type='primary' onClick={onSearch}>
                 <NIcon>
