@@ -17,25 +17,22 @@
 
 package org.apache.dolphinscheduler.server.worker;
 
+import org.apache.dolphinscheduler.common.CommonConfiguration;
 import org.apache.dolphinscheduler.common.IStoppable;
 import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.lifecycle.ServerLifeCycleManager;
+import org.apache.dolphinscheduler.common.thread.DefaultUncaughtExceptionHandler;
 import org.apache.dolphinscheduler.common.thread.ThreadUtils;
-import org.apache.dolphinscheduler.plugin.task.api.TaskExecutionContext;
-import org.apache.dolphinscheduler.plugin.task.api.TaskExecutionContextCacheManager;
+import org.apache.dolphinscheduler.meter.metrics.MetricsProvider;
+import org.apache.dolphinscheduler.meter.metrics.SystemMetrics;
+import org.apache.dolphinscheduler.plugin.datasource.api.plugin.DataSourceProcessorProvider;
+import org.apache.dolphinscheduler.plugin.storage.api.StorageConfiguration;
 import org.apache.dolphinscheduler.plugin.task.api.TaskPluginManager;
-import org.apache.dolphinscheduler.plugin.task.api.utils.LogUtils;
-import org.apache.dolphinscheduler.plugin.task.api.utils.ProcessUtils;
-import org.apache.dolphinscheduler.server.worker.config.WorkerConfig;
-import org.apache.dolphinscheduler.server.worker.message.MessageRetryRunner;
+import org.apache.dolphinscheduler.registry.api.RegistryConfiguration;
+import org.apache.dolphinscheduler.server.worker.executor.PhysicalTaskEngineDelegator;
+import org.apache.dolphinscheduler.server.worker.metrics.WorkerServerMetrics;
 import org.apache.dolphinscheduler.server.worker.registry.WorkerRegistryClient;
-import org.apache.dolphinscheduler.server.worker.rpc.WorkerRpcClient;
 import org.apache.dolphinscheduler.server.worker.rpc.WorkerRpcServer;
-import org.apache.dolphinscheduler.server.worker.runner.WorkerManagerThread;
-
-import org.apache.commons.collections4.CollectionUtils;
-
-import java.util.Collection;
 
 import javax.annotation.PostConstruct;
 
@@ -44,41 +41,26 @@ import lombok.extern.slf4j.Slf4j;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.boot.SpringApplication;
 import org.springframework.boot.autoconfigure.SpringBootApplication;
-import org.springframework.context.annotation.ComponentScan;
-import org.springframework.context.annotation.FilterType;
-import org.springframework.transaction.annotation.EnableTransactionManagement;
+import org.springframework.context.annotation.Import;
 
-@SpringBootApplication
-@EnableTransactionManagement
-@ComponentScan(basePackages = "org.apache.dolphinscheduler", excludeFilters = {
-        @ComponentScan.Filter(type = FilterType.REGEX, pattern = {
-                "org.apache.dolphinscheduler.service.process.*",
-                "org.apache.dolphinscheduler.service.queue.*",
-        })
-})
 @Slf4j
+@Import({CommonConfiguration.class,
+        StorageConfiguration.class,
+        RegistryConfiguration.class})
+@SpringBootApplication
 public class WorkerServer implements IStoppable {
 
-    @Autowired
-    private WorkerManagerThread workerManagerThread;
-
     @Autowired
     private WorkerRegistryClient workerRegistryClient;
 
-    @Autowired
-    private TaskPluginManager taskPluginManager;
-
     @Autowired
     private WorkerRpcServer workerRpcServer;
 
     @Autowired
-    private WorkerRpcClient workerRpcClient;
+    private MetricsProvider metricsProvider;
 
     @Autowired
-    private MessageRetryRunner messageRetryRunner;
-
-    @Autowired
-    private WorkerConfig workerConfig;
+    private PhysicalTaskEngineDelegator physicalTaskEngineDelegator;
 
     /**
      * worker server startup, not use web service
@@ -86,22 +68,39 @@ public class WorkerServer implements IStoppable {
      * @param args arguments
      */
     public static void main(String[] args) {
+        WorkerServerMetrics.registerUncachedException(DefaultUncaughtExceptionHandler::getUncaughtExceptionCount);
+        Thread.setDefaultUncaughtExceptionHandler(DefaultUncaughtExceptionHandler.getInstance());
         Thread.currentThread().setName(Constants.THREAD_NAME_WORKER_SERVER);
         SpringApplication.run(WorkerServer.class);
     }
 
     @PostConstruct
     public void run() {
+        ServerLifeCycleManager.toRunning();
+
         this.workerRpcServer.start();
-        this.workerRpcClient.start();
-        this.taskPluginManager.loadPlugin();
+
+        TaskPluginManager.loadTaskPlugin();
+
+        DataSourceProcessorProvider.initialize();
 
         this.workerRegistryClient.setRegistryStoppable(this);
         this.workerRegistryClient.start();
 
-        this.workerManagerThread.start();
+        this.physicalTaskEngineDelegator.start();
 
-        this.messageRetryRunner.start();
+        WorkerServerMetrics.registerWorkerCpuUsageGauge(() -> {
+            SystemMetrics systemMetrics = metricsProvider.getSystemMetrics();
+            return systemMetrics.getSystemCpuUsagePercentage();
+        });
+        WorkerServerMetrics.registerWorkerMemoryAvailableGauge(() -> {
+            SystemMetrics systemMetrics = metricsProvider.getSystemMetrics();
+            return (systemMetrics.getSystemMemoryMax() - systemMetrics.getSystemMemoryUsed()) / 1024.0 / 1024 / 1024;
+        });
+        WorkerServerMetrics.registerWorkerMemoryUsageGauge(() -> {
+            SystemMetrics systemMetrics = metricsProvider.getSystemMetrics();
+            return systemMetrics.getJvmMemoryUsedPercentage();
+        });
 
         /*
          * registry hooks, which are called before the process exits
@@ -121,11 +120,10 @@ public class WorkerServer implements IStoppable {
         ThreadUtils.sleep(Constants.SERVER_CLOSE_WAIT_TIME.toMillis());
 
         try (
-                WorkerRpcServer closedWorkerRpcServer = workerRpcServer;
-                WorkerRegistryClient closedRegistryClient = workerRegistryClient) {
+                final PhysicalTaskEngineDelegator ignore1 = physicalTaskEngineDelegator;
+                final WorkerRpcServer ignore2 = workerRpcServer;
+                final WorkerRegistryClient ignore3 = workerRegistryClient) {
             log.info("Worker server is stopping, current cause : {}", cause);
-            // kill running tasks
-            this.killAllRunningTasks();
         } catch (Exception e) {
             log.error("Worker server stop failed, current cause: {}", cause, e);
             return;
@@ -136,27 +134,10 @@ public class WorkerServer implements IStoppable {
     @Override
     public void stop(String cause) {
         close(cause);
+
+        // make sure exit after server closed, don't call System.exit in close logic, will cause deadlock if close
+        // multiple times at the same time
+        System.exit(1);
     }
 
-    public void killAllRunningTasks() {
-        Collection<TaskExecutionContext> taskRequests = TaskExecutionContextCacheManager.getAllTaskRequestList();
-        if (CollectionUtils.isEmpty(taskRequests)) {
-            return;
-        }
-        log.info("Worker begin to kill all cache task, task size: {}", taskRequests.size());
-        int killNumber = 0;
-        for (TaskExecutionContext taskRequest : taskRequests) {
-            // kill task when it's not finished yet
-            try (
-                    final LogUtils.MDCAutoClosableContext mdcAutoClosableContext =
-                            LogUtils.setWorkflowAndTaskInstanceIDMDC(taskRequest.getProcessInstanceId(),
-                                    taskRequest.getTaskInstanceId())) {
-                if (ProcessUtils.kill(taskRequest)) {
-                    killNumber++;
-                }
-            }
-        }
-        log.info("Worker after kill all cache task, task size: {}, killed number: {}", taskRequests.size(),
-                killNumber);
-    }
 }
