@@ -18,7 +18,6 @@
 package org.apache.dolphinscheduler.server.worker.config;
 
 import org.apache.dolphinscheduler.common.utils.NetUtils;
-import org.apache.dolphinscheduler.registry.api.ConnectStrategyProperties;
 import org.apache.dolphinscheduler.registry.api.enums.RegistryNodeType;
 
 import org.apache.commons.lang3.StringUtils;
@@ -42,11 +41,10 @@ import org.springframework.validation.annotation.Validated;
 public class WorkerConfig implements Validator {
 
     private int listenPort = 1234;
-    private int execThreads = 10;
     private Duration maxHeartbeatInterval = Duration.ofSeconds(10);
     private int hostWeight = 100;
-    private WorkerServerLoadProtection serverLoadProtection = new WorkerServerLoadProtection();
-    private ConnectStrategyProperties registryDisconnectStrategy = new ConnectStrategyProperties();
+    private WorkerServerLoadProtectionConfig serverLoadProtection = new WorkerServerLoadProtectionConfig();
+    private String group;
 
     /**
      * This field doesn't need to set at config file, it will be calculated by workerIp:listenPort
@@ -54,10 +52,10 @@ public class WorkerConfig implements Validator {
     private String workerAddress;
     private String workerRegistryPath;
 
-    private TaskExecuteThreadsFullPolicy taskExecuteThreadsFullPolicy = TaskExecuteThreadsFullPolicy.REJECT;
-
     private TenantConfig tenantConfig = new TenantConfig();
 
+    private PhysicalTaskConfig physicalTaskConfig = new PhysicalTaskConfig();
+
     @Override
     public boolean supports(Class<?> clazz) {
         return WorkerConfig.class.isAssignableFrom(clazz);
@@ -66,11 +64,8 @@ public class WorkerConfig implements Validator {
     @Override
     public void validate(Object target, Errors errors) {
         WorkerConfig workerConfig = (WorkerConfig) target;
-        if (workerConfig.getExecThreads() <= 0) {
-            errors.rejectValue("exec-threads", null, "should be a positive value");
-        }
         if (workerConfig.getMaxHeartbeatInterval().getSeconds() <= 0) {
-            errors.rejectValue("max-heartbeat-interval", null, "shoule be a valid duration");
+            errors.rejectValue("max-heartbeat-interval", null, "should be a valid duration");
         }
         if (StringUtils.isEmpty(workerConfig.getWorkerAddress())) {
             workerConfig.setWorkerAddress(NetUtils.getAddr(workerConfig.getListenPort()));
@@ -78,6 +73,11 @@ public class WorkerConfig implements Validator {
 
         workerConfig.setWorkerRegistryPath(
                 RegistryNodeType.WORKER.getRegistryPath() + "/" + workerConfig.getWorkerAddress());
+
+        if (StringUtils.isEmpty(group)) {
+            workerConfig.setGroup("default");
+        }
+
         printConfig();
     }
 
@@ -85,15 +85,14 @@ public class WorkerConfig implements Validator {
         String config =
                 "\n****************************Worker Configuration**************************************" +
                         "\n  listen-port -> " + listenPort +
-                        "\n  exec-threads -> " + execThreads +
                         "\n  max-heartbeat-interval -> " + maxHeartbeatInterval +
                         "\n  host-weight -> " + hostWeight +
                         "\n  tenantConfig -> " + tenantConfig +
                         "\n  server-load-protection -> " + serverLoadProtection +
-                        "\n  registry-disconnect-strategy -> " + registryDisconnectStrategy +
-                        "\n  task-execute-threads-full-policy: " + taskExecuteThreadsFullPolicy +
                         "\n  address -> " + workerAddress +
                         "\n  registry-path: " + workerRegistryPath +
+                        "\n  physical-task-config -> " + physicalTaskConfig +
+                        "\n  group -> " + group +
                         "\n****************************Worker Configuration**************************************";
         log.info(config);
     }
